@@ -54,19 +54,22 @@
 /  a friend, but please do not charge him....
 /
 /---------------------------------------------------------------------*/
-const char CfgOpts_rcsid[] = "Hatari $Id: cfgopts.c,v 1.9 2006/07/11 18:52:18 thothy Exp $";
+const char CfgOpts_rcsid[] = "Hatari $Id: cfgopts.c,v 1.11 2007/05/12 09:24:36 thothy Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h>
+#include <unistd.h>
 
 #include "main.h"
 #include "cfgopts.h"
 
 
 
-/* --- Remove spaces from beginning and end of a string --- */
+/**
+ *  --- Remove spaces from beginning and end of a string ---
+ */
 static char *trim(char *buffer)
 {
 	const char SPACE = ' ';
@@ -104,17 +107,19 @@ static char *trim(char *buffer)
 }
 
 
-/*---------------------------------------------------------------------/
-/   reads from an input configuration (INI) file.
-/---------------------------------------------------------------------*/
-/*>>------[   input_config()   ]-------------[ 08-02-95 14:02PM ]------/
-/ return value:
-/     int                     ; number of records read or -1 on error
-/ parameters:
-/     char *filename          ; filename of INI style file
-/     struct Config_Tag configs[]; Configuration structure
-/     char *header            ; INI header name (i.e. "[TEST]")
-/-------------------------------------------------------------------<<*/
+/**
+ * ---------------------------------------------------------------------/
+ * /   reads from an input configuration (INI) file.
+ * /---------------------------------------------------------------------
+ * >>------[   input_config()   ]-------------[ 08-02-95 14:02PM ]------/
+ * / return value:
+ * /     int                     ; number of records read or -1 on error
+ * / parameters:
+ * /     char *filename          ; filename of INI style file
+ * /     struct Config_Tag configs[]; Configuration structure
+ * /     char *header            ; INI header name (i.e. "[TEST]")
+ * /-------------------------------------------------------------------<<
+ */
 int input_config(const char *filename, const struct Config_Tag configs[], const char *header)
 {
 	const struct Config_Tag *ptr;
@@ -220,7 +225,9 @@ int input_config(const char *filename, const struct Config_Tag configs[], const
 }
 
 
-/* Write out an settings line */
+/**
+ *  Write out an settings line
+ */
 static int write_token(FILE *outfile, const struct Config_Tag *ptr)
 {
 	fprintf(outfile,"%s = ",ptr->code);
@@ -269,17 +276,19 @@ static int write_token(FILE *outfile, const struct Config_Tag *ptr)
 }
 
 
-/*---------------------------------------------------------------------/
-/   updates an input configuration (INI) file from a structure.
-/---------------------------------------------------------------------*/
-/*>>------[   update_config()  ]-------------[ 08-02-95 14:02PM ]------/
-/ return value:
-/     int                     ; Number of records read & updated
-/ parameters:
-/     char *filename          ; filename of INI file
-/     struct Config_Tag configs[]; Configuration structure
-/     char *header            ; INI header name (i.e. "[TEST]")
-/-------------------------------------------------------------------<<*/
+/**
+ * ---------------------------------------------------------------------/
+ * /   updates an input configuration (INI) file from a structure.
+ * /---------------------------------------------------------------------
+ * >>------[   update_config()  ]-------------[ 08-02-95 14:02PM ]------/
+ * / return value:
+ * /     int                     ; Number of records read & updated
+ * / parameters:
+ * /     char *filename          ; filename of INI file
+ * /     struct Config_Tag configs[]; Configuration structure
+ * /     char *header            ; INI header name (i.e. "[TEST]")
+ * /-------------------------------------------------------------------<<
+ */
 int update_config(const char *filename, const struct Config_Tag configs[], const char *header)
 {
 	const struct Config_Tag *ptr;
@@ -287,6 +296,8 @@ int update_config(const char *filename, const struct Config_Tag configs[], const
 	FILE *cfgfile, *tempfile;
 	char *fptr, *tok, *next;
 	char line[1024];
+	BOOL bUseTempCfg = FALSE;
+	const char *sTempCfgName = "_temp_.cfg";
 
 	cfgfile = fopen(filename, "r");
 
@@ -312,9 +323,16 @@ int update_config(const char *filename, const struct Config_Tag configs[], const
 
 	tempfile = tmpfile();                        /* Open a temporary file for output */
 	if (tempfile == NULL)
+	{
+		/* tmpfile() failed, let's try a normal open */
+		tempfile = fopen(sTempCfgName, "w+");
+		bUseTempCfg = TRUE;
+	}
+	if (tempfile == NULL)
 	{
 		fclose(cfgfile);
-		return -1;                                /* return error designation. */
+		perror("update_config");
+		return -1;                               /* return error designation. */
 	}
 
 	if (header != NULL)
@@ -433,6 +451,8 @@ int update_config(const char *filename, const struct Config_Tag configs[], const
 	if (cfgfile == NULL)
 	{
 		fclose(tempfile);
+		if (bUseTempCfg)
+			unlink(sTempCfgName);
 		return -1;
 	}
 
@@ -440,6 +460,8 @@ int update_config(const char *filename, const struct Config_Tag configs[], const
 	{
 		fclose(cfgfile);
 		fclose(tempfile);
+		if (bUseTempCfg)
+			unlink(sTempCfgName);
 		return -1;
 	}
 
@@ -448,16 +470,22 @@ int update_config(const char *filename, const struct Config_Tag configs[], const
 	{
 		size_t copycount;
 		copycount = fread(line, sizeof(char), sizeof(line), tempfile);
-		if (fwrite(line, sizeof(char), copycount, cfgfile) != copycount)
+		if (copycount <= 0
+		    || fwrite(line, sizeof(char), copycount, cfgfile) != copycount)
 		{
 			fclose(cfgfile);
 			fclose(tempfile);
+			if (bUseTempCfg)
+				unlink(sTempCfgName);
 			return -1;
 		}
 	}
 
 	fclose(cfgfile);
 	fclose(tempfile);
+	if (bUseTempCfg)
+		unlink(sTempCfgName);
+
 	return count;
 }
 
