@@ -9,7 +9,7 @@
   The configuration file is now stored in an ASCII format to allow the user
   to edit the file manually.
 */
-const char Configuration_rcsid[] = "Hatari $Id: configuration.c,v 1.52 2006/08/09 08:14:24 eerot Exp $";
+const char Configuration_rcsid[] = "Hatari $Id: configuration.c,v 1.65 2007/02/27 20:53:52 eerot Exp $";
 
 #include <SDL_keysym.h>
 
@@ -20,6 +20,7 @@ const char Configuration_rcsid[] = "Hatari $Id: configuration.c,v 1.52 2006/08/0
 #include "file.h"
 #include "log.h"
 #include "m68000.h"
+#include "memorySnapShot.h"
 #include "screen.h"
 #include "vdi.h"
 #include "video.h"
@@ -45,11 +46,11 @@ static const struct Config_Tag configs_Log[] =
 static const struct Config_Tag configs_Screen[] =
 {
 	{ "bFullScreen", Bool_Tag, &ConfigureParams.Screen.bFullScreen },
-	{ "bFrameSkip", Bool_Tag, &ConfigureParams.Screen.bFrameSkip },
+	{ "FrameSkips", Int_Tag, &ConfigureParams.Screen.FrameSkips },
 	{ "bAllowOverscan", Bool_Tag, &ConfigureParams.Screen.bAllowOverscan },
-	{ "bInterleavedScreen", Bool_Tag, &ConfigureParams.Screen.bInterleavedScreen },
-	{ "ChosenDisplayMode", Int_Tag, &ConfigureParams.Screen.ChosenDisplayMode },
-	{ "bUseHighRes", Bool_Tag, &ConfigureParams.Screen.bUseHighRes },
+	{ "bForce8Bpp", Bool_Tag, &ConfigureParams.Screen.bForce8Bpp },
+	{ "bZoomLowRes", Bool_Tag, &ConfigureParams.Screen.bZoomLowRes },
+	{ "MonitorType", Int_Tag, &ConfigureParams.Screen.MonitorType },
 	{ "bUseExtVdiResolutions", Bool_Tag, &ConfigureParams.Screen.bUseExtVdiResolutions },
 	{ "nVdiResolution", Int_Tag, &ConfigureParams.Screen.nVdiResolution },
 	{ "nVdiColors", Int_Tag, &ConfigureParams.Screen.nVdiColors },
@@ -217,14 +218,6 @@ static const struct Config_Tag configs_Floppy[] =
 	{ NULL , Error_Tag, NULL }
 };
 
-/* Obsolete - to be removed */
-static const struct Config_Tag configs_OldFloppy[] =
-{
-	{ "bAutoInsertDiscB", Bool_Tag, &ConfigureParams.DiskImage.bAutoInsertDiskB },
-	{ "szDiscImageDirectory", String_Tag, ConfigureParams.DiskImage.szDiskImageDirectory },
-	{ NULL , Error_Tag, NULL }
-};
-
 /* Used to load/save HD options */
 static const struct Config_Tag configs_HardDisk[] =
 {
@@ -239,17 +232,6 @@ static const struct Config_Tag configs_HardDisk[] =
 	{ NULL , Error_Tag, NULL }
 };
 
-/* Obsolete - to be removed */
-static const struct Config_Tag configs_OldHardDisc[] =
-{
-	{ "bBootFromHardDisc", Bool_Tag, &ConfigureParams.HardDisk.bBootFromHardDisk },
-	{ "bUseHardDiscDirectory", Bool_Tag, &ConfigureParams.HardDisk.bUseHardDiskDirectories },
-	{ "szHardDiscDirectory", String_Tag, ConfigureParams.HardDisk.szHardDiskDirectories[DRIVE_C] },
-	{ "bUseHardDiscImage", Bool_Tag, &ConfigureParams.HardDisk.bUseHardDiskImage },
-	{ "szHardDiscImage", String_Tag, ConfigureParams.HardDisk.szHardDiskImage },
-	{ NULL , Error_Tag, NULL }
-};
-
 /* Used to load/save ROM options */
 static const struct Config_Tag configs_Rom[] =
 {
@@ -293,6 +275,7 @@ static const struct Config_Tag configs_System[] =
 	{ "bCompatibleCpu", Bool_Tag, &ConfigureParams.System.bCompatibleCpu },
 	{ "nMachineType", Int_Tag, &ConfigureParams.System.nMachineType },
 	{ "bBlitter", Bool_Tag, &ConfigureParams.System.bBlitter },
+	{ "nDSPType", Int_Tag, &ConfigureParams.System.nDSPType },
 	{ "bRealTimeClock", Bool_Tag, &ConfigureParams.System.bRealTimeClock },
 	{ "bPatchTimerD", Bool_Tag, &ConfigureParams.System.bPatchTimerD },
 	{ "bSlowFDC", Bool_Tag, &ConfigureParams.System.bSlowFDC },
@@ -301,9 +284,9 @@ static const struct Config_Tag configs_System[] =
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set default configuration values.
-*/
+/**
+ * Set default configuration values.
+ */
 void Configuration_SetDefault(void)
 {
 	int i;
@@ -337,6 +320,8 @@ void Configuration_SetDefault(void)
 	}
 	ConfigureParams.HardDisk.bUseHardDiskImage = FALSE;
 	strcpy(ConfigureParams.HardDisk.szHardDiskImage, szWorkingDir);
+	ConfigureParams.HardDisk.bUseIdeHardDiskImage = FALSE;
+	strcpy(ConfigureParams.HardDisk.szIdeHardDiskImage, szWorkingDir);
 
 	/* Set defaults for Joysticks */
 	for (i = 0; i < JOYSTICK_COUNT; i++)
@@ -358,24 +343,26 @@ void Configuration_SetDefault(void)
 	ConfigureParams.Keyboard.nKeymapType = KEYMAP_SYMBOLIC;
 	strcpy(ConfigureParams.Keyboard.szMappingFileName, "");
   
-  /* Set defaults for Shortcuts */
-  ConfigureParams.Shortcut.withoutModifier[SHORTCUT_OPTIONS] = SDLK_F12;
-  ConfigureParams.Shortcut.withoutModifier[SHORTCUT_FULLSCREEN] = SDLK_F11;
+	/* Set defaults for Shortcuts */
+	ConfigureParams.Shortcut.withoutModifier[SHORTCUT_OPTIONS] = SDLK_F12;
+	ConfigureParams.Shortcut.withoutModifier[SHORTCUT_FULLSCREEN] = SDLK_F11;
   
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_OPTIONS] = SDLK_o;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_FULLSCREEN] = SDLK_f;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_MOUSEMODE] = SDLK_m;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_COLDRESET] = SDLK_c;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_WARMRESET] = SDLK_r;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_SCREENSHOT] = SDLK_g;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_BOSSKEY] = SDLK_i;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_CURSOREMU] = SDLK_j;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_MAXSPEED] = SDLK_x;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_RECANIM] = SDLK_a;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_RECSOUND] = SDLK_y;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_SOUND] = SDLK_s;
-  ConfigureParams.Shortcut.withModifier[SHORTCUT_QUIT] = SDLK_q;
-         
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_OPTIONS] = SDLK_o;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_FULLSCREEN] = SDLK_f;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_MOUSEMODE] = SDLK_m;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_COLDRESET] = SDLK_c;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_WARMRESET] = SDLK_r;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_SCREENSHOT] = SDLK_g;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_BOSSKEY] = SDLK_i;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_CURSOREMU] = SDLK_j;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_MAXSPEED] = SDLK_x;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_RECANIM] = SDLK_a;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_RECSOUND] = SDLK_y;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_SOUND] = SDLK_s;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_QUIT] = SDLK_q;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_LOADMEM] = SDLK_l;
+	ConfigureParams.Shortcut.withModifier[SHORTCUT_SAVEMEM] = SDLK_k;
+	
 	/* Set defaults for Memory */
 	ConfigureParams.Memory.nMemorySize = 1;     /* 1 MiB */
 	sprintf(ConfigureParams.Memory.szMemoryCaptureFileName, "%s%chatari.sav", szWorkingDir,PATHSEP);
@@ -396,11 +383,11 @@ void Configuration_SetDefault(void)
 
 	/* Set defaults for Screen */
 	ConfigureParams.Screen.bFullScreen = FALSE;
-	ConfigureParams.Screen.bFrameSkip = FALSE;
+	ConfigureParams.Screen.FrameSkips = 1;
 	ConfigureParams.Screen.bAllowOverscan = TRUE;
-	ConfigureParams.Screen.bInterleavedScreen = FALSE;
-	ConfigureParams.Screen.ChosenDisplayMode = DISPLAYMODE_HICOL_LOWRES;
-	ConfigureParams.Screen.bUseHighRes = FALSE;
+	ConfigureParams.Screen.bForce8Bpp = FALSE;
+	ConfigureParams.Screen.bZoomLowRes = FALSE;
+	ConfigureParams.Screen.MonitorType = MONITOR_TYPE_RGB;
 	ConfigureParams.Screen.bUseExtVdiResolutions = FALSE;
 	ConfigureParams.Screen.nVdiResolution = GEMRES_640x480;
 	ConfigureParams.Screen.nVdiColors = GEMCOLOUR_16;
@@ -423,6 +410,7 @@ void Configuration_SetDefault(void)
 	/*ConfigureParams.System.bAddressSpace24 = TRUE;*/
 	ConfigureParams.System.nMachineType = MACHINE_ST;
 	ConfigureParams.System.bBlitter = FALSE;
+	ConfigureParams.System.nDSPType = DSP_TYPE_NONE;
 	ConfigureParams.System.bPatchTimerD = TRUE;
 	ConfigureParams.System.bRealTimeClock = TRUE;
 	ConfigureParams.System.nMinMaxSpeed = MINMAXSPEED_MIN;
@@ -434,23 +422,36 @@ void Configuration_SetDefault(void)
 		sprintf(sConfigFileName, "%s%c.hatari.cfg", homeDir,PATHSEP);
 	else
 		strcpy(sConfigFileName, "hatari.cfg");
+
+#if defined(__AMIGAOS4__)
+	/* Fix default path names on Amiga OS */
+	sprintf(ConfigureParams.Rom.szTosImageFileName, "%stos.img", DATADIR);
+#endif
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Copy details from configuration structure into global variables for system,
-  clean file names, etc...
-*/
-void Configuration_WorkOnDetails(BOOL bReset)
+/**
+ * Copy details from configuration structure into global variables for system,
+ * clean file names, etc...  Called from main.c and dialog.c files.
+ */
+void Configuration_Apply(BOOL bReset)
 {
-	/* Set resolution change */
 	if (bReset)
 	{
+		/* Set resolution change */
 		bUseVDIRes = ConfigureParams.Screen.bUseExtVdiResolutions;
-		bUseHighRes = (!bUseVDIRes && ConfigureParams.Screen.bUseHighRes)
-					  || (bUseVDIRes && ConfigureParams.Screen.nVdiColors==GEMCOLOUR_2);
-		VDI_SetResolution(ConfigureParams.Screen.nVdiResolution, ConfigureParams.Screen.nVdiColors);
+		bUseHighRes = ((!bUseVDIRes) && ConfigureParams.Screen.MonitorType == MONITOR_TYPE_MONO)
+			|| (bUseVDIRes && ConfigureParams.Screen.nVdiColors == GEMCOLOUR_2);
+		if (bUseHighRes)
+		{
+			STRes = ST_HIGH_RES;
+		}
+		if (bUseVDIRes)
+		{
+			VDI_SetResolution(ConfigureParams.Screen.nVdiResolution,
+			                  ConfigureParams.Screen.nVdiColors);
+		}
 	}
 
 	/* Set playback frequency */
@@ -473,6 +474,9 @@ void Configuration_WorkOnDetails(BOOL bReset)
 		ConfigureParams.System.nCpuFreq = 16;
 		nCpuFreqShift = 1;
 	}
+	/* Change UAE cpu_level and cpu_compatible accordingly */
+	check_prefs_changed_cpu(ConfigureParams.System.nCpuLevel,
+				ConfigureParams.System.bCompatibleCpu);
 
 	/* Clean file and directory names */
 	File_MakeAbsoluteName(ConfigureParams.Rom.szTosImageFileName);
@@ -481,16 +485,23 @@ void Configuration_WorkOnDetails(BOOL bReset)
 	File_MakeAbsoluteName(ConfigureParams.HardDisk.szHardDiskImage);
 	File_CleanFileName(ConfigureParams.HardDisk.szHardDiskDirectories[0]);
 	File_MakeAbsoluteName(ConfigureParams.HardDisk.szHardDiskDirectories[0]);
-	File_MakeAbsoluteName(ConfigureParams.Midi.szMidiOutFileName);
+	File_MakeAbsoluteName(ConfigureParams.Memory.szMemoryCaptureFileName);
+	File_MakeAbsoluteName(ConfigureParams.Sound.szYMCaptureFileName);
+	File_MakeAbsoluteName(ConfigureParams.Keyboard.szMappingFileName);
 	File_MakeAbsoluteName(ConfigureParams.RS232.szOutFileName);
 	File_MakeAbsoluteName(ConfigureParams.RS232.szInFileName);
+	
+	/* make path names absolute, but handle special file names */
+	File_MakeAbsoluteSpecialName(ConfigureParams.Log.sLogFileName);
+	File_MakeAbsoluteSpecialName(ConfigureParams.Midi.szMidiOutFileName);
+	File_MakeAbsoluteSpecialName(ConfigureParams.Printer.szPrintToFileName);
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Load a settings section from the configuration file.
-*/
+/**
+ * Load a settings section from the configuration file.
+ */
 static int Configuration_LoadSection(const char *pFilename, const struct Config_Tag configs[], const char *pSection)
 {
 	int ret;
@@ -506,10 +517,10 @@ static int Configuration_LoadSection(const char *pFilename, const struct Config_
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Load program setting from configuration file. If psFileName is NULL, use
-  the default (i.e. the users) configuration file.
-*/
+/**
+ * Load program setting from configuration file. If psFileName is NULL, use
+ * the default (i.e. the users) configuration file.
+ */
 void Configuration_Load(const char *psFileName)
 {
 	if (psFileName == NULL)
@@ -536,28 +547,20 @@ void Configuration_Load(const char *psFileName)
 	Configuration_LoadSection(psFileName, configs_ShortCutWithoutMod, "[ShortcutsWithoutModifiers]");
 	Configuration_LoadSection(psFileName, configs_Sound, "[Sound]");
 	Configuration_LoadSection(psFileName, configs_Memory, "[Memory]");
-	Configuration_LoadSection(psFileName, configs_OldFloppy, "[Floppy]");  /* <- to be removed */
 	Configuration_LoadSection(psFileName, configs_Floppy, "[Floppy]");
-	Configuration_LoadSection(psFileName, configs_OldHardDisc, "[HardDisc]");  /* <- to be removed */
 	Configuration_LoadSection(psFileName, configs_HardDisk, "[HardDisk]");
 	Configuration_LoadSection(psFileName, configs_Rom, "[ROM]");
 	Configuration_LoadSection(psFileName, configs_Rs232, "[RS232]");
 	Configuration_LoadSection(psFileName, configs_Printer, "[Printer]");
 	Configuration_LoadSection(psFileName, configs_Midi, "[Midi]");
 	Configuration_LoadSection(psFileName, configs_System, "[System]");
-
-	/* Copy details to global variables */
-	cpu_level = ConfigureParams.System.nCpuLevel;
-	cpu_compatible = ConfigureParams.System.bCompatibleCpu;
-
-	Configuration_WorkOnDetails(TRUE);
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Save a settings section to configuration file
-*/
+/**
+ * Save a settings section to configuration file
+ */
 static int Configuration_SaveSection(const char *pFilename, const struct Config_Tag configs[], const char *pSection)
 {
 	int ret;
@@ -572,9 +575,9 @@ static int Configuration_SaveSection(const char *pFilename, const struct Config_
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Save program setting to configuration file
-*/
+/**
+ * Save program setting to configuration file
+ */
 void Configuration_Save(void)
 {
 	if (Configuration_SaveSection(sConfigFileName, configs_Log, "[Log]") < 0)
@@ -603,3 +606,40 @@ void Configuration_Save(void)
 	Configuration_SaveSection(sConfigFileName, configs_System, "[System]");
 }
 
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Save/restore snapshot of configuration variables
+ * ('MemorySnapShot_Store' handles type)
+ */
+void Configuration_MemorySnapShot_Capture(BOOL bSave)
+{
+	MemorySnapShot_Store(ConfigureParams.Rom.szTosImageFileName, sizeof(ConfigureParams.Rom.szTosImageFileName));
+	MemorySnapShot_Store(ConfigureParams.Rom.szCartridgeImageFileName, sizeof(ConfigureParams.Rom.szCartridgeImageFileName));
+
+	MemorySnapShot_Store(&ConfigureParams.Memory.nMemorySize, sizeof(ConfigureParams.Memory.nMemorySize));
+
+	MemorySnapShot_Store(&ConfigureParams.HardDisk.bUseHardDiskDirectories, sizeof(ConfigureParams.HardDisk.bUseHardDiskDirectories));
+	MemorySnapShot_Store(ConfigureParams.HardDisk.szHardDiskDirectories[DRIVE_C], sizeof(ConfigureParams.HardDisk.szHardDiskDirectories[DRIVE_C]));
+	MemorySnapShot_Store(&ConfigureParams.HardDisk.bUseHardDiskImage, sizeof(ConfigureParams.HardDisk.bUseHardDiskImage));
+	MemorySnapShot_Store(ConfigureParams.HardDisk.szHardDiskImage, sizeof(ConfigureParams.HardDisk.szHardDiskImage));
+
+	MemorySnapShot_Store(&ConfigureParams.Screen.MonitorType, sizeof(ConfigureParams.Screen.MonitorType));
+	MemorySnapShot_Store(&ConfigureParams.Screen.bUseExtVdiResolutions, sizeof(ConfigureParams.Screen.bUseExtVdiResolutions));
+	MemorySnapShot_Store(&ConfigureParams.Screen.nVdiResolution, sizeof(ConfigureParams.Screen.nVdiResolution));
+	MemorySnapShot_Store(&ConfigureParams.Screen.nVdiColors, sizeof(ConfigureParams.Screen.nVdiColors));
+
+	MemorySnapShot_Store(&ConfigureParams.System.nCpuLevel, sizeof(ConfigureParams.System.nCpuLevel));
+	MemorySnapShot_Store(&ConfigureParams.System.nCpuFreq, sizeof(ConfigureParams.System.nCpuFreq));
+	MemorySnapShot_Store(&ConfigureParams.System.bCompatibleCpu, sizeof(ConfigureParams.System.bCompatibleCpu));
+	MemorySnapShot_Store(&ConfigureParams.System.nMachineType, sizeof(ConfigureParams.System.nMachineType));
+	MemorySnapShot_Store(&ConfigureParams.System.bBlitter, sizeof(ConfigureParams.System.bBlitter));
+	MemorySnapShot_Store(&ConfigureParams.System.nDSPType, sizeof(ConfigureParams.System.nDSPType));
+	MemorySnapShot_Store(&ConfigureParams.System.bRealTimeClock, sizeof(ConfigureParams.System.bRealTimeClock));
+	MemorySnapShot_Store(&ConfigureParams.System.bPatchTimerD, sizeof(ConfigureParams.System.bPatchTimerD));
+	MemorySnapShot_Store(&ConfigureParams.System.bSlowFDC, sizeof(ConfigureParams.System.bSlowFDC));
+
+	if (!bSave)
+		Configuration_Apply(TRUE);
+}
+
