@@ -4,9 +4,11 @@ static void Line_ConvertLowRes_640x16Bit(Uint32 *edi, Uint32 *ebp, Uint32 *esi,
 {
  Uint32 edx;
  Uint32 ebx, ecx;
- int x;
+ int x, update, Screen4BytesPerLine;
 
  x = STScreenWidthBytes>>3;   /* Amount to draw across in 16-pixels(8 bytes) */
+ Screen4BytesPerLine = PCScreenBytesPerLine/4;
+ update = ScrUpdateFlag & PALETTEMASK_UPDATEMASK;
 
  do    /* x-loop */
   {
@@ -14,7 +16,7 @@ static void Line_ConvertLowRes_640x16Bit(Uint32 *edi, Uint32 *ebp, Uint32 *esi,
    ebx=*edi;
    ecx=*(edi+1);
 
-   if( (ScrUpdateFlag&0xe0000000) || ebx!=*ebp || ecx!=*(ebp+1) )     /* Does differ? */
+   if( update || ebx!=*ebp || ecx!=*(ebp+1) )     /* Does differ? */
     { /* copy word */
 
      bScreenContentsChanged=TRUE;
@@ -100,12 +102,11 @@ static void ConvertLowRes_640x16Bit(void)
    ebp = (Uint32 *)((Uint8 *)pSTScreenCopy + eax);    /* Previous ST format screen */
    esi = (Uint32 *)pPCScreenDest;                     /* PC format screen */
 
-   if( (AdjustLinePaletteRemap(y) & 0x00030000)==0 )     /* Change palette table */
-     Line_ConvertLowRes_640x16Bit(edi, ebp, esi, eax);
-    else
+   if (AdjustLinePaletteRemap(y) & 0x00030000)        /* Change palette table */
      Line_ConvertMediumRes_640x16Bit(edi, ebp, (Uint16 *)esi, eax);
+    else
+     Line_ConvertLowRes_640x16Bit(edi, ebp, esi, eax);
 
    pPCScreenDest = (((Uint8 *)pPCScreenDest)+PCScreenBytesPerLine*2);  /* Offset to next line */
   }
 }
-
