@@ -8,9 +8,17 @@
   pressed, the emulator is (hopefully) halted and this little CLI can be used
   (in the terminal box) for debugging tasks like memory and register dumps.
 */
-const char DebugUI_rcsid[] = "Hatari $Id: debugui.c,v 1.12 2006/02/08 22:49:27 eerot Exp $";
+const char DebugUI_rcsid[] = "Hatari $Id: debugui.c,v 1.16 2007/01/16 18:42:59 thothy Exp $";
 
 #include <ctype.h>
+#include <stdio.h>
+
+#include "config.h"
+
+#if HAVE_LIBREADLINE
+#include <readline/readline.h>
+#include <readline/history.h>
+#endif
 
 #include "main.h"
 #include "configuration.h"
@@ -40,7 +48,9 @@ static FILE *debugLogFile;
 static FILE *debug_stdout;
 
 
-/* convert string to lowercase */
+/**
+ * convert string to lowercase
+ */
 static void string_tolower(char *str)
 {
 	int i=0;
@@ -52,7 +62,9 @@ static void string_tolower(char *str)
 	}
 }
 
-/* truncate string at first unprintable char (e.g. newline) */
+/**
+ * truncate string at first unprintable char (e.g. newline)
+ */
 static void string_trunc(char *str)
 {
 	int i=0;
@@ -64,7 +76,9 @@ static void string_trunc(char *str)
 	}
 }
 
-/* check if string is valid hex number. */
+/**
+ * check if string is valid hex number.
+ */
 static BOOL isHex(char *str)
 {
 	int i=0;
@@ -79,12 +93,12 @@ static BOOL isHex(char *str)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Get a hex adress range, eg. "fa0000-fa0100" 
-  returns -1 if not a range,
-  -2 if a range, but not a valid one.
-  0 if OK.
-*/
+/**
+ * Get a hex adress range, eg. "fa0000-fa0100" 
+ * returns -1 if not a range,
+ * -2 if a range, but not a valid one.
+ * 0 if OK.
+ */
 static BOOL getRange(char *str, unsigned long *lower, unsigned long *upper)
 {
 	BOOL fDash = FALSE;
@@ -112,9 +126,9 @@ static BOOL getRange(char *str, unsigned long *lower, unsigned long *upper)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Open a log file.
-*/
+/**
+ * Open a log file.
+ */
 static void DebugUI_OpenLog(const char *arg)
 {
 	debugLogFile = fopen(arg, "w");
@@ -125,9 +139,9 @@ static void DebugUI_OpenLog(const char *arg)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Load a binary file to a memory address.
-*/
+/**
+ * Load a binary file to a memory address.
+ */
 static void DebugUI_LoadBin(char *args)
 {
 	FILE *fp;
@@ -161,9 +175,9 @@ static void DebugUI_LoadBin(char *args)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Dump memory from an address to a binary file.
-*/
+/**
+ * Dump memory from an address to a binary file.
+ */
 static void DebugUI_SaveBin(char *args)
 {
 	FILE *fp;
@@ -196,9 +210,9 @@ static void DebugUI_SaveBin(char *args)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Do a register dump.
-*/
+/**
+ * Do a register dump.
+ */
 static void DebugUI_RegDump(void)
 {
 	uaecptr nextpc;
@@ -208,9 +222,9 @@ static void DebugUI_RegDump(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Dissassemble - arg = starting address, or PC.
-*/
+/**
+ * Dissassemble - arg = starting address, or PC.
+ */
 static void DebugUI_DisAsm(char *arg, BOOL cont)
 {
 	int i,j;
@@ -272,9 +286,9 @@ static void DebugUI_DisAsm(char *arg, BOOL cont)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set a register: 
-*/
+/**
+ * Set a register: 
+ */
 static void DebugUI_RegSet(char *arg)
 {
 	int i;
@@ -400,9 +414,9 @@ static void DebugUI_RegSet(char *arg)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Do a memory dump, args = starting address.
-*/
+/**
+ * Do a memory dump, args = starting address.
+ */
 static void DebugUI_MemDump(char *arg, BOOL cont)
 {
 	int i,j;
@@ -487,10 +501,10 @@ static void DebugUI_MemDump(char *arg, BOOL cont)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Do a memory write, arg = starting address, followed by bytes.
-*/
-static void DebugUI_MemWrite(char *addr_str, char *arg)
+/**
+ * Do a memory write, arg = starting address, followed by bytes.
+ */
+static void DebugUI_MemWrite(char *arg)
 {
 	int i, j, numBytes;
 	long write_addr;
@@ -564,9 +578,9 @@ static void DebugUI_MemWrite(char *addr_str, char *arg)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Print help.
-*/
+/**
+ * Print help.
+ */
 static void DebugUI_Help(void)
 {
 	fprintf(stderr, "---- debug mode commands ----\n"
@@ -579,51 +593,76 @@ static void DebugUI_Help(void)
 	        " l filename address - load a file into memory starting at address. \n"
 	        " s filename address length - dump length bytes from memory to a file. \n"
 	        " o - disable debug mode\n\n"
-	        " q - return to emulation\n\n"
+	        " q - quit emulator\n"
+	        " c - continue emulation\n\n"
 	        " Adresses may be given as a range e.g. fc0000-fc0100\nAll values in hexadecimal.\n"
 	        "-----------------------------\n"
 	        "\n");
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Get a UI command, return it.
-*/
+/**
+ * Get a UI command, return it.
+ */
 static int DebugUI_Getcommand(void)
 {
-	char temp[255];
 	char command[255], arg[255];
+	static char lastcommand = 0;
+	char *pInput;
 	int i;
+	int retval;
 
+#if HAVE_LIBREADLINE
+	pInput = readline("> ");
+	if (!pInput)
+		return DEBUG_QUIT;
+	if (pInput[0] != 0)
+		add_history(pInput);
+#else
 	fprintf(stderr, "> ");
-	temp[0] = '\0';
-	fgets(temp, sizeof(temp), stdin);
+	pInput = malloc(256);
+	if (!pInput)
+		return DEBUG_QUIT;
+	pInput[0] = '\0';
+	fgets(pInput, 256, stdin);
+#endif
 
-	i = sscanf(temp, "%s%s", command, arg);
+	command[0] = lastcommand;          /* Used for 'm' and 'd' to continue at last pos */
+	command[1] = 0;
+	arg[0] = 0;
+	i = sscanf(pInput, "%s%s", command, arg);
 	string_tolower(command);
 
 	if (i == 0)
 	{
 		fprintf(stderr, "  Unknown command.\n");
+		free(pInput);
 		return DEBUG_CMD;
 	}
 
+	lastcommand = 0;
+	retval = DEBUG_CMD;                /* Default return value */
+
 	switch (command[0])
 	{
+	 case 'c':
+		retval = DEBUG_QUIT;
+		break;
+
 	 case 'q':
-		return(DEBUG_QUIT);
+		bQuitProgram = TRUE;
+		set_special(SPCFLAG_BRK);   /* Assure that CPU core shuts down */
+		retval = DEBUG_QUIT;
 		break;
 
 	 case 'h':
 	 case '?':
 		DebugUI_Help(); /* get help */
-		return(DEBUG_CMD);
 		break;
 
 	 case 'o':
 		bEnableDebug = FALSE;
 		fprintf(stderr, "  Debug mode disabled.\n");
-		return(DEBUG_CMD);
 		break;
 
 	 case 'd':
@@ -631,20 +670,20 @@ static int DebugUI_Getcommand(void)
 			DebugUI_DisAsm(arg, TRUE);    /* No arg - disassemble at PC */
 		else
 			DebugUI_DisAsm(arg, FALSE);   /* disasm at address. */
+		lastcommand = 'd';
 		break;
 
 	 case 'm':
 		if (i < 2)
 		{  /* no arg? */
 			if (bMemDump == FALSE)
-			{
 				fprintf(stderr,"  Usage: m address\n");
-				return(DEBUG_CMD);
-			}
-			DebugUI_MemDump(arg, TRUE);   /* No arg - continue memdump */
+			else
+				DebugUI_MemDump(arg, TRUE);   /* No arg - continue memdump */
 		}
 		else
 			DebugUI_MemDump(arg, FALSE);  /* new memdump */
+		lastcommand = 'm';
 		break;
 
 	 case 'f':
@@ -664,54 +703,49 @@ static int DebugUI_Getcommand(void)
 		break;
 
 	 case 'w':
-		if (i < 2)
-		{  /* no arg? */
+		if (i < 2)    /* not enough args? */
 			fprintf(stderr, "  Usage: w address bytes\n");
-			return DEBUG_CMD;
-		}
-		DebugUI_MemWrite(arg, temp);
+		else
+			DebugUI_MemWrite(pInput);
 		break;
 
 	 case 'r':
 		if (i < 2)
-		{  /* no arg - dump regs */
-			DebugUI_RegDump();
-			return DEBUG_CMD;
-		}
-		DebugUI_RegSet(arg);
+			DebugUI_RegDump();  /* no arg - dump regs */
+		else
+			DebugUI_RegSet(arg);
 		break;
 
 	 case 'l':
-		if (i < 2)
-		{  /* no arg? */
+		if (i < 2)    /* not enough args? */
 			fprintf(stderr,"  Usage: l filename address\n");
-			return DEBUG_CMD;
-		}
-		DebugUI_LoadBin(temp);
+		else
+			DebugUI_LoadBin(pInput);
 		break;
 
 	 case 's':
-		if (i < 2)
-		{  /* no arg? */
+		if (i < 2)    /* not enough args? */
 			fprintf(stderr,"  Usage: s filename address bytes\n");
-			return DEBUG_CMD;
-		}
-		DebugUI_SaveBin(temp);
+		else
+			DebugUI_SaveBin(pInput);
 		break;
 
 	 default:
-		fprintf(stderr,"  Unknown command: '%s'\n", command);
+		if (command[0])
+			fprintf(stderr,"  Unknown command: '%s'\n", command);
 		break;
 	}
 
-	return DEBUG_CMD;
+	free(pInput);
+
+	return retval;
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Debug UI
-*/
+/**
+ * Debug UI
+ */
 void DebugUI(void)
 {
 	debugLogFile = NULL;
@@ -721,8 +755,8 @@ void DebugUI(void)
 	disasm_addr = 0;
 
 
-	fprintf(stderr, "\nYou have entered debug mode. Type q to quit, h for help."
-	                "\n------------------------------\n");
+	fprintf(stderr, "\nYou have entered debug mode. Type c to continue emulation, h for help."
+	                "\n----------------------------------------------------------------------\n");
 	while (DebugUI_Getcommand() != DEBUG_QUIT)
 		;
 	if (debugLogFile != NULL)
