@@ -9,7 +9,7 @@
   open our dialog we make a backup of this structure. When the user finally
   clicks on 'OK', we can compare and makes the necessary changes.
 */
-const char Dialog_rcsid[] = "Hatari $Id: dialog.c,v 1.51 2006/07/03 20:36:28 clafou Exp $";
+const char Dialog_rcsid[] = "Hatari $Id: dialog.c,v 1.60 2007/01/30 20:33:49 eerot Exp $";
 
 #include "main.h"
 #include "configuration.h"
@@ -34,20 +34,26 @@ const char Dialog_rcsid[] = "Hatari $Id: dialog.c,v 1.51 2006/07/03 20:36:28 cla
 #include "video.h"
 #include "sdlgui.h"
 #include "uae-cpu/hatari-glue.h"
+#if ENABLE_DSP_EMU
+# include "falcon/dsp.h"
+#endif
 
 
 CNF_PARAMS DialogParams;   /* List of configuration for dialogs (so the user can also choose 'Cancel') */
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Check if need to warn user that changes will take place after reset.
-  Return TRUE if wants to reset.
-*/
+/**
+ * Check if need to warn user that changes will take place after reset.
+ * Return TRUE if wants to reset.
+ */
 BOOL Dialog_DoNeedReset(void)
 {
-	/* Did we change colour/mono monitor? If so, must reset */
-	if (ConfigureParams.Screen.bUseHighRes!=DialogParams.Screen.bUseHighRes)
+	/* Did we change monitor type? If so, must reset */
+	if (ConfigureParams.Screen.MonitorType != DialogParams.Screen.MonitorType
+	    && (DialogParams.System.nMachineType == MACHINE_FALCON
+	        || ConfigureParams.Screen.MonitorType == MONITOR_TYPE_MONO
+	        || DialogParams.Screen.MonitorType == MONITOR_TYPE_MONO))
 		return TRUE;
 
 	/* Did change to GEM VDI display? */
@@ -76,14 +82,18 @@ BOOL Dialog_DoNeedReset(void)
 	        && DialogParams.HardDisk.bUseHardDiskDirectories))
 		return TRUE;
 
+	/* Did change machine type? */
+	if (DialogParams.System.nMachineType != ConfigureParams.System.nMachineType)
+		return TRUE;
+
 	return FALSE;
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Copy details back to configuration and perform reset.
-*/
+/**
+ * Copy details back to configuration and perform reset.
+ */
 void Dialog_CopyDialogParamsToConfiguration(BOOL bForceReset)
 {
 	BOOL NeedReset;
@@ -98,13 +108,16 @@ void Dialog_CopyDialogParamsToConfiguration(BOOL bForceReset)
 
 	/* Do need to change resolution? Need if change display/overscan settings */
 	/*(if switch between Colour/Mono cause reset later) */
-	if (DialogParams.Screen.ChosenDisplayMode != ConfigureParams.Screen.ChosenDisplayMode
-	    || DialogParams.Screen.bAllowOverscan != ConfigureParams.Screen.bAllowOverscan)
+	if (!NeedReset &&
+	    (DialogParams.Screen.bForce8Bpp != ConfigureParams.Screen.bForce8Bpp
+	     || DialogParams.Screen.bZoomLowRes != ConfigureParams.Screen.bZoomLowRes
+	     || DialogParams.Screen.bAllowOverscan != ConfigureParams.Screen.bAllowOverscan))
 	{
-		ConfigureParams.Screen.ChosenDisplayMode = DialogParams.Screen.ChosenDisplayMode;
+		ConfigureParams.Screen.bForce8Bpp = DialogParams.Screen.bForce8Bpp;
+		ConfigureParams.Screen.bZoomLowRes = DialogParams.Screen.bZoomLowRes;
 		ConfigureParams.Screen.bAllowOverscan = DialogParams.Screen.bAllowOverscan;
-		PrevSTRes = -1;
-		Screen_DidResolutionChange();
+
+		Screen_ModeChanged();
 	}
 
 	/* Did set new printer parameters? */
@@ -151,26 +164,42 @@ void Dialog_CopyDialogParamsToConfiguration(BOOL bForceReset)
 
 	/* Did change blitter, rtc or system type? */
 	if (DialogParams.System.bBlitter != ConfigureParams.System.bBlitter
+#if ENABLE_DSP_EMU
+	    || DialogParams.System.nDSPType != ConfigureParams.System.nDSPType
+#endif
 	    || DialogParams.System.bRealTimeClock != ConfigureParams.System.bRealTimeClock
 	    || DialogParams.System.nMachineType != ConfigureParams.System.nMachineType)
 	{
 		IoMem_UnInit();
 		bReInitIoMem = TRUE;
 	}
+	
+#if ENABLE_DSP_EMU
+	/* Disabled DSP? */
+	if (DialogParams.System.nDSPType == DSP_TYPE_EMU &&
+	    (DialogParams.System.nDSPType != ConfigureParams.System.nDSPType))
+	{
+		DSP_UnInit();
+	}
+#endif
 
 	/* Copy details to configuration, so can be saved out or set on reset */
 	ConfigureParams = DialogParams;
 
 	/* Copy details to global, if we reset copy them all */
-	Configuration_WorkOnDetails(NeedReset);
+	Configuration_Apply(NeedReset);
+
+#if ENABLE_DSP_EMU
+	if (ConfigureParams.System.nDSPType == DSP_TYPE_EMU)
+	{
+		DSP_Init();
+	}
+#endif
 
 	/* Set keyboard remap file */
 	if (ConfigureParams.Keyboard.nKeymapType == KEYMAP_LOADED)
 		Keymap_LoadRemapFile(ConfigureParams.Keyboard.szMappingFileName);
 
-	/* Did the user changed the CPU mode? */
-	check_prefs_changed_cpu(DialogParams.System.nCpuLevel, DialogParams.System.bCompatibleCpu);
-
 	/* Mount a new HD image: */
 	if (bReInitAcsiEmu && ConfigureParams.HardDisk.bUseHardDiskImage)
 	{
@@ -216,10 +245,10 @@ void Dialog_CopyDialogParamsToConfiguration(BOOL bForceReset)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Open Property sheet Options dialog.
-  Return TRUE if user choses OK, or FALSE if cancel!
-*/
+/**
+ * Open Property sheet Options dialog.
+ * Return TRUE if user choses OK, or FALSE if cancel!
+ */
 BOOL Dialog_DoProperty(void)
 {
 	BOOL bOKDialog;  /* Did user 'OK' dialog? */
@@ -249,9 +278,9 @@ BOOL Dialog_DoProperty(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Loads params from the configuration file into DialogParams
-*/
+/**
+ * Loads params from the configuration file into DialogParams
+ */
 void Dialog_LoadParams(void)
 {
 	CNF_PARAMS tmpParams;
@@ -265,9 +294,9 @@ void Dialog_LoadParams(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Saves params in DialogParams to the configuration file
-*/
+/**
+ * Saves params in DialogParams to the configuration file
+ */
 void Dialog_SaveParams(void)
 {
 	CNF_PARAMS tmpParams;
