@@ -6,7 +6,7 @@
 
   Common file access functions.
 */
-const char File_rcsid[] = "Hatari $Id: file.c,v 1.33 2006/08/08 07:19:15 thothy Exp $";
+const char File_rcsid[] = "Hatari $Id: file.c,v 1.41 2007/02/27 20:53:52 eerot Exp $";
 
 #include <string.h>
 #include <strings.h>
@@ -14,7 +14,8 @@ const char File_rcsid[] = "Hatari $Id: file.c,v 1.33 2006/08/08 07:19:15 thothy
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-
+#include <assert.h>
+#include <errno.h>
 #include <zlib.h>
 
 #include "main.h"
@@ -25,9 +26,9 @@ const char File_rcsid[] = "Hatari $Id: file.c,v 1.33 2006/08/08 07:19:15 thothy
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Remove any '/'s from end of filenames, but keeps / intact
-*/
+/**
+ * Remove any '/'s from end of filenames, but keeps / intact
+ */
 void File_CleanFileName(char *pszFileName)
 {
 	int len;
@@ -48,9 +49,9 @@ void File_CleanFileName(char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Add '/' to end of filename
-*/
+/**
+ * Add '/' to end of filename
+ */
 void File_AddSlashToEndFileName(char *pszFileName)
 {
 	int len;
@@ -70,9 +71,9 @@ void File_AddSlashToEndFileName(char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Does filename extension match? If so, return TRUE
-*/
+/**
+ * Does filename extension match? If so, return TRUE
+ */
 BOOL File_DoesFileExtensionMatch(const char *pszFileName, const char *pszExtension)
 {
 	if (strlen(pszFileName) < strlen(pszExtension))
@@ -87,11 +88,11 @@ BOOL File_DoesFileExtensionMatch(const char *pszFileName, const char *pszExtensi
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Check if filename is from root
-  
-  Return TRUE if filename is '/', else give FALSE
-*/
+/**
+ * Check if filename is from root
+ * 
+ * Return TRUE if filename is '/', else give FALSE
+ */
 BOOL File_IsRootFileName(char *pszFileName)
 {
 	if (pszFileName[0]=='\0')     /* If NULL string return! */
@@ -111,9 +112,9 @@ BOOL File_IsRootFileName(char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Return string, to remove 'C:' part of filename
-*/
+/**
+ * Return string, to remove 'C:' part of filename
+ */
 const char *File_RemoveFileNameDrive(const char *pszFileName)
 {
 	if ( (pszFileName[0]!='\0') && (pszFileName[1]==':') )
@@ -124,11 +125,11 @@ const char *File_RemoveFileNameDrive(const char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Check if filename end with a '/'
-  
-  Return TRUE if filename ends with '/'
-*/
+/**
+ * Check if filename end with a '/'
+ * 
+ * Return TRUE if filename ends with '/'
+ */
 BOOL File_DoesFileNameEndWithSlash(char *pszFileName)
 {
 	if (pszFileName[0] == '\0')    /* If NULL string return! */
@@ -143,10 +144,10 @@ BOOL File_DoesFileNameEndWithSlash(char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read file from disk into memory, allocate memory for it if need to (pass
-  Address as NULL).
-*/
+/**
+ * Read file from disk into memory, allocate memory for it if need to (pass
+ * Address as NULL).
+ */
 void *File_Read(char *pszFileName, void *pAddress, long *pFileSize, const char * const ppszExts[])
 {
 	void *pFile = NULL;
@@ -232,9 +233,9 @@ void *File_Read(char *pszFileName, void *pAddress, long *pFileSize, const char *
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Save file to disk, return FALSE if errors
-*/
+/**
+ * Save file to disk, return FALSE if errors
+ */
 BOOL File_Save(char *pszFileName, const void *pAddress, size_t Size, BOOL bQueryOverwrite)
 {
 	BOOL bRet = FALSE;
@@ -282,9 +283,9 @@ BOOL File_Save(char *pszFileName, const void *pAddress, size_t Size, BOOL bQuery
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Return size of file, -1 if error
-*/
+/**
+ * Return size of file, -1 if error
+ */
 int File_Length(const char *pszFileName)
 {
 	FILE *hDiskFile;
@@ -305,18 +306,16 @@ int File_Length(const char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Return TRUE if file exists
-*/
-BOOL File_Exists(const char *pszFileName)
+/**
+ * Return TRUE if file exists, is readable or writable at least and is not
+ * a directory. 
+ */
+BOOL File_Exists(const char *filename)
 {
-	FILE *hDiskFile;
-
-	/* Attempt to open file */
-	hDiskFile = fopen(pszFileName, "rb");
-	if (hDiskFile!=NULL)
-	{
-		fclose(hDiskFile);
+	struct stat buf;
+	if (stat(filename, &buf) == 0 &&
+	    (buf.st_mode & (S_IRUSR|S_IWUSR)) && !(buf.st_mode & S_IFDIR)) {
+		/* file points to user readable regular file */
 		return TRUE;
 	}
 	return FALSE;
@@ -324,9 +323,9 @@ BOOL File_Exists(const char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Find if file exists, and if so ask user if OK to overwrite
-*/
+/**
+ * Find if file exists, and if so ask user if OK to overwrite
+ */
 BOOL File_QueryOverwrite(const char *pszFileName)
 {
 	char szString[FILENAME_MAX + 26];
@@ -345,9 +344,9 @@ BOOL File_QueryOverwrite(const char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Try filename with various extensions and check if file exists - if so return correct name
-*/
+/**
+ * Try filename with various extensions and check if file exists - if so return correct name
+ */
 BOOL File_FindPossibleExtFileName(char *pszFileName, const char * const ppszExts[])
 {
 	char *szSrcDir, *szSrcName, *szSrcExt;
@@ -393,10 +392,10 @@ BOOL File_FindPossibleExtFileName(char *pszFileName, const char * const ppszExts
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Split a complete filename into path, filename and extension.
-  If pExt is NULL, don't split the extension from the file name!
-*/
+/**
+ * Split a complete filename into path, filename and extension.
+ * If pExt is NULL, don't split the extension from the file name!
+ */
 void File_splitpath(const char *pSrcFileName, char *pDir, char *pName, char *pExt)
 {
 	char *ptr1, *ptr2;
@@ -432,10 +431,10 @@ void File_splitpath(const char *pSrcFileName, char *pDir, char *pName, char *pEx
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Build a complete filename from path, filename and extension.
-  pExt can also be NULL.
-*/
+/**
+ * Build a complete filename from path, filename and extension.
+ * pExt can also be NULL.
+ */
 void File_makepath(char *pDestFileName, const char *pDir, const char *pName, const char *pExt)
 {
 	int len;
@@ -463,10 +462,10 @@ void File_makepath(char *pDestFileName, const char *pDir, const char *pName, con
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Shrink a file name to a certain length and insert some dots if we cut
-  something away (usefull for showing file names in a dialog).
-*/
+/**
+ * Shrink a file name to a certain length and insert some dots if we cut
+ * something away (usefull for showing file names in a dialog).
+ */
 void File_ShrinkName(char *pDestFileName, char *pSrcFileName, int maxlen)
 {
 	int srclen = strlen(pSrcFileName);
@@ -486,16 +485,92 @@ void File_ShrinkName(char *pDestFileName, char *pSrcFileName, int maxlen)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Create a clean absolute file name from a (possibly) relative file name.
-  I.e. filter out all occurancies of "./" and "../".
-  pFileName needs to point to a buffer of at least FILENAME_MAX bytes.
-*/
+/**
+ * Open given filename in given mode and handle "stdout" & "stderr"
+ * filenames specially. Return FILE* to the opened file or NULL on error.
+ */
+FILE *File_Open(const char *path, const char *mode)
+{
+	int wr = 0, rd = 0;
+	FILE *fp;
+
+	/* special "stdout" and "stderr" files can be used
+	 * for files which are written or appended
+	 */
+	if (strchr(mode, 'w') || strchr(mode, 'a'))
+		wr = 1;
+	if (strchr(mode, 'r'))
+		rd = 1;
+	if (strcmp(path, "stdin") == 0)
+	{
+		assert(rd && !wr);
+		return stdin;
+	}
+	if (strcmp(path, "stdout") == 0)
+	{
+		assert(wr && !rd);
+		return stdout;
+	}
+	if (strcmp(path, "stderr") == 0)
+	{
+		assert(wr && !rd);
+		return stderr;
+	}
+	/* Open a normal log file */
+	fp = fopen(path, mode);
+	if (!fp)
+		fprintf(stderr, "Can't open file '%s':\n  %s\n", path, strerror(errno));
+	/* printf("'%s' opened in mode '%s'\n", path, mode, fp); */
+	return fp;
+}
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Close given FILE pointer and return the closed pointer
+ * as NULL for the idiom "fp = File_Close(fp);"
+ */
+FILE *File_Close(FILE *fp)
+{
+	if (fp && fp != stdin && fp != stdout && fp != stderr)
+	{
+		fclose(fp);
+	}
+	return NULL;
+}
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Wrapper for File_MakeAbsoluteName() which special-cases stdin/out/err
+ * named files.  The given buffer should be opened with File_Open()
+ * and closed with File_Close() if this function is used!
+ * (On Linux one can use /dev/stdout etc, this is intended for other OSes)
+ */
+void File_MakeAbsoluteSpecialName(char *path)
+{
+	if (strcmp(path, "stdin")  != 0 &&
+	    strcmp(path, "stdout") != 0 &&
+	    strcmp(path, "stderr") != 0)
+		File_MakeAbsoluteName(path);
+}
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Create a clean absolute file name from a (possibly) relative file name.
+ * I.e. filter out all occurancies of "./" and "../".
+ * pFileName needs to point to a buffer of at least FILENAME_MAX bytes.
+ */
 void File_MakeAbsoluteName(char *pFileName)
 {
 	char *pTempName;
 	int inpos, outpos;
 
+#if defined (__AMIGAOS4__)
+	/* This function does not work on Amiga OS */
+	return;
+#endif
+
 	inpos = 0;
 	pTempName = malloc(FILENAME_MAX);
 	if (!pTempName)
@@ -567,11 +642,11 @@ void File_MakeAbsoluteName(char *pFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Create a valid path name from a possibly invalid name by erasing invalid
-  path parts at the end of the string.
-  pPathName needs to point to a buffer of at least FILENAME_MAX bytes.
-*/
+/**
+ * Create a valid path name from a possibly invalid name by erasing invalid
+ * path parts at the end of the string.
+ * pPathName needs to point to a buffer of at least FILENAME_MAX bytes.
+ */
 void File_MakeValidPathName(char *pPathName)
 {
 	struct stat dirstat;
