@@ -18,7 +18,7 @@
   * rmdir routine, can't remove dir with files in it. (another tos/unix difference)
   * Fix bugs, there are probably a few lurking around in here..
 */
-const char Gemdos_rcsid[] = "Hatari $Id: gemdos.c,v 1.53 2006/07/22 15:49:23 thothy Exp $";
+const char Gemdos_rcsid[] = "Hatari $Id: gemdos.c,v 1.60 2007/01/16 18:42:59 thothy Exp $";
 
 #include <string.h>
 #include <strings.h>
@@ -208,7 +208,7 @@ static const char *pszGemDOSNames[] =
 	"Close",      /*0x3e*/
 	"Read",       /*0x3f*/
 	"Write",      /*0x40*/
-	"UnLink",     /*0x41*/
+	"Fdelete",    /*0x41*/
 	"LSeek",      /*0x42*/
 	"Fattrib",    /*0x43*/
 	"",           /*0x44*/
@@ -247,15 +247,20 @@ typedef struct
     size_t gl_offs;     /* Slots to reserve in `gl_pathv'.  */
 } glob_t;
 
-int glob(const char *pattern, int flags,
+static int glob(const char *pattern, int flags,
 	 int errfunc(const char *epath, int eerrno),
          glob_t *pglob)
 {
+	/* Just a quick hack to keep Hatari happy... */
+	pglob->gl_pathv = malloc(1 * sizeof(void *));
+	pglob->gl_pathv[0] = NULL;
+	pglob->gl_pathc = 0;
 	return 0;
 }
 
-void globfree(glob_t *pglob)
+static void globfree(glob_t *pglob)
 {
+	free(pglob->gl_pathv);
 }
 
 #define mkdir(name,mode) mkdir(name)
@@ -265,29 +270,40 @@ void globfree(glob_t *pglob)
 
 
 /*-------------------------------------------------------*/
-/*
-  Routines to convert time and date to MSDOS format.
-  Originally from the STonX emulator. (cheers!)
-*/
+/**
+ * Routines to convert time and date to MSDOS format.
+ * Originally from the STonX emulator. (cheers!)
+ */
 static Uint16 GemDOS_Time2dos(time_t t)
 {
 	struct tm *x;
-	x = localtime (&t);
+
+	x = localtime(&t);
+	
+	if (x == NULL)
+		return 0;
+
 	return (x->tm_sec>>1)|(x->tm_min<<5)|(x->tm_hour<<11);
 }
 
 static Uint16 GemDOS_Date2dos(time_t t)
 {
 	struct tm *x;
-	x = localtime (&t);
-	return x->tm_mday | ((x->tm_mon+1)<<5) | (((x->tm_year-80 > 0) ? x->tm_year-80 : 0) << 9);
+
+	x = localtime(&t);
+
+	if (x == NULL)
+		return 0;
+
+	return x->tm_mday | ((x->tm_mon+1)<<5)
+	       | (((x->tm_year-80 > 0) ? x->tm_year-80 : 0) << 9);
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Populate a DATETIME structure with file info
-*/
+/**
+ * Populate a DATETIME structure with file info
+ */
 static BOOL GemDOS_GetFileInformation(char *name, DATETIME *DateTime)
 {
 	struct stat filestat;
@@ -297,7 +313,10 @@ static BOOL GemDOS_GetFileInformation(char *name, DATETIME *DateTime)
 	n = stat(name, &filestat);
 	if (n != 0)
 		return FALSE;
-	x = localtime( &filestat.st_mtime );
+
+	x = localtime(&filestat.st_mtime);
+	if (x == NULL)
+		return FALSE;
 
 	DateTime->word1 = 0;
 	DateTime->word2 = 0;
@@ -315,9 +334,9 @@ static BOOL GemDOS_GetFileInformation(char *name, DATETIME *DateTime)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Covert from FindFirstFile/FindNextFile attribute to GemDOS format
-*/
+/**
+ * Covert from FindFirstFile/FindNextFile attribute to GemDOS format
+ */
 static unsigned char GemDOS_ConvertAttribute(mode_t mode)
 {
 	unsigned char Attrib = 0;
@@ -337,19 +356,22 @@ static unsigned char GemDOS_ConvertAttribute(mode_t mode)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Populate the DTA buffer with file info
-*/
+/**
+ * Populate the DTA buffer with file info
+ */
 static BOOL PopulateDTA(char *path, struct dirent *file)
 {
 	char tempstr[MAX_GEMDOS_PATH];
 	struct stat filestat;
 	int n;
 
-	snprintf(tempstr, sizeof(tempstr), "%s/%s", path, file->d_name);
+	snprintf(tempstr, sizeof(tempstr), "%s%c%s", path, PATHSEP, file->d_name);
 	n = stat(tempstr, &filestat);
 	if (n != 0)
+	{
+		perror(tempstr);
 		return FALSE;   /* return on error */
+	}
 
 	if (!pDTA)
 		return FALSE;   /* no DTA pointer set */
@@ -365,9 +387,9 @@ static BOOL PopulateDTA(char *path, struct dirent *file)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Clear a used DTA structure.
-*/
+/**
+ * Clear a used DTA structure.
+ */
 static void ClearInternalDTA(void)
 {
 	int i;
@@ -386,9 +408,9 @@ static void ClearInternalDTA(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Match a file to a dir mask.
-*/
+/**
+ * Match a file to a dir mask.
+ */
 static int match (char *pat, char *name)
 {
 	char *p=pat, *n=name;
@@ -428,10 +450,10 @@ static int match (char *pat, char *name)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Parse directory from sfirst mask
-  - e.g.: input:  "hdemudir/auto/mask*.*" outputs: "hdemudir/auto"
-*/
+/**
+ * Parse directory from sfirst mask
+ * - e.g.: input:  "hdemudir/auto/mask*.*" outputs: "hdemudir/auto"
+ */
 static void fsfirst_dirname(char *string, char *new)
 {
 	int i=0;
@@ -443,7 +465,7 @@ static void fsfirst_dirname(char *string, char *new)
 	while (new[i] != '\0')
 	{
 		if (new[i] == '\\')
-			new[i] = '/';
+			new[i] = PATHSEP;
 		i++;
 	}
 	while (string[i] != '\0')
@@ -451,23 +473,23 @@ static void fsfirst_dirname(char *string, char *new)
 		new[i] = string[i];
 		i++;
 	} /* find end of string */
-	while (new[i] != '/')
+	while (new[i] != PATHSEP)
 		i--; /* find last slash */
 	new[i] = '\0';
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Parse directory mask, e.g. "*.*"
-*/
+/**
+ * Parse directory mask, e.g. "*.*"
+ */
 static void fsfirst_dirmask(char *string, char *new)
 {
 	int i=0, j=0;
 
 	while (string[i] != '\0')
 		i++;   /* go to end of string */
-	while (string[i] != '/')
+	while (string[i] != PATHSEP)
 		i--;   /* find last slash */
 	i++;
 	while (string[i] != '\0')
@@ -477,9 +499,9 @@ static void fsfirst_dirmask(char *string, char *new)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Initialize GemDOS/PC file system
-*/
+/**
+ * Initialize GemDOS/PC file system
+ */
 void GemDOS_Init(void)
 {
 	int i;
@@ -499,9 +521,9 @@ void GemDOS_Init(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Reset GemDOS file system
-*/
+/**
+ * Reset GemDOS file system
+ */
 void GemDOS_Reset(void)
 {
 	int i;
@@ -531,10 +553,10 @@ void GemDOS_Reset(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Initialize a GEMDOS drive.
-  Only 1 emulated drive allowed, as of yet.
-*/
+/**
+ * Initialize a GEMDOS drive.
+ * Only 1 emulated drive allowed, as of yet.
+ */
 void GemDOS_InitDrives(void)
 {
 	int i;
@@ -571,9 +593,9 @@ void GemDOS_InitDrives(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Un-init the GEMDOS drive
-*/
+/**
+ * Un-init the GEMDOS drive
+ */
 void GemDOS_UnInitDrives(void)
 {
 	int i;
@@ -595,9 +617,9 @@ void GemDOS_UnInitDrives(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Save/Restore snapshot of local variables('MemorySnapShot_Store' handles type)
-*/
+/**
+ * Save/Restore snapshot of local variables('MemorySnapShot_Store' handles type)
+ */
 void GemDOS_MemorySnapShot_Capture(BOOL bSave)
 {
 	unsigned int Addr;
@@ -632,9 +654,9 @@ void GemDOS_MemorySnapShot_Capture(BOOL bSave)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Return free PC file handle table index, or -1 if error
-*/
+/**
+ * Return free PC file handle table index, or -1 if error
+ */
 static int GemDOS_FindFreeFileHandle(void)
 {
 	int i;
@@ -651,9 +673,9 @@ static int GemDOS_FindFreeFileHandle(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Check ST handle is within our table range, return TRUE if not
-*/
+/**
+ * Check ST handle is within our table range, return TRUE if not
+ */
 static BOOL GemDOS_IsInvalidFileHandle(int Handle)
 {
 	BOOL bInvalidHandle=FALSE;
@@ -668,10 +690,10 @@ static BOOL GemDOS_IsInvalidFileHandle(int Handle)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Find drive letter from a filename, eg C,D... and return as drive ID(C:2, D:3...)
-  returns the current drive number if none is specified.
-*/
+/**
+ * Find drive letter from a filename, eg C,D... and return as drive ID(C:2, D:3...)
+ * returns the current drive number if none is specified.
+ */
 static int GemDOS_FindDriveNumber(char *pszFileName)
 {
 	/* Does have 'A:' or 'C:' etc.. at start of string? */
@@ -687,9 +709,9 @@ static int GemDOS_FindDriveNumber(char *pszFileName)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Return drive ID(C:2, D:3 etc...) or -1 if not one of our emulation hard-drives
-*/
+/**
+ * Return drive ID(C:2, D:3 etc...) or -1 if not one of our emulation hard-drives
+ */
 static int GemDOS_IsFileNameAHardDrive(char *pszFileName)
 {
 	int DriveLetter;
@@ -712,10 +734,10 @@ static int GemDOS_IsFileNameAHardDrive(char *pszFileName)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Returns the length of the basename of the file passed in parameter
-   (ie the file without extension)
-*/
+/**
+ * Returns the length of the basename of the file passed in parameter
+ *  (ie the file without extension)
+ */
 static int baselen(char *s)
 {
 	char *ext = strchr(s,'.');
@@ -725,9 +747,9 @@ static int baselen(char *s)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Use hard-drive directory, current ST directory and filename to create full path
-*/
+/**
+ * Use hard-drive directory, current ST directory and filename to create full path
+ */
 void GemDOS_CreateHardDriveFileName(int Drive, const char *pszFileName, char *pszDestName)
 {
 	char *s,*start;
@@ -774,7 +796,7 @@ void GemDOS_CreateHardDriveFileName(int Drive, const char *pszFileName, char *ps
 			int len, found, base_len;
 			unsigned int j;
 
-			*start++ = '/';
+			*start++ = PATHSEP;
 			old1 = *start;
 			*start++ = '*';
 			old2 = *start;
@@ -795,7 +817,7 @@ void GemDOS_CreateHardDriveFileName(int Drive, const char *pszFileName, char *ps
 						strncasecmp(globbuf.gl_pathv[j],pszDestName,len)))
 				{
 					/* we found a matching name... */
-					sprintf(dest,"%s%c%s",globbuf.gl_pathv[j],'/',s+1);
+					sprintf(dest,"%s%c%s",globbuf.gl_pathv[j], PATHSEP,s+1);
 					strcpy(pszDestName,dest);
 					j = globbuf.gl_pathc;
 					found = 1;
@@ -815,7 +837,7 @@ void GemDOS_CreateHardDriveFileName(int Drive, const char *pszFileName, char *ps
 					if (!strncasecmp(globbuf.gl_pathv[j],pszDestName,len))
 					{
 						/* we found a matching name... */
-						sprintf(dest,"%s%c%s",globbuf.gl_pathv[j],'/',s+1);
+						sprintf(dest,"%s%c%s",globbuf.gl_pathv[j], PATHSEP,s+1);
 						strcpy(pszDestName,dest);
 						j = globbuf.gl_pathc;
 						found = 1;
@@ -824,7 +846,7 @@ void GemDOS_CreateHardDriveFileName(int Drive, const char *pszFileName, char *ps
 				globfree(&globbuf);
 				if (!found)
 				{           /* really nothing ! */
-					*s = '/';
+					*s = PATHSEP;
 					fprintf(stderr,"no path for %s\n",pszDestName);
 				}
 			}
@@ -833,11 +855,11 @@ void GemDOS_CreateHardDriveFileName(int Drive, const char *pszFileName, char *ps
 	}
 
 	if (!start)
-		start = strrchr(pszDestName,'/'); // path already converted ?
+		start = strrchr(pszDestName, PATHSEP); // path already converted ?
 
 	if (start)
 	{
-		*start++ = '/';     /* in case there was only 1 anti slash */
+		*start++ = PATHSEP;     /* in case there was only 1 anti slash */
 		if (*start && !strchr(start,'?') && !strchr(start,'*'))
 		{
 			/* We have a complete name after the path, not a wildcard */
@@ -889,10 +911,10 @@ void GemDOS_CreateHardDriveFileName(int Drive, const char *pszFileName, char *ps
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Cauxin
-  Call 0x3
-*/
+/**
+ * GEMDOS Cauxin
+ * Call 0x3
+ */
 #if 0
 static BOOL GemDOS_Cauxin(Uint32 Params)
 {
@@ -911,10 +933,10 @@ static BOOL GemDOS_Cauxin(Uint32 Params)
 #endif
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Cauxout
-  Call 0x4
-*/
+/**
+ * GEMDOS Cauxout
+ * Call 0x4
+ */
 #if 0
 static BOOL GemDOS_Cauxout(Uint32 Params)
 {
@@ -929,10 +951,10 @@ static BOOL GemDOS_Cauxout(Uint32 Params)
 #endif
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Cprnout
-  Call 0x5
-*/
+/**
+ * GEMDOS Cprnout
+ * Call 0x5
+ */
 static BOOL GemDOS_Cprnout(Uint32 Params)
 {
 	unsigned char c;
@@ -946,10 +968,10 @@ static BOOL GemDOS_Cprnout(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Set drive (0=A,1=B,2=C etc...)
-  Call 0xE
-*/
+/**
+ * GEMDOS Set drive (0=A,1=B,2=C etc...)
+ * Call 0xE
+ */
 static BOOL GemDOS_SetDrv(Uint32 Params)
 {
 	/* Read details from stack for our own use */
@@ -960,10 +982,10 @@ static BOOL GemDOS_SetDrv(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Cprnos
-  Call 0x11
-*/
+/**
+ * GEMDOS Cprnos
+ * Call 0x11
+ */
 static BOOL GemDOS_Cprnos(Uint32 Params)
 {
 	/* pritner status depends if printing is enabled or not... */
@@ -976,10 +998,10 @@ static BOOL GemDOS_Cprnos(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Cauxis
-  Call 0x12
-*/
+/**
+ * GEMDOS Cauxis
+ * Call 0x12
+ */
 #if 0
 static BOOL GemDOS_Cauxis(Uint32 Params)
 {
@@ -994,10 +1016,10 @@ static BOOL GemDOS_Cauxis(Uint32 Params)
 #endif
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Cauxos
-  Call 0x13
-*/
+/**
+ * GEMDOS Cauxos
+ * Call 0x13
+ */
 #if 0
 static BOOL GemDOS_Cauxos(Uint32 Params)
 {
@@ -1008,10 +1030,10 @@ static BOOL GemDOS_Cauxos(Uint32 Params)
 #endif
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Set Disk Transfer Address (DTA)
-  Call 0x1A
-*/
+/**
+ * GEMDOS Set Disk Transfer Address (DTA)
+ * Call 0x1A
+ */
 static BOOL GemDOS_SetDTA(Uint32 Params)
 {
 	/* Look up on stack to find where DTA is! Store as PC pointer */
@@ -1021,10 +1043,10 @@ static BOOL GemDOS_SetDTA(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Dfree Free disk space.
-  Call 0x39
-*/
+/**
+ * GEMDOS Dfree Free disk space.
+ * Call 0x39
+ */
 static BOOL GemDOS_DFree(Uint32 Params)
 {
 	int Drive;
@@ -1049,13 +1071,12 @@ static BOOL GemDOS_DFree(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS MkDir
-  Call 0x39
-*/
+/**
+ * GEMDOS MkDir
+ * Call 0x39
+ */
 static BOOL GemDOS_MkDir(Uint32 Params)
 {
-	char szDirPath[MAX_GEMDOS_PATH];
 	char *pDirName;
 	int Drive;
 
@@ -1066,28 +1087,37 @@ static BOOL GemDOS_MkDir(Uint32 Params)
 
 	if (ISHARDDRIVE(Drive))
 	{
+		char *psDirPath;
+		psDirPath = malloc(FILENAME_MAX);
+		if (!psDirPath)
+		{
+			perror("GemDOS_MkDir");
+			Regs[REG_D0] = GEMDOS_ENSMEM;
+			return TRUE;
+		}
+
 		/* Copy old directory, as if calls fails keep this one */
-		GemDOS_CreateHardDriveFileName(Drive,pDirName,szDirPath);
+		GemDOS_CreateHardDriveFileName(Drive, pDirName, psDirPath);
 
 		/* Attempt to make directory */
-		if ( mkdir(szDirPath, 0755)==0 )
+		if (mkdir(psDirPath, 0755) == 0)
 			Regs[REG_D0] = GEMDOS_EOK;
 		else
 			Regs[REG_D0] = GEMDOS_EACCDN;        /* Access denied */
 
+		free(psDirPath);
 		return TRUE;
 	}
 	return FALSE;
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS RmDir
-  Call 0x3A
-*/
+/**
+ * GEMDOS RmDir
+ * Call 0x3A
+ */
 static BOOL GemDOS_RmDir(Uint32 Params)
 {
-	char szDirPath[MAX_GEMDOS_PATH];
 	char *pDirName;
 	int Drive;
 
@@ -1096,15 +1126,25 @@ static BOOL GemDOS_RmDir(Uint32 Params)
 	Drive = GemDOS_IsFileNameAHardDrive(pDirName);
 	if (ISHARDDRIVE(Drive))
 	{
+		char *psDirPath;
+		psDirPath = malloc(FILENAME_MAX);
+		if (!psDirPath)
+		{
+			perror("GemDOS_RmDir");
+			Regs[REG_D0] = GEMDOS_ENSMEM;
+			return TRUE;
+		}
+
 		/* Copy old directory, as if calls fails keep this one */
-		GemDOS_CreateHardDriveFileName(Drive,pDirName,szDirPath);
+		GemDOS_CreateHardDriveFileName(Drive, pDirName, psDirPath);
 
 		/* Attempt to make directory */
-		if ( rmdir(szDirPath)==0 )
+		if (rmdir(psDirPath) == 0)
 			Regs[REG_D0] = GEMDOS_EOK;
 		else
 			Regs[REG_D0] = GEMDOS_EACCDN;        /* Access denied */
 
+		free(psDirPath);
 		return TRUE;
 	}
 	return FALSE;
@@ -1112,10 +1152,10 @@ static BOOL GemDOS_RmDir(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS ChDir
-  Call 0x3B
-*/
+/**
+ * GEMDOS ChDir
+ * Call 0x3B
+ */
 static BOOL GemDOS_ChDir(Uint32 Params)
 {
 	char *pDirName;
@@ -1168,10 +1208,10 @@ static BOOL GemDOS_ChDir(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Create file
-  Call 0x3C
-*/
+/**
+ * GEMDOS Create file
+ * Call 0x3C
+ */
 static BOOL GemDOS_Create(Uint32 Params)
 {
 	char szActualFileName[MAX_GEMDOS_PATH];
@@ -1230,10 +1270,10 @@ static BOOL GemDOS_Create(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Open file
-  Call 0x3D
-*/
+/**
+ * GEMDOS Open file
+ * Call 0x3D
+ */
 static BOOL GemDOS_Open(Uint32 Params)
 {
 	char szActualFileName[MAX_GEMDOS_PATH];
@@ -1275,6 +1315,10 @@ static BOOL GemDOS_Open(Uint32 Params)
 			Regs[REG_D0] = Index+BASE_FILEHANDLE;  /* Return valid ST file handle from range 6 to 45! (ours start from 0) */
 			return TRUE;
 		}
+
+		if (Mode != 1 && errno == EACCES)
+			Log_Printf(LOG_DEBUG, "Missing permission to read file '%s'\n", szActualFileName);
+
 		Regs[REG_D0] = GEMDOS_EFILNF;     /* File not found/ error opening */
 		return TRUE;
 	}
@@ -1283,10 +1327,10 @@ static BOOL GemDOS_Open(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Close file
-  Call 0x3E
-*/
+/**
+ * GEMDOS Close file
+ * Call 0x3E
+ */
 static BOOL GemDOS_Close(Uint32 Params)
 {
 	int Handle;
@@ -1312,10 +1356,10 @@ static BOOL GemDOS_Close(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Read file
-  Call 0x3F
-*/
+/**
+ * GEMDOS Read file
+ * Call 0x3F
+ */
 static BOOL GemDOS_Read(Uint32 Params)
 {
 	char *pBuffer;
@@ -1369,10 +1413,10 @@ static BOOL GemDOS_Read(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Write file
-  Call 0x40
-*/
+/**
+ * GEMDOS Write file
+ * Call 0x40
+ */
 static BOOL GemDOS_Write(Uint32 Params)
 {
 	char *pBuffer;
@@ -1406,14 +1450,13 @@ static BOOL GemDOS_Write(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS UnLink (Delete) file
-  Call 0x41
-*/
-static BOOL GemDOS_UnLink(Uint32 Params)
+/**
+ * GEMDOS Delete file
+ * Call 0x41
+ */
+static BOOL GemDOS_FDelete(Uint32 Params)
 {
 #ifdef ENABLE_SAVING
-	char szActualFileName[MAX_GEMDOS_PATH];
 	char *pszFileName;
 	int Drive;
 
@@ -1422,15 +1465,25 @@ static BOOL GemDOS_UnLink(Uint32 Params)
 	Drive = GemDOS_IsFileNameAHardDrive(pszFileName);
 	if (ISHARDDRIVE(Drive))
 	{
+		char *psActualFileName;
+		psActualFileName = malloc(FILENAME_MAX);
+		if (!psActualFileName)
+		{
+			perror("GemDOS_FDelete");
+			Regs[REG_D0] = GEMDOS_ENSMEM;
+			return TRUE;
+		}
+
 		/* And convert to hard drive filename */
-		GemDOS_CreateHardDriveFileName(Drive,pszFileName,szActualFileName);
+		GemDOS_CreateHardDriveFileName(Drive, pszFileName, psActualFileName);
 
 		/* Now delete file?? */
-		if ( unlink(szActualFileName)==0 )
+		if (unlink(psActualFileName) == 0)
 			Regs[REG_D0] = GEMDOS_EOK;          /* OK */
 		else
 			Regs[REG_D0] = GEMDOS_EFILNF;       /* File not found */
 
+		free(psActualFileName);
 		return TRUE;
 	}
 #endif
@@ -1439,10 +1492,10 @@ static BOOL GemDOS_UnLink(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS File seek
-  Call 0x42
-*/
+/**
+ * GEMDOS File seek
+ * Call 0x42
+ */
 static BOOL GemDOS_LSeek(Uint32 Params)
 {
 	long Offset;
@@ -1470,10 +1523,10 @@ static BOOL GemDOS_LSeek(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Fattrib() - get or set file attributes
-  Call 0x43
-*/
+/**
+ * GEMDOS Fattrib() - get or set file attributes
+ * Call 0x43
+ */
 static BOOL GemDOS_Fattrib(Uint32 Params)
 {
 	char sActualFileName[MAX_GEMDOS_PATH];
@@ -1524,10 +1577,10 @@ static BOOL GemDOS_Fattrib(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Get Directory
-  Call 0x47
-*/
+/**
+ * GEMDOS Get Directory
+ * Call 0x47
+ */
 static int GemDOS_GetDir(Uint32 Params)
 {
 	Uint32 Address;
@@ -1549,7 +1602,7 @@ static int GemDOS_GetDir(Uint32 Params)
 		for (i = 0; i <= len; i++)
 		{
 			c = path[i];
-			STMemory_WriteByte(Address+i, (c=='/' ? '\\' : c) );
+			STMemory_WriteByte(Address+i, (c==PATHSEP ? '\\' : c) );
 		}
 #if GEMDOS_FILE_DEBUG
 		Log_Printf(LOG_DEBUG, "GemDOS_GetDir (%d) = %s\n", Drive, path);
@@ -1561,11 +1614,11 @@ static int GemDOS_GetDir(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  PExec Load And Go - Redirect to cart' routine at address 0xFA1000
- 
-  If loading from hard-drive(ie drive ID 2 or more) set condition codes to run own GEMDos routines
-*/
+/**
+ * PExec Load And Go - Redirect to cart' routine at address 0xFA1000
+ *
+ * If loading from hard-drive(ie drive ID 2 or more) set condition codes to run own GEMDos routines
+ */
 static int GemDOS_Pexec_LoadAndGo(Uint32 Params)
 {
 	/* add multiple disk support here too */
@@ -1582,9 +1635,9 @@ static int GemDOS_Pexec_LoadAndGo(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  PExec Load But Don't Go - Redirect to cart' routine at address 0xFA1000
-*/
+/**
+ * PExec Load But Don't Go - Redirect to cart' routine at address 0xFA1000
+ */
 static int GemDOS_Pexec_LoadDontGo(Uint32 Params)
 {
 	/* Hard-drive? */
@@ -1598,10 +1651,10 @@ static int GemDOS_Pexec_LoadDontGo(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS PExec handler
-  Call 0x4B
-*/
+/**
+ * GEMDOS PExec handler
+ * Call 0x4B
+ */
 static int GemDOS_Pexec(Uint32 Params)
 {
 	Uint16 Mode;
@@ -1636,10 +1689,10 @@ static int GemDOS_Pexec(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Search Next
-  Call 0x4F
-*/
+/**
+ * GEMDOS Search Next
+ * Call 0x4F
+ */
 static BOOL GemDOS_SNext(void)
 {
 	struct dirent **temp;
@@ -1664,7 +1717,7 @@ static BOOL GemDOS_SNext(void)
 		temp = InternalDTAs[Index].found;
 		if (PopulateDTA(InternalDTAs[Index].path, temp[InternalDTAs[Index].centry++]) == FALSE)
 		{
-			Log_Printf(LOG_ERROR, "\tError setting DTA.\n");
+			Log_Printf(LOG_ERROR, "GemDOS_SNext: Error setting DTA.\n");
 			return TRUE;
 		}
 
@@ -1677,10 +1730,10 @@ static BOOL GemDOS_SNext(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Find first file
-  Call 0x4E
-*/
+/**
+ * GEMDOS Find first file
+ * Call 0x4E
+ */
 static BOOL GemDOS_SFirst(Uint32 Params)
 {
 	char szActualFileName[MAX_GEMDOS_PATH];
@@ -1784,10 +1837,10 @@ static BOOL GemDOS_SFirst(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS Rename
-  Call 0x56
-*/
+/**
+ * GEMDOS Rename
+ * Call 0x56
+ */
 static BOOL GemDOS_Rename(Uint32 Params)
 {
 	char *pszNewFileName,*pszOldFileName;
@@ -1818,10 +1871,10 @@ static BOOL GemDOS_Rename(Uint32 Params)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  GEMDOS GSDToF
-  Call 0x57
-*/
+/**
+ * GEMDOS GSDToF
+ * Call 0x57
+ */
 static BOOL GemDOS_GSDToF(Uint32 Params)
 {
 	DATETIME DateTime;
@@ -1860,14 +1913,14 @@ static BOOL GemDOS_GSDToF(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Run GEMDos call, and re-direct if need to. Used to handle hard disk emulation etc...
-  This sets the condition codes (in SR), which are used in the 'cart_asm.s' program to
-  decide if we need to run old GEM vector, or PExec or nothing.
- 
-  This method keeps the stack and other states consistant with the original ST which is very important
-  for the PExec call and maximum compatibility through-out
-*/
+/**
+ * Run GEMDos call, and re-direct if need to. Used to handle hard disk emulation etc...
+ * This sets the condition codes (in SR), which are used in the 'cart_asm.s' program to
+ * decide if we need to run old GEM vector, or PExec or nothing.
+ * 
+ * This method keeps the stack and other states consistant with the original ST which is very important
+ * for the PExec call and maximum compatibility through-out
+ */
 void GemDOS_OpCode(void)
 {
 	unsigned short int GemDOSCall,CallingSReg;
@@ -1983,7 +2036,7 @@ void GemDOS_OpCode(void)
 			RunOld = FALSE;
 		break;
 	 case 0x41:
-		if (GemDOS_UnLink(Params))
+		if (GemDOS_FDelete(Params))
 			RunOld = FALSE;
 		break;
 	 case 0x42:
@@ -2035,10 +2088,10 @@ void GemDOS_OpCode(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  GemDOS_Boot - routine called on the first occurence of the gemdos opcode.
-  (this should be in the cartridge bootrom)
-  Sets up our gemdos handler (or, if we don't need one, just turn off keyclicks)
+/**
+ * GemDOS_Boot - routine called on the first occurence of the gemdos opcode.
+ * (this should be in the cartridge bootrom)
+ * Sets up our gemdos handler (or, if we don't need one, just turn off keyclicks)
  */
 void GemDOS_Boot(void)
 {
