@@ -6,7 +6,7 @@
 
   Device (Printer etc.) setup dialog
 */
-const char DlgDevice_rcsid[] = "Hatari $Id: dlgDevice.c,v 1.9 2006/08/14 18:32:45 thothy Exp $";
+const char DlgDevice_rcsid[] = "Hatari $Id: dlgDevice.c,v 1.11 2007/01/13 11:57:41 thothy Exp $";
 
 #include "main.h"
 #include "configuration.h"
@@ -63,7 +63,7 @@ static SGOBJ devicedlg[] =
  	{ SGBUTTON, 0, 0, 42,17, 8,1, "Browse" },
  	{ SGTEXT, 0, 0, 3,18, 46,1, dlgMidiOutName },
 
- 	{ SGBUTTON, 0, 0, 16,20, 20,1, "Back to main menu" },
+ 	{ SGBUTTON, SG_DEFAULT, 0, 16,20, 20,1, "Back to main menu" },
 	{ -1, 0, 0, 0,0, 0,0, NULL }
 };
 
@@ -161,7 +161,8 @@ void Dialog_DeviceDlg(void)
 			break;
 		}
 	}
-	while (but != DEVDLG_EXIT && but != SDLGUI_QUIT && !bQuitProgram);
+	while (but != DEVDLG_EXIT && but != SDLGUI_QUIT
+	       && but != SDLGUI_ERROR && !bQuitProgram);
 
 	/* Read values from dialog */
 	DialogParams.Printer.bEnablePrinting = (devicedlg[DEVDLG_PRNENABLE].state & SG_SELECTED);
