@@ -6,7 +6,7 @@
 
   The main dialog.
 */
-const char DlgMain_rcsid[] = "Hatari $Id: dlgMain.c,v 1.10 2006/07/03 20:36:28 clafou Exp $";
+const char DlgMain_rcsid[] = "Hatari $Id: dlgMain.c,v 1.12 2007/01/13 11:57:41 thothy Exp $";
 
 #include "main.h"
 #include "configuration.h"
@@ -53,7 +53,7 @@ static SGOBJ maindlg[] =
   { SGBUTTON, 0, 0, 19,15, 14,1, "Save config." },
   { SGRADIOBUT, 0, 0, 2,18, 10,1, "No Reset" },
   { SGRADIOBUT, 0, 0, 2,20, 10,1, "Reset ST" },
-  { SGBUTTON, 0, 0, 14,18, 8,3, "Okay" },
+  { SGBUTTON, SG_DEFAULT, 0, 14,18, 8,3, "Okay" },
   { SGBUTTON, 0, 0, 25,20, 8,1, "Cancel" },
   { SGBUTTON, 0, 0, 25,18, 8,1, "Quit" },
   { -1, 0, 0, 0,0, 0,0, NULL }
@@ -128,7 +128,8 @@ int Dialog_MainDlg(BOOL *bReset)
         break;
     }
   }
-  while (retbut!=MAINDLG_OK && retbut!=MAINDLG_CANCEL && retbut!=SDLGUI_QUIT && !bQuitProgram);
+  while (retbut!=MAINDLG_OK && retbut!=MAINDLG_CANCEL && retbut!=SDLGUI_QUIT
+         && retbut!=SDLGUI_ERROR && !bQuitProgram);
 
 
   if( maindlg[MAINDLG_RESET].state & SG_SELECTED )
