@@ -6,7 +6,7 @@
 
   A tiny graphical user interface for Hatari.
 */
-const char SDLGui_rcsid[] = "Hatari $Id: sdlgui.c,v 1.13 2006/02/09 21:55:44 eerot Exp $";
+const char SDLGui_rcsid[] = "Hatari $Id: sdlgui.c,v 1.15 2007/01/13 11:57:41 thothy Exp $";
 
 #include <SDL.h>
 #include <ctype.h>
@@ -564,6 +564,25 @@ static int SDLGui_FindObj(const SGOBJ *dlg, int fx, int fy)
 }
 
 
+/*-----------------------------------------------------------------------*/
+/*
+  Search the default button in a dialog.
+*/
+static int SDLGui_SearchDefaultButton(const SGOBJ *dlg)
+{
+  int i = 0;
+
+  while (dlg[i].type != -1)
+  {
+    if (dlg[i].flags & SG_DEFAULT)
+      return i;
+    i++;
+  }
+
+  return 0;
+}
+
+
 /*-----------------------------------------------------------------------*/
 /*
   Show and process a dialog. Returns the button number that has been
@@ -581,7 +600,13 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
   Uint32 grey;
   SDL_Surface *pBgSurface;
   SDL_Rect dlgrect, bgrect;
-  
+
+  if (pSdlGuiScrn->h / fontheight < dlg[0].h)
+  {
+    fprintf(stderr, "Screen size too small for dialog!\n");
+    return SDLGUI_ERROR;
+  }
+
   grey = SDL_MapRGB(pSdlGuiScrn->format,192,192,192);
 
   dlgrect.x = dlg[0].x * fontwidth;
@@ -750,6 +775,18 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
         case SDL_MOUSEMOTION:
           break;
 
+        case SDL_KEYDOWN:                     /* Key pressed */
+          if (sdlEvent.key.keysym.sym == SDLK_RETURN
+              || sdlEvent.key.keysym.sym == SDLK_KP_ENTER)
+          {
+            retbutton = SDLGui_SearchDefaultButton(dlg);
+          }
+          else if (pEventOut)
+          {
+            retbutton = SDLGUI_UNKNOWNEVENT;
+          }
+          break;
+
         default:
           if (pEventOut)
             retbutton = SDLGUI_UNKNOWNEVENT;
