@@ -4,7 +4,7 @@
   This file is distributed under the GNU Public License, version 2 or at
   your option any later version. Read the file gpl.txt for details.
 
-  This file contains definitios used for hardware-level
+  This file contains definitions which are used for hardware-level
   harddrive emulation.
 */
 
@@ -33,19 +33,29 @@
 #define HD_WRITE_SECTOR    0x0A               /* Write sector */
 
 /* other codes */
+#define HD_FORMAT_DRIVE    0x04               /* Format the whole drive */
 #define HD_SEEK            0x0B               /* Seek */
 #define HD_CORRECTION      0x0D               /* Correction */
 #define HD_INQUIRY         0x12               /* Inquiry */
+#define HD_MODESELECT      0x15               /* Mode select */
 #define HD_MODESENSE       0x1A               /* Mode sense */
 #define HD_REQ_SENSE       0x03               /* Request sense */
 #define HD_SHIP            0x1B               /* Ship drive */
 
-#define HD_STATUS_OK          0               /* OK return status */
-#define HD_STATUS_NODRIVE  0x25               /* Invalid drive */
-#define HD_STATUS_OPCODE   0x20               /* Opcode not supported */
+/* Status codes */
+#define HD_STATUS_OK       0x00
+#define HD_STATUS_ERROR    0x02
+#define HD_STATUS_BUSY     0x08
+
+/* Error codes for REQUEST SENSE: */
+#define HD_REQSENS_OK      0x00               /* OK return status */
+#define HD_REQSENS_OPCODE  0x20               /* Opcode not supported */
+#define HD_REQSENS_INVADDR 0x21               /* Invalid block address */
+#define HD_REQSENS_INVARG  0x24               /* Invalid argument */
+#define HD_REQSENS_NODRIVE 0x25               /* Invalid drive */
+
+#define ACSI_EMU_ON        bAcsiEmuOn         /* Do we have HDC emulation? */
 
-#define ACSI_EMU_ON         (nPartitions != 0) 
-/* do we have hdc emulation */
 /* 
    Structure representing an ACSI command block.
 */
@@ -59,6 +69,7 @@ extern FILE *hd_image_file;
 extern HDCOMMAND HDCCommand;
 extern short int HDCSectorCount;
 extern int nPartitions;
+extern BOOL bAcsiEmuOn;
 
 extern BOOL HDC_Init(char *filename);
 extern void HDC_UnInit(void);
