@@ -8,10 +8,10 @@
 #ifndef HATARI_MAIN_H
 #define HATARI_MAIN_H
 
-typedef signed char BOOL;
 
-#define PROG_NAME      "Hatari v0.90" /* Name, version for window title */
-#define PROG_VERSION   "v0.90"
+/* Name and version for window title: */
+/* #define PROG_NAME "Hatari CVS (" __DATE__ ")" */
+#define PROG_NAME "Hatari v0.95"
 
 
 #include <stdio.h>
@@ -23,6 +23,8 @@ typedef signed char BOOL;
 #include <SDL_types.h>
 
 
+typedef signed char BOOL;
+
 #ifndef FALSE
 #define FALSE 0
 #define TRUE (!0)
