@@ -15,7 +15,6 @@
 extern BOOL bWriteEnvelopeFreq,bWriteChannelAAmp,bWriteChannelBAmp,bWriteChannelCAmp;
 extern BOOL bEnvelopeFreqFlag;
 extern Sint8 MixBuffer[MIXBUFFER_SIZE];
-extern int SoundCycles;
 extern int nGeneratedSamples;
 
 extern void Sound_Init(void);
@@ -24,7 +23,6 @@ extern void Sound_ResetBufferIndex(void);
 extern void Sound_MemorySnapShot_Capture(BOOL bSave);
 extern void Sound_Update(void);
 extern void Sound_Update_VBL(void);
-extern void Sound_UpdateFromAudioCallBack(void);
 extern BOOL Sound_BeginRecording(char *pszCaptureFileName);
 extern void Sound_EndRecording(void);
 extern BOOL Sound_AreWeRecording(void);
