@@ -50,7 +50,7 @@
 #define SCREEN_HEIGHT_HBL  200          /* This is usually the height of the screen */
 
 /* FIXME: SCREEN_START_CYCLE should rather be 52 or so, but this breaks a lot of other things at the moment... */
-#define SCREEN_START_CYCLE  96          /* Cycle first normal pixel appears on */
+#define SCREEN_START_CYCLE  56          /* Cycle first normal pixel appears on */
 
 /* Bytes for opened left and right border: */
 #define BORDERBYTES_LEFT  26
@@ -58,9 +58,9 @@
 
 /* Legacy defines: */
 #define CYCLES_PER_FRAME    (nScanlinesPerFrame*nCyclesPerLine)  /* Cycles per VBL @ 50fps = 160256 */
-#define CYCLES_HBL          (nCyclesPerLine+96)   /* Cycles for first HBL - very inaccurate on ST */
 
 
+extern BOOL bUseSTShifter;
 extern BOOL bUseHighRes;
 extern int nVBLs,nHBL;
 extern int nStartHBL, nEndHBL;
@@ -78,6 +78,8 @@ extern int nCyclesPerLine;
 
 extern void Video_Reset(void);
 extern void Video_MemorySnapShot_Capture(BOOL bSave);
+extern void Video_GetTTRes(int *width, int *height, int *bpp);
+extern void Video_StartInterrupts(void);
 extern void Video_InterruptHandler_VBL(void);
 extern void Video_InterruptHandler_EndLine(void);
 extern void Video_InterruptHandler_HBL(void);
@@ -114,5 +116,8 @@ extern void Video_Color14_WriteWord(void);
 extern void Video_Color15_WriteWord(void);
 extern void Video_ShifterMode_WriteByte(void);
 extern void Video_HorScroll_Write(void);
+extern void Video_TTShiftMode_WriteWord(void);
+extern void Video_TTColorRegs_WriteWord(void);
+extern void Video_TTColorSTRegs_WriteWord(void);
 
 #endif  /* HATARI_VIDEO_H */
