@@ -9,66 +9,45 @@
   When Hatari runs, it can output information, debug, warning and error texts
   to the error log file and/or displays them in alert dialog boxes.
 */
-const char Log_rcsid[] = "Hatari $Id: log.c,v 1.3 2006/02/08 22:49:27 eerot Exp $";
+const char Log_rcsid[] = "Hatari $Id: log.c,v 1.5 2007/02/25 21:20:10 eerot Exp $";
 
 #include <stdio.h>
 #include <stdarg.h>
-#include <errno.h>
 
 #include "main.h"
 #include "configuration.h"
 #include "dialog.h"
 #include "log.h"
 #include "screen.h"
-
+#include "file.h"
 
 static FILE *hLogFile = NULL;
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Initialize the logging functions (open the log file etc.).
-*/
+/**
+ * Initialize the logging functions (open the log file etc.).
+ */
 void Log_Init(void)
 {
-	/* First check for "stdout" and "stderr" which are special */
-	if (!strcmp(ConfigureParams.Log.sLogFileName, "stdout"))
-	{
-		hLogFile = stdout;
-	}
-	else if (!strcmp(ConfigureParams.Log.sLogFileName, "stderr"))
-	{
-		hLogFile = stderr;
-	}
-	else
-	{
-		/* Open a normal log file */
-		hLogFile = fopen(ConfigureParams.Log.sLogFileName, "w");
-		if (!hLogFile)
-			fprintf(stderr, "Can't open log file %s: %s\n",
-			        ConfigureParams.Log.sLogFileName, strerror(errno));
-	}
+	hLogFile = File_Open(ConfigureParams.Log.sLogFileName, "w");
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Un-Initialize - close error log file etc.
-*/
+/**
+ * Un-Initialize - close error log file etc.
+ */
 void Log_UnInit(void)
 {
-	if (hLogFile && hLogFile != stdout && hLogFile != stderr)
-	{
-		fclose(hLogFile);
-	}
-	hLogFile = NULL;
+	hLogFile = File_Close(hLogFile);
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Output string to log file
-*/
+/**
+ * Output string to log file
+ */
 void Log_Printf(LOGTYPE nType, const char *psFormat, ...)
 {
 	va_list argptr;
@@ -83,9 +62,9 @@ void Log_Printf(LOGTYPE nType, const char *psFormat, ...)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Show logging alert dialog box and output string to log file
-*/
+/**
+ * Show logging alert dialog box and output string to log file
+ */
 void Log_AlertDlg(LOGTYPE nType, const char *psFormat, ...)
 {
 	va_list argptr;
