@@ -8,7 +8,7 @@
   few OpCode's such as Line-F and Line-A. In Hatari it has mainly become a
   wrapper between the WinSTon sources and the UAE CPU code.
 */
-const char M68000_rcsid[] = "Hatari $Id: m68000.c,v 1.36 2006/06/26 23:03:09 thothy Exp $";
+const char M68000_rcsid[] = "Hatari $Id: m68000.c,v 1.39 2007/01/28 22:41:56 thothy Exp $";
 
 #include "main.h"
 #include "bios.h"
@@ -24,9 +24,6 @@ const char M68000_rcsid[] = "Hatari $Id: m68000.c,v 1.36 2006/06/26 23:03:09 tho
 #include "xbios.h"
 
 
-void (*PendingInterruptFunction)(void);
-short int PendingInterruptCount;
-
 Uint32 BusErrorAddress;          /* Stores the offending address for bus-/address errors */
 Uint32 BusErrorPC;               /* Value of the PC when bus error occurs */
 BOOL bBusErrorReadWrite;         /* 0 for write error, 1 for read error */
@@ -35,9 +32,9 @@ int nWaitStateCycles;            /* Used to emulate the wait state cycles of cer
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Reset CPU 68000 variables
-*/
+/**
+ * Reset CPU 68000 variables
+ */
 void M68000_Reset(BOOL bCold)
 {
   int i;
@@ -55,33 +52,18 @@ void M68000_Reset(BOOL bCold)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Save/Restore snapshot of CPU variables ('MemorySnapShot_Store' handles type)
-*/
+/**
+ * Save/Restore snapshot of CPU variables ('MemorySnapShot_Store' handles type)
+ */
 void M68000_MemorySnapShot_Capture(BOOL bSave)
 {
-  int ID;
   Uint32 savepc;
 
   /* Save/Restore details */
   MemorySnapShot_Store(Regs,sizeof(Regs));
   MemorySnapShot_Store(&STRamEnd,sizeof(STRamEnd));
-  MemorySnapShot_Store(&PendingInterruptCount,sizeof(PendingInterruptCount));
-  if (bSave)
-  {
-    /* Convert function to ID */
-    ID = Int_HandlerFunctionToID(PendingInterruptFunction);
-    MemorySnapShot_Store(&ID,sizeof(int));
-  }
-  else
-  {
-    /* Convert ID to function */
-    MemorySnapShot_Store(&ID,sizeof(int));
-    PendingInterruptFunction = Int_IDToHandlerFunction(ID);
-  }
 
   /* For the UAE CPU core: */
-  MemorySnapShot_Store(&cpu_level, sizeof(cpu_level));          /* MODEL */
   MemorySnapShot_Store(&address_space_24, sizeof(address_space_24));
   MemorySnapShot_Store(&regs.regs[0], sizeof(regs.regs));       /* D0-D7 A0-A6 */
   if (bSave)
@@ -142,10 +124,10 @@ void M68000_MemorySnapShot_Capture(BOOL bSave)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  BUSERROR - Access outside valid memory range.
-  Use bReadWrite = 0 for write errors and bReadWrite = 1 for read errors!
-*/
+/**
+ * BUSERROR - Access outside valid memory range.
+ * Use bReadWrite = 0 for write errors and bReadWrite = 1 for read errors!
+ */
 void M68000_BusError(Uint32 addr, BOOL bReadWrite)
 {
   /* FIXME: In prefetch mode, m68k_getpc() seems already to point to the next instruction */
@@ -164,9 +146,9 @@ void M68000_BusError(Uint32 addr, BOOL bReadWrite)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Exception handler
-*/
+/**
+ * Exception handler
+ */
 void M68000_Exception(Uint32 ExceptionVector)
 {
   int exceptionNr = ExceptionVector/4;
@@ -212,10 +194,10 @@ void M68000_Exception(Uint32 ExceptionVector)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  There seem to be wait states when a program accesses certain hardware
-  registers on the ST. Use this function to simulate these wait states.
-*/
+/**
+ * There seem to be wait states when a program accesses certain hardware
+ * registers on the ST. Use this function to simulate these wait states.
+ */
 void M68000_WaitState(int nCycles)
 {
   set_special(SPCFLAG_EXTRA_CYCLES);
