@@ -6,7 +6,7 @@
 
   Main initialization and event handling routines.
 */
-const char Opt_rcsid[] = "Hatari $Id: main.c,v 1.86 2006/08/02 07:45:00 thothy Exp $";
+const char Opt_rcsid[] = "Hatari $Id: main.c,v 1.100 2007/01/30 20:33:49 eerot Exp $";
 
 #include <time.h>
 #include <unistd.h>
@@ -31,6 +31,7 @@ const char Opt_rcsid[] = "Hatari $Id: main.c,v 1.86 2006/08/02 07:45:00 thothy E
 #include "memorySnapShot.h"
 #include "misc.h"
 #include "midi.h"
+#include "nvram.h"
 #include "printer.h"
 #include "reset.h"
 #include "rs232.h"
@@ -47,6 +48,11 @@ const char Opt_rcsid[] = "Hatari $Id: main.c,v 1.86 2006/08/02 07:45:00 thothy E
 
 #include "uae-cpu/hatari-glue.h"
 
+#include "falcon/hostscreen.h"
+#if ENABLE_DSP_EMU
+#include "falcon/dsp.h"
+#endif
+
 
 BOOL bQuitProgram = FALSE;                /* Flag to quit program cleanly */
 BOOL bEnableDebug = FALSE;                /* Enable debug UI? */
@@ -58,9 +64,9 @@ static BOOL bIgnoreNextMouseMotion = FALSE;  /* Next mouse motion will be ignore
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Save/Restore snapshot of local variables('MemorySnapShot_Store' handles type)
-*/
+/**
+ * Save/Restore snapshot of local variables('MemorySnapShot_Store' handles type)
+ */
 void Main_MemorySnapShot_Capture(BOOL bSave)
 {
   int nBytes;
@@ -84,9 +90,9 @@ void Main_MemorySnapShot_Capture(BOOL bSave)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Pause emulation, stop sound
-*/
+/**
+ * Pause emulation, stop sound
+ */
 void Main_PauseEmulation(void)
 {
   if( bEmulationActive )
@@ -97,9 +103,9 @@ void Main_PauseEmulation(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Start emulation
-*/
+/**
+ * Start emulation
+ */
 void Main_UnPauseEmulation(void)
 {
   if( !bEmulationActive )
@@ -114,14 +120,14 @@ void Main_UnPauseEmulation(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  This function waits on each emulated VBL to synchronize the real time
-  with the emulated ST.
-  Unfortunately SDL_Delay and other sleep functions like usleep or nanosleep
-  are very inaccurate on some systems like Linux 2.4 or Mac OS X (they can only
-  wait for a multiple of 10ms due to the scheduler on these systems), so we have
-  to "busy wait" there to get an accurate timing.
-*/
+/**
+ * This function waits on each emulated VBL to synchronize the real time
+ * with the emulated ST.
+ * Unfortunately SDL_Delay and other sleep functions like usleep or nanosleep
+ * are very inaccurate on some systems like Linux 2.4 or Mac OS X (they can only
+ * wait for a multiple of 10ms due to the scheduler on these systems), so we have
+ * to "busy wait" there to get an accurate timing.
+ */
 void Main_WaitOnVbl(void)
 {
   int nCurrentMilliTicks;
@@ -169,10 +175,10 @@ void Main_WaitOnVbl(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Since SDL_Delay and friends are very inaccurate on some systems, we have
-  to check if we can rely on this delay function.
-*/
+/**
+ * Since SDL_Delay and friends are very inaccurate on some systems, we have
+ * to check if we can rely on this delay function.
+ */
 static void Main_CheckForAccurateDelays(void)
 {
   int nStartTicks, nEndTicks;
@@ -195,10 +201,10 @@ static void Main_CheckForAccurateDelays(void)
 
 
 /* ----------------------------------------------------------------------- */
-/*
-  Set mouse pointer to new coordinates and set flag to ignore the mouse event
-  that is generated by SDL_WarpMouse().
-*/
+/**
+ * Set mouse pointer to new coordinates and set flag to ignore the mouse event
+ * that is generated by SDL_WarpMouse().
+ */
 void Main_WarpMouse(int x, int y)
 {
   SDL_WarpMouse(x, y);                  /* Set mouse pointer to new position */
@@ -207,9 +213,9 @@ void Main_WarpMouse(int x, int y)
 
 
 /* ----------------------------------------------------------------------- */
-/*
-  Handle mouse motion event.
-*/
+/**
+ * Handle mouse motion event.
+ */
 static void Main_HandleMouseMotion(SDL_Event *pEvent)
 {
 	int dx, dy;
@@ -225,36 +231,22 @@ static void Main_HandleMouseMotion(SDL_Event *pEvent)
 	dx = pEvent->motion.xrel;
 	dy = pEvent->motion.yrel;
 
-	if (STRes == ST_LOW_RES &&
-	    (ConfigureParams.Screen.ChosenDisplayMode == DISPLAYMODE_LOWCOL_HIGHRES ||
-	     ConfigureParams.Screen.ChosenDisplayMode == DISPLAYMODE_HICOL_HIGHRES))
+	/* In zoomed low res mode, we divide dx and dy by the zoom factor so that
+	 * the ST mouse cursor stays in sync with the host mouse. However, we have
+	 * to take care of lowest bit of dx and dy which will get lost when
+	 * dividing. So we store these bits in ax and ay and add them to dx and dy
+	 * the next time. */
+	if (nScreenZoomX != 1)
 	{
-		/* In zoomed ST-Low res mode, we devide dx and dy by two so that the ST mouse
-		 * cursor stays in sync with the host mouse. However, we have to take care of
-		 * lowest bit of dx and dy which will get lost when dividing by two. So we
-		 * store these bits in ax and ay and add them to dx and dy the next time. */
 		dx += ax;
-		dy += ay;
-		if (dx & 1)
-			ax = (dx > 0) ? 1 : -1;
-		else
-			ax = 0;
-		if (dy & 1)
-			ay = (dy > 0) ? 1 : -1;
-		else
-			ay = 0;
-		dx /= 2;
-		dy /= 2;
+		ax = dx % nScreenZoomX;
+		dx /= nScreenZoomX;
 	}
-	else if (STRes == ST_MEDIUM_RES || STRes == ST_LOWMEDIUM_MIX_RES)
+	if (nScreenZoomY != 1)
 	{
-		/* In medium resolution, we only have to take care about dy. */
 		dy += ay;
-		if (dy & 1)
-			ay = (dy > 0) ? 1 : -1;
-		else
-			ay = 0;
-		dy /= 2;
+		ay = dy % nScreenZoomY;
+		dy /= nScreenZoomY;
 	}
 
 	KeyboardProcessor.Mouse.dx += dx;
@@ -263,11 +255,11 @@ static void Main_HandleMouseMotion(SDL_Event *pEvent)
 
 
 /* ----------------------------------------------------------------------- */
-/*
-  Message handler
-  Here we process the SDL events (keyboard, mouse, ...) and map it to
-  Atari IKBD events.
-*/
+/**
+ * SDL message handler.
+ * Here we process the SDL events (keyboard, mouse, ...) and map it to
+ * Atari IKBD events.
+ */
 void Main_EventHandler(void)
 {
   SDL_Event event;
@@ -345,9 +337,9 @@ void Main_EventHandler(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Initialise emulation
-*/
+/**
+ * Initialise emulation
+ */
 static void Main_Init(void)
 {
   /* Open debug log file */
@@ -362,12 +354,17 @@ static void Main_Init(void)
     exit(-1);
   }
 
-  Misc_SeedRandom(1043618);
   SDLGui_Init();
   Printer_Init();
   RS232_Init();
   Midi_Init();
   Screen_Init();
+  HostScreen_Init();
+#if ENABLE_DSP_EMU
+  if (ConfigureParams.System.nDSPType == DSP_TYPE_EMU) {
+    DSP_Init();
+  }
+#endif
   Floppy_Init();
   Init680x0();                  /* Init CPU emulation */
   Audio_Init();
@@ -402,6 +399,7 @@ static void Main_Init(void)
   }
 
   IoMem_Init();
+  NvRam_Init();
   Joy_Init();
   Sound_Init();
 
@@ -414,9 +412,9 @@ static void Main_Init(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Un-Initialise emulation
-*/
+/**
+ * Un-Initialise emulation
+ */
 static void Main_UnInit(void)
 {
   Screen_ReturnFromFullScreen();
@@ -426,6 +424,7 @@ static void Main_UnInit(void)
   RS232_UnInit();
   Printer_UnInit();
   IoMem_UnInit();
+  NvRam_UnInit();
   GemDOS_UnInitDrives();
   Joy_UnInit();
   if(Sound_AreWeRecording())
@@ -433,6 +432,12 @@ static void Main_UnInit(void)
   Audio_UnInit();
   YMFormat_FreeRecording();
   SDLGui_UnInit();
+#if ENABLE_DSP_EMU
+  if (ConfigureParams.System.nDSPType == DSP_TYPE_EMU) {
+    DSP_UnInit();
+  }
+  HostScreen_UnInit();
+#endif
   Screen_UnInit();
   Exit680x0();
 
@@ -445,9 +450,9 @@ static void Main_UnInit(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Main
-*/
+/**
+ * Main
+ */
 int main(int argc, char *argv[])
 {
   /* Generate random seed */
@@ -468,6 +473,19 @@ int main(int argc, char *argv[])
 
   /* Check for any passed parameters, get boot disk */
   Opt_ParseParameters(argc, argv, szBootDiskImage, sizeof(szBootDiskImage));
+  /* monitor type option might require "reset" -> TRUE */
+  Configuration_Apply(TRUE);
+
+#ifdef WIN32
+  Win_OpenCon();
+#endif
+
+  /* Needed on N770 but useful also with other X11 window managers
+   * for window grouping when you have multiple SDL windows open
+   */
+#ifndef WIN32
+  setenv("SDL_VIDEO_X11_WMCLASS", "hatari", 1);
+#endif
 
   /* Init emulator system */
   Main_Init();
