@@ -6,9 +6,10 @@
 
   Reset emulation state.
 */
-const char Reset_rcsid[] = "Hatari $Id: reset.c,v 1.14 2006/02/21 14:15:35 thothy Exp $";
+const char Reset_rcsid[] = "Hatari $Id: reset.c,v 1.22 2007/01/18 09:24:25 eerot Exp $";
 
 #include "main.h"
+#include "configuration.h"
 #include "cart.h"
 #include "dmaSnd.h"
 #include "fdc.h"
@@ -25,36 +26,16 @@ const char Reset_rcsid[] = "Hatari $Id: reset.c,v 1.14 2006/02/21 14:15:35 thoth
 #include "sound.h"
 #include "stMemory.h"
 #include "tos.h"
+#include "vdi.h"
 #include "video.h"
+#include "falcon/videl.h"
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Cold reset ST (reset memory, all registers and reboot)
-*/
-int Reset_Cold(void)
-{
-  Main_WarpMouse(sdlscrn->w/2, sdlscrn->h/2);  /* Set mouse pointer to the middle of the screen */
-
-  return Reset_ST(TRUE);
-}
-
-
-/*-----------------------------------------------------------------------*/
-/*
-  Warm reset ST (reset registers, leave in same state and reboot)
-*/
-int Reset_Warm(void)
-{
-  return Reset_ST(FALSE);
-}
-
-
-/*-----------------------------------------------------------------------*/
-/*
-  Reset ST emulator states, chips, interrupts and registers
-*/
-int Reset_ST(BOOL bCold)
+/**
+ * Reset ST emulator states, chips, interrupts and registers
+ */
+static int Reset_ST(BOOL bCold)
 {
   if (bCold)
   {
@@ -85,13 +66,36 @@ int Reset_ST(BOOL bCold)
   PSG_Reset();                  /* Reset PSG */
   Sound_Reset();                /* Reset Sound */
   IKBD_Reset(bCold);            /* Keyboard */
-  Screen_Reset();               /* Reset screen */
+  if (ConfigureParams.System.nMachineType == MACHINE_FALCON && !bUseVDIRes)
+    VIDEL_reset();
+  else
+    Screen_Reset();               /* Reset screen */
   M68000_Reset(bCold);          /* Reset CPU */
 
-  /* And VBL interrupt, MUST always be one interrupt ready to trigger */
-  Int_AddAbsoluteInterrupt(nCyclesPerLine, INTERRUPT_VIDEO_ENDLINE);
-  Int_AddAbsoluteInterrupt(CYCLES_HBL, INTERRUPT_VIDEO_HBL);
-  Int_AddAbsoluteInterrupt(CYCLES_PER_FRAME, INTERRUPT_VIDEO_VBL);
+  /* Start HBL and VBL interrupts */
+  Video_StartInterrupts();
 
   return 0;
 }
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Cold reset ST (reset memory, all registers and reboot)
+ */
+int Reset_Cold(void)
+{
+  Main_WarpMouse(sdlscrn->w/2, sdlscrn->h/2);  /* Set mouse pointer to the middle of the screen */
+
+  return Reset_ST(TRUE);
+}
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Warm reset ST (reset registers, leave in same state and reboot)
+ */
+int Reset_Warm(void)
+{
+  return Reset_ST(FALSE);
+}
