@@ -13,11 +13,9 @@
   the bytes into an input buffer. This method fits in with the internet code
   which also reads data into a buffer.
 */
-const char RS232_rcsid[] = "Hatari $Id: rs232.c,v 1.22 2006/07/27 19:57:44 thothy Exp $";
+const char RS232_rcsid[] = "Hatari $Id: rs232.c,v 1.27 2007/01/16 18:42:59 thothy Exp $";
 
-#ifndef HAVE_TERMIOS_H
-#define HAVE_TERMIOS_H 1
-#endif
+#include "config.h"
 
 #if HAVE_TERMIOS_H
 # include <termios.h>
@@ -46,7 +44,7 @@ const char RS232_rcsid[] = "Hatari $Id: rs232.c,v 1.22 2006/07/27 19:57:44 thoth
 
 
 #ifndef HAVE_CFMAKERAW
-# if defined(__BEOS__) || (defined(__sun) && defined(__SVR4))
+# if defined(__BEOS__) || (defined(__sun) && defined(__SVR4)) || defined(__AMIGAOS4__) || defined(__riscos)
 #  define HAVE_CFMAKERAW 0
 # else
 #  define HAVE_CFMAKERAW 1
@@ -75,10 +73,44 @@ static inline void cfmakeraw(struct termios *termios_p)
 }
 #endif
 
+
+#if defined(__AMIGAOS4__)
+
+// dummy functions. REMOVE THEM LATER
+
+int tcgetattr(int file_descriptor,struct termios *tios_p)
+{
+	return -1;
+}
+
+int tcsetattr(int file_descriptor,int action,struct termios *tios_p)
+{
+	return -1;
+}
+
+int cfsetospeed(struct termios *tios, speed_t ospeed)
+{
+
+	tios->c_ospeed = ospeed;
+
+	return 0;
+}
+
+
+int cfsetispeed(struct termios *tios,speed_t ispeed)
+{
+	tios->c_ispeed = ispeed;
+
+	return 0;
+}
+
+#endif  /* __AMIGAOS4__ */
+
+
 /*-----------------------------------------------------------------------*/
-/*
-  Set serial line parameters to "raw" mode.
-*/
+/**
+ * Set serial line parameters to "raw" mode.
+ */
 static BOOL RS232_SetRawMode(FILE *fhndl)
 {
 	struct termios termmode;
@@ -104,12 +136,12 @@ static BOOL RS232_SetRawMode(FILE *fhndl)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set hardware configuration of RS-232:
-  - Bits per character
-  - Parity
-  - Start/stop bits
-*/
+/**
+ * Set hardware configuration of RS-232:
+ * - Bits per character
+ * - Parity
+ * - Start/stop bits
+ */
 static BOOL RS232_SetBitsConfig(int fd, int nCharSize, int nStopBits, BOOL bUseParity, BOOL bEvenParity)
 {
 	struct termios termmode;
@@ -166,15 +198,15 @@ static BOOL RS232_SetBitsConfig(int fd, int nCharSize, int nStopBits, BOOL bUseP
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Open file on COM port.
-*/
+/**
+ * Open file on COM port.
+ */
 static BOOL RS232_OpenCOMPort(void)
 {
 	bConnectedRS232 = FALSE;
 
 	/* Create our COM file for output */
-	hComOut = fopen(ConfigureParams.RS232.szOutFileName, "wb"); 
+	hComOut = fopen(ConfigureParams.RS232.szOutFileName, "wb");
 	if (hComOut == NULL)
 	{
 		Dprintf(("RS232: Failed to open output file %s\n",
@@ -184,7 +216,7 @@ static BOOL RS232_OpenCOMPort(void)
 	setvbuf(hComOut, NULL, _IONBF, 0);
 
 	/* Create our COM file for input */
-	hComIn = fopen(ConfigureParams.RS232.szInFileName, "rb"); 
+	hComIn = fopen(ConfigureParams.RS232.szInFileName, "rb");
 	if (hComIn == NULL)
 	{
 		Dprintf(("RS232: Failed to open input file %s\n",
@@ -220,9 +252,9 @@ static BOOL RS232_OpenCOMPort(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Close file on COM port
-*/
+/**
+ * Close file on COM port
+ */
 static void RS232_CloseCOMPort(void)
 {
 	/* Do have file open? */
@@ -248,9 +280,9 @@ static SDL_Thread *RS232Thread = NULL; /* Thread handle for reading incoming dat
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Add incoming bytes from other machine into our input buffer
-*/
+/**
+ * Add incoming bytes from other machine into our input buffer
+ */
 static void RS232_AddBytesToInputBuffer(unsigned char *pBytes, int nBytes)
 {
 	int i;
@@ -266,9 +298,9 @@ static void RS232_AddBytesToInputBuffer(unsigned char *pBytes, int nBytes)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Thread to read incoming RS-232 data, and pass to emulator input buffer
-*/
+/**
+ * Thread to read incoming RS-232 data, and pass to emulator input buffer
+ */
 static int RS232_ThreadFunc(void *pData)
 {
 	int iInChar;
@@ -312,10 +344,10 @@ static int RS232_ThreadFunc(void *pData)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Initialize RS-232, start thread to wait for incoming data
-  (we will open a connection when first bytes are sent).
-*/
+/**
+ * Initialize RS-232, start thread to wait for incoming data
+ * (we will open a connection when first bytes are sent).
+ */
 void RS232_Init(void)
 {
 	if (ConfigureParams.RS232.bEnableRS232)
@@ -343,9 +375,9 @@ void RS232_Init(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Close RS-232 connection and stop checking for incoming data.
-*/
+/**
+ * Close RS-232 connection and stop checking for incoming data.
+ */
 void RS232_UnInit(void)
 {
 	/* Close, kill thread and free resource */
@@ -358,7 +390,7 @@ void RS232_UnInit(void)
 		RS232Thread = NULL;
 	}
 	RS232_CloseCOMPort();
-	
+
 	if (pSemFreeBuf)
 	{
 		SDL_DestroySemaphore(pSemFreeBuf);
@@ -368,25 +400,25 @@ void RS232_UnInit(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set hardware configuration of RS-232 according to the USART control register.
-
-  ucr: USART Control Register
-    Bit 0: unused
-    Bit 1: 0-Odd Parity, 1-Even Parity
-    Bit 2: 0-No Parity, 1-Parity
-    Bits 3,4: Start/Stop bits
-      0 0 : 0-Start, 0-Stop    Synchronous
-      0 1 : 0-Start, 1-Stop    Asynchronous
-      1 0 : 1-Start, 1.5-Stop  Asynchronous
-      1 1 : 1-Start, 2-Stop    Asynchronous
-    Bits 5,6: 'WordLength'
-      0 0 : 8 Bits
-      0 1 : 7 Bits
-      1 0 : 6 Bits
-      1 1 : 5 Bits
-    Bit 7: Frequency from TC and RC
-*/
+/**
+ * Set hardware configuration of RS-232 according to the USART control register.
+ *
+ * ucr: USART Control Register
+ *   Bit 0: unused
+ *   Bit 1: 0-Odd Parity, 1-Even Parity
+ *   Bit 2: 0-No Parity, 1-Parity
+ *   Bits 3,4: Start/Stop bits
+ *     0 0 : 0-Start, 0-Stop    Synchronous
+ *     0 1 : 0-Start, 1-Stop    Asynchronous
+ *     1 0 : 1-Start, 1.5-Stop  Asynchronous
+ *     1 1 : 1-Start, 2-Stop    Asynchronous
+ *   Bits 5,6: 'WordLength'
+ *     0 0 : 8 Bits
+ *     0 1 : 7 Bits
+ *     1 0 : 6 Bits
+ *     1 1 : 5 Bits
+ *   Bit 7: Frequency from TC and RC
+ */
 void RS232_HandleUCR(short int ucr)
 {
 #if HAVE_TERMIOS_H
@@ -415,9 +447,9 @@ void RS232_HandleUCR(short int ucr)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set baud rate configuration of RS-232.
-*/
+/**
+ * Set baud rate configuration of RS-232.
+ */
 BOOL RS232_SetBaudRate(int nBaud)
 {
 #if HAVE_TERMIOS_H
@@ -509,10 +541,10 @@ BOOL RS232_SetBaudRate(int nBaud)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set baud rate configuration of RS-232 according to the Timer-D hardware
-  registers.
-*/
+/**
+ * Set baud rate configuration of RS-232 according to the Timer-D hardware
+ * registers.
+ */
 void RS232_SetBaudRateFromTimerD(void)
 {
 	int nTimerD_CR, nTimerD_DR, nBaudRate;
@@ -555,9 +587,9 @@ void RS232_SetBaudRateFromTimerD(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set flow control configuration of RS-232.
-*/
+/**
+ * Set flow control configuration of RS-232.
+ */
 void RS232_SetFlowControl(int ctrl)
 {
 	Dprintf(("RS232_SetFlowControl(%i)\n", ctrl));
@@ -567,9 +599,9 @@ void RS232_SetFlowControl(int ctrl)
 
 
 /*----------------------------------------------------------------------- */
-/*
-  Pass bytes from emulator to RS-232
-*/
+/**
+ * Pass bytes from emulator to RS-232
+ */
 BOOL RS232_TransferBytesTo(unsigned char *pBytes, int nBytes)
 {
 	/* Do need to open a connection to RS232? */
@@ -598,9 +630,9 @@ BOOL RS232_TransferBytesTo(unsigned char *pBytes, int nBytes)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read characters from our internal input buffer (bytes from other machine)
-*/
+/**
+ * Read characters from our internal input buffer (bytes from other machine)
+ */
 BOOL RS232_ReadBytes(unsigned char *pBytes, int nBytes)
 {
 	int i;
@@ -623,9 +655,9 @@ BOOL RS232_ReadBytes(unsigned char *pBytes, int nBytes)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Return TRUE if bytes waiting!
-*/
+/**
+ * Return TRUE if bytes waiting!
+ */
 BOOL RS232_GetStatus(void)
 {
 	/* Connected? */
@@ -642,9 +674,9 @@ BOOL RS232_GetStatus(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read from the Syncronous Character Register.
-*/
+/**
+ * Read from the Syncronous Character Register.
+ */
 void RS232_SCR_ReadByte(void)
 {
 	M68000_WaitState(4);
@@ -653,9 +685,9 @@ void RS232_SCR_ReadByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to the Syncronous Character Register.
-*/
+/**
+ * Write to the Syncronous Character Register.
+ */
 void RS232_SCR_WriteByte(void)
 {
 	M68000_WaitState(4);
@@ -665,9 +697,9 @@ void RS232_SCR_WriteByte(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read from the USART Control Register.
-*/
+/**
+ * Read from the USART Control Register.
+ */
 void RS232_UCR_ReadByte(void)
 {
 	M68000_WaitState(4);
@@ -676,9 +708,9 @@ void RS232_UCR_ReadByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to the USART Control Register.
-*/
+/**
+ * Write to the USART Control Register.
+ */
 void RS232_UCR_WriteByte(void)
 {
 	M68000_WaitState(4);
@@ -691,9 +723,9 @@ void RS232_UCR_WriteByte(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read from the Receiver Status Register.
-*/
+/**
+ * Read from the Receiver Status Register.
+ */
 void RS232_RSR_ReadByte(void)
 {
 	M68000_WaitState(4);
@@ -707,9 +739,9 @@ void RS232_RSR_ReadByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to the Receiver Status Register.
-*/
+/**
+ * Write to the Receiver Status Register.
+ */
 void RS232_RSR_WriteByte(void)
 {
 	M68000_WaitState(4);
@@ -719,9 +751,9 @@ void RS232_RSR_WriteByte(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read from the Transmitter Status Register.
-*/
+/**
+ * Read from the Transmitter Status Register.
+ */
 void RS232_TSR_ReadByte(void)
 {
 	M68000_WaitState(4);
@@ -735,9 +767,9 @@ void RS232_TSR_ReadByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to the Transmitter Status Register.
-*/
+/**
+ * Write to the Transmitter Status Register.
+ */
 void RS232_TSR_WriteByte(void)
 {
 	M68000_WaitState(4);
@@ -747,9 +779,9 @@ void RS232_TSR_WriteByte(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read from the USART Data Register.
-*/
+/**
+ * Read from the USART Data Register.
+ */
 void RS232_UDR_ReadByte(void)
 {
 	unsigned char InByte;
@@ -768,9 +800,9 @@ void RS232_UDR_ReadByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to the USART Data Register.
-*/
+/**
+ * Write to the USART Data Register.
+ */
 void RS232_UDR_WriteByte(void)
 {
 	unsigned char OutByte;
