@@ -19,7 +19,7 @@
   only convert the screen every 50 times a second - inbetween frames are not
   processed.
 */
-const char Screen_rcsid[] = "Hatari $Id: screen.c,v 1.50 2006/06/26 23:03:09 thothy Exp $";
+const char Screen_rcsid[] = "Hatari $Id: screen.c,v 1.63 2007/01/18 09:24:25 eerot Exp $";
 
 #include <SDL.h>
 #include <SDL_endian.h>
@@ -29,7 +29,6 @@ const char Screen_rcsid[] = "Hatari $Id: screen.c,v 1.50 2006/06/26 23:03:09 tho
 #include "ikbd.h"
 #include "m68000.h"
 #include "misc.h"
-#include "printer.h"
 #include "screen.h"
 #include "convert/routines.h"
 #include "screenSnapShot.h"
@@ -37,17 +36,26 @@ const char Screen_rcsid[] = "Hatari $Id: screen.c,v 1.50 2006/06/26 23:03:09 tho
 #include "spec512.h"
 #include "vdi.h"
 #include "video.h"
+#include "falcon/videl.h"
+#include "falcon/hostscreen.h"
 
 
+/* extern for several purposes */
+int STRes = ST_LOW_RES;       /* current resolution */
+SDL_Surface *sdlscrn = NULL;  /* The SDL screen surface */
+int nScreenZoomX, nScreenZoomY;  /* Zooming factors, used for scaling mouse motions */
+
+/* extern for shortcuts and falcon/hostscreen.c */
 BOOL bGrabMouse = FALSE;      /* Grab the mouse cursor in the window */
-BOOL bInFullScreen=FALSE;     /* TRUE if in full screen */
+BOOL bInFullScreen = FALSE;   /* TRUE if in full screen */
+
+/* extern for spec512.c */
 int STScreenLeftSkipBytes;
 int STScreenStartHorizLine;   /* Start lines to be converted */
-int STRes=ST_LOW_RES;         /* current resolution */
-int PrevSTRes=ST_LOW_RES;     /* previous ST resolution */
 Uint32 STRGBPalette[16];      /* Palette buffer used in conversion routines */
 Uint32 ST2RGB[4096];          /* Table to convert ST 0x777 / STe 0xfff palette to PC format RGB551 (2 pixels each entry) */
-SDL_Surface *sdlscrn = NULL;  /* The SDL screen surface */
+
+/* extern for video.c */
 Uint8 *pSTScreen;
 FRAMEBUFFER *pFrameBuffer;    /* Pointer into current 'FrameBuffer' */
 
@@ -61,7 +69,7 @@ static int STScreenWidthBytes;
 static int STScreenLineOffset[NUM_VISIBLE_LINES];  /* Offsets for ST screen lines eg, 0,160,320... */
 static Uint16 HBLPalette[16], PrevHBLPalette[16];  /* Current palette for line, also copy of first line */
 
-static void (*ScreenDrawFunctionsNormal[4])(void); /* Screen draw functions */
+static void (*ScreenDrawFunctionsNormal[3])(void); /* Screen draw functions */
 static void (*ScreenDrawFunctionsVDI[3])(void) =
 {
   ConvertVDIRes_16Colour,
@@ -75,10 +83,10 @@ static int ScrUpdateFlag;               /* Bit mask of how to update screen */
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Create ST 0x777 / STe 0xfff color format to 16-bits per pixel conversion
-  table. Called each time when changed resolution or to/from fullscreen mode.
-*/
+/**
+ * Create ST 0x777 / STe 0xfff color format to 16-bits per pixel conversion
+ * table. Called each time when changed resolution or to/from fullscreen mode.
+ */
 static void Screen_SetupRGBTable(void)
 {
   Uint16 STColour, RGBColour;
@@ -106,9 +114,9 @@ static void Screen_SetupRGBTable(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Create new palette for display.
-*/
+/**
+ * Create new palette for display.
+ */
 static void Screen_CreatePalette(void)
 {
 #if SDL_BYTEORDER == SDL_BIG_ENDIAN
@@ -159,9 +167,9 @@ static void Screen_CreatePalette(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Create 8-Bit palette for display if needed.
-*/
+/**
+ * Create 8-Bit palette for display if needed.
+ */
 static void Screen_Handle8BitPalettes(void)
 {
   BOOL bPaletteChanged=FALSE;
@@ -199,52 +207,44 @@ static void Screen_Handle8BitPalettes(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set screen draw functions.
-*/
+/**
+ * Set screen draw functions.
+ */
 static void Screen_SetDrawFunctions(void)
 {
-  switch (ConfigureParams.Screen.ChosenDisplayMode)
-  {
-    case DISPLAYMODE_LOWCOL_LOWRES:     /* low color, low resolution */
-      ScreenDrawFunctionsNormal[ST_LOW_RES] = ConvertLowRes_320x8Bit;
-      ScreenDrawFunctionsNormal[ST_MEDIUM_RES] = ConvertMediumRes_640x8Bit;
-      ScreenDrawFunctionsNormal[ST_HIGH_RES] = ConvertHighRes_640x8Bit;
-      ScreenDrawFunctionsNormal[ST_LOWMEDIUM_MIX_RES] = ConvertMediumRes_640x8Bit;
-      break;
-    case DISPLAYMODE_LOWCOL_HIGHRES:    /* low color, zoomed resolution */
+  if (ConfigureParams.Screen.bForce8Bpp) {
+
+    if (ConfigureParams.Screen.bZoomLowRes) {
+      /* low color, zoomed resolution */
       ScreenDrawFunctionsNormal[ST_LOW_RES] = ConvertLowRes_640x8Bit;
       ScreenDrawFunctionsNormal[ST_MEDIUM_RES] = ConvertMediumRes_640x8Bit;
       ScreenDrawFunctionsNormal[ST_HIGH_RES] = ConvertHighRes_640x8Bit;
-      ScreenDrawFunctionsNormal[ST_LOWMEDIUM_MIX_RES] = ConvertMediumRes_640x8Bit;
-      break;
-    case DISPLAYMODE_HICOL_LOWRES:      /* high color, low resolution */
-      ScreenDrawFunctionsNormal[ST_LOW_RES] = ConvertLowRes_320x16Bit;
-      ScreenDrawFunctionsNormal[ST_MEDIUM_RES] = ConvertMediumRes_640x16Bit;
+    } else {
+      /* low color, low resolution */
+      ScreenDrawFunctionsNormal[ST_LOW_RES] = ConvertLowRes_320x8Bit;
+      ScreenDrawFunctionsNormal[ST_MEDIUM_RES] = ConvertMediumRes_640x8Bit;
       ScreenDrawFunctionsNormal[ST_HIGH_RES] = ConvertHighRes_640x8Bit;
-      ScreenDrawFunctionsNormal[ST_LOWMEDIUM_MIX_RES] = ConvertMediumRes_640x16Bit;
-      break;
-    case DISPLAYMODE_HICOL_HIGHRES:     /* high color, zoomed resolution */
+    }
+  } else {
+    if (ConfigureParams.Screen.bZoomLowRes) {
+      /* high color, zoomed resolution */
       ScreenDrawFunctionsNormal[ST_LOW_RES] = ConvertLowRes_640x16Bit;
       ScreenDrawFunctionsNormal[ST_MEDIUM_RES] = ConvertMediumRes_640x16Bit;
       ScreenDrawFunctionsNormal[ST_HIGH_RES] = ConvertHighRes_640x8Bit;
-      ScreenDrawFunctionsNormal[ST_LOWMEDIUM_MIX_RES] = ConvertMediumRes_640x16Bit;
-      break;
-    default:
-      fprintf(stderr, "Illegal display mode: %i\n", ConfigureParams.Screen.ChosenDisplayMode);
-      ScreenDrawFunctionsNormal[ST_LOW_RES] = NULL;
-      ScreenDrawFunctionsNormal[ST_MEDIUM_RES] = NULL;
-      ScreenDrawFunctionsNormal[ST_HIGH_RES] = NULL;
-      ScreenDrawFunctionsNormal[ST_LOWMEDIUM_MIX_RES] = NULL;
-      break;
+    } else {
+      /* high color, low resolution */
+      ScreenDrawFunctionsNormal[ST_LOW_RES] = ConvertLowRes_320x16Bit;
+      ScreenDrawFunctionsNormal[ST_MEDIUM_RES] = ConvertMediumRes_640x16Bit;
+      ScreenDrawFunctionsNormal[ST_HIGH_RES] = ConvertHighRes_640x8Bit;
+    }
   }
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Initialize SDL screen surface / set resolution.
-*/
+/**
+ * Initialize SDL screen surface / set resolution.
+ */
 static void Screen_SetResolution(void)
 {
   int Width, Height, BitCount;
@@ -258,9 +258,7 @@ static void Screen_SetResolution(void)
   }
   else
   {
-    if (STRes == ST_LOW_RES &&
-        (ConfigureParams.Screen.ChosenDisplayMode == DISPLAYMODE_LOWCOL_LOWRES
-         || ConfigureParams.Screen.ChosenDisplayMode == DISPLAYMODE_HICOL_LOWRES))
+    if (STRes == ST_LOW_RES && !ConfigureParams.Screen.bZoomLowRes)
     {
       Width = 320;
       Height = 200;
@@ -282,9 +280,7 @@ static void Screen_SetResolution(void)
   }
 
   /* Bits per pixel */
-  if (ConfigureParams.Screen.ChosenDisplayMode == DISPLAYMODE_LOWCOL_LOWRES
-      || ConfigureParams.Screen.ChosenDisplayMode == DISPLAYMODE_LOWCOL_HIGHRES
-      || STRes == ST_HIGH_RES || bUseVDIRes)
+  if (ConfigureParams.Screen.bForce8Bpp || STRes == ST_HIGH_RES || bUseVDIRes)
   {
     BitCount = 8;
   }
@@ -293,6 +289,23 @@ static void Screen_SetResolution(void)
     BitCount = 16;
   }
 
+  /* Set zoom factors, used for scaling mouse motions */
+  if (STRes == ST_LOW_RES && ConfigureParams.Screen.bZoomLowRes)
+  {
+    nScreenZoomX = 2;
+    nScreenZoomY = 2;
+  }
+  else if (STRes == ST_MEDIUM_RES)
+  {
+    nScreenZoomX = 1;
+    nScreenZoomY = 2;
+  }
+  else
+  {
+    nScreenZoomX = 1;
+    nScreenZoomY = 1;
+  }
+
   /* SDL Video attributes: */
   if (bInFullScreen)
   {
@@ -305,6 +318,11 @@ static void Screen_SetResolution(void)
     sdlVideoFlags  = SDL_SWSURFACE|SDL_HWPALETTE;
   }
 
+  /* set draw functions in case SDL attribs didn't change
+   * but STRes changed (e.g. medres -> zoomed lowres)
+   */
+  Screen_SetDrawFunctions();
+
   /* Check if we really have to change the video mode: */
   if (sdlscrn && sdlscrn->w == Width && sdlscrn->h == Height
       && sdlscrn->format->BitsPerPixel == BitCount
@@ -330,15 +348,14 @@ static void Screen_SetResolution(void)
   if (!bGrabMouse)
     SDL_WM_GrabInput(SDL_GRAB_OFF); /* Un-grab mouse pointer in windowed mode */
 
-  Screen_SetDrawFunctions();        /* Set draw functions */
   Screen_SetFullUpdate();           /* Cause full update of screen */
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Store Y offset for each horizontal line in our source ST screen for each reference in assembler(no multiply)
-*/
+/**
+ * Store Y offset for each horizontal line in our source ST screen for each reference in assembler(no multiply)
+ */
 static void Screen_SetScreenLineOffsets(void)
 {
   int i;
@@ -349,12 +366,13 @@ static void Screen_SetScreenLineOffsets(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Init Screen bitmap and buffers/tables needed for ST to PC screen conversion
-*/
+/**
+ * Init Screen bitmap and buffers/tables needed for ST to PC screen conversion
+ */
 void Screen_Init(void)
 {
   int i;
+  SDL_Surface *pIconSurf;
 
   /* Clear frame buffer structures and set current pointer */
   memset(FrameBuffers, 0, NUM_FRAMEBUFFERS * sizeof(FRAMEBUFFER));
@@ -372,6 +390,16 @@ void Screen_Init(void)
   }
   pFrameBuffer = &FrameBuffers[0];
 
+  /* Load and set icon */
+  pIconSurf = SDL_LoadBMP(DATADIR "/hatari-icon.bmp");
+  if (pIconSurf)
+  {
+    SDL_SetColorKey(pIconSurf, SDL_SRCCOLORKEY, SDL_MapRGB(pIconSurf->format, 255, 255, 255));
+    SDL_WM_SetIcon(pIconSurf, NULL);
+    SDL_FreeSurface(pIconSurf);
+  }
+
+  /* Set initial window resolution */
   Screen_SetResolution();
 
   Video_SetScreenRasters();                       /* Set rasters ready for first screen */
@@ -388,9 +416,9 @@ void Screen_Init(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Free screen bitmap and allocated resources
-*/
+/**
+ * Free screen bitmap and allocated resources
+ */
 void Screen_UnInit(void)
 {
   int i;
@@ -405,9 +433,9 @@ void Screen_UnInit(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Reset screen
-*/
+/**
+ * Reset screen
+ */
 void Screen_Reset(void)
 {
   /* On re-boot, always correct ST resolution for monitor, eg Colour/Mono */
@@ -422,17 +450,16 @@ void Screen_Reset(void)
     else
       STRes = ST_LOW_RES;
   }
-  PrevSTRes = -1;
   /* Cause full update */
-  Screen_SetFullUpdate();
+  Screen_ModeChanged();
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set flags so screen will be TOTALLY re-drawn (clears whole of full-screen)
-  next time around
-*/
+/**
+ * Set flags so screen will be TOTALLY re-drawn (clears whole of full-screen)
+ * next time around
+ */
 void Screen_SetFullUpdate(void)
 {
   int i;
@@ -444,31 +471,38 @@ void Screen_SetFullUpdate(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Clear Window display memory
-*/
+/**
+ * Clear Window display memory
+ */
 static void Screen_ClearScreen(void)
 {
   SDL_FillRect(sdlscrn,NULL, SDL_MapRGB(sdlscrn->format, 0, 0, 0) );
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Enter Full screen mode
-*/
+/**
+ * Enter Full screen mode
+ */
 void Screen_EnterFullScreen(void)
 {
   if (!bInFullScreen)
   {
     Main_PauseEmulation();        /* Hold things... */
-
     bInFullScreen = TRUE;
-    Screen_SetResolution();
 
-    SDL_Delay(20);                /* To give monitor time to change to new resolution */
-    Screen_ClearScreen();         /* Black out screen bitmap as will be invalid when return */
+    if ((ConfigureParams.System.nMachineType == MACHINE_FALCON
+         || ConfigureParams.System.nMachineType == MACHINE_TT) && !bUseVDIRes)
+    {
+      HostScreen_toggleFullScreen();
+    }
+    else
+    {
+      Screen_SetResolution();
+      Screen_ClearScreen();         /* Black out screen bitmap as will be invalid when return */
+    }
 
-    Main_UnPauseEmulation();      /* And off we go... */
+    SDL_Delay(20);                  /* To give monitor time to change to new resolution */
+    Main_UnPauseEmulation();        /* And off we go... */
 
     SDL_WM_GrabInput(SDL_GRAB_ON);  /* Grab mouse pointer in fullscreen */
   }
@@ -476,74 +510,111 @@ void Screen_EnterFullScreen(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Return from Full screen mode back to a window
-*/
+/**
+ * Return from Full screen mode back to a window
+ */
 void Screen_ReturnFromFullScreen(void)
 {
   if (bInFullScreen)
   {
     Main_PauseEmulation();        /* Hold things... */
-
     bInFullScreen = FALSE;
-    Screen_SetResolution();
+
+    if ((ConfigureParams.System.nMachineType == MACHINE_FALCON
+         || ConfigureParams.System.nMachineType == MACHINE_TT) && !bUseVDIRes)
+    {
+      HostScreen_toggleFullScreen();
+      if (!bGrabMouse)
+        SDL_WM_GrabInput(SDL_GRAB_OFF); /* Un-grab mouse pointer in windowed mode */
+    }
+    else
+    {
+      Screen_SetResolution();
+    }
 
     SDL_Delay(20);                /* To give monitor time to switch resolution */
-
     Main_UnPauseEmulation();      /* And off we go... */
   }
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Have we changes beteen low/medium/high res?
-*/
-void Screen_DidResolutionChange(void)
+/**
+ * Have we changed between low/med/high res?
+ */
+static void Screen_DidResolutionChange(int new_res)
 {
-  /* Did change res? */
-  if (STRes!=PrevSTRes)
+  if (new_res != STRes)
   {
-    /* Set new display mode, if differs from current */
-    Screen_SetResolution();
-    PrevSTRes = STRes;
+    STRes = new_res;
+    Screen_ModeChanged();
+  }
+  else
+  {
+    /* Did change overscan mode? Causes full update */
+    if (pFrameBuffer->OverscanModeCopy != OverscanMode)
+      pFrameBuffer->bFullUpdate = TRUE;
   }
-
-  /* Did change overscan mode? Causes full update */
-  if (pFrameBuffer->OverscanModeCopy != OverscanMode)
-    pFrameBuffer->bFullUpdate = TRUE;
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Compare current resolution on line with previous, and set 'UpdateLine' accordingly
-  Also check if swap between low/medium resolution and return in 'bLowMedMix'
-*/
-static void Screen_CompareResolution(int y, int *pUpdateLine, BOOL *pbLowMedMix)
+/**
+ * Force things associated with changing between low/medium/high res.
+ */
+void Screen_ModeChanged(void)
 {
-  int Resolution;
+  if (!sdlscrn)
+  {
+    /* screen not yet initialized */
+    return;
+  }
+  /* Don't run this function if Videl emulation is running! */
+  if (ConfigureParams.System.nMachineType == MACHINE_FALCON && !bUseVDIRes)
+  {
+    VIDEL_ZoomModeChanged();
+    return;
+  }
+  else if (ConfigureParams.System.nMachineType == MACHINE_TT && !bUseVDIRes)
+  {
+    int width, height, bpp;
+    Video_GetTTRes(&width, &height, &bpp);
+    HostScreen_setWindowSize(width, height, 8);
+    return;
+  }
+  /* Set new display mode, if differs from current */
+  Screen_SetResolution();
+  Screen_SetFullUpdate();
+}
 
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Compare current resolution on line with previous, and set 'UpdateLine' accordingly
+ * Return if swap between low/medium resolution
+ */
+static BOOL Screen_CompareResolution(int y, int *pUpdateLine, int oldres)
+{
   /* Check if wrote to resolution register */
   if (HBLPaletteMasks[y]&PALETTEMASK_RESOLUTION)  /* See 'Intercept_ShifterMode_WriteByte' */
   {
-    Resolution = (HBLPaletteMasks[y]>>16)&0x1;
-    /* Have used any low/medium res mix? */
-    if (Resolution!=(STRes&0x1))
-      *pbLowMedMix = TRUE;
-    /* Did change resolution */
-    if (Resolution!=(int)((pFrameBuffer->HBLPaletteMasks[y]>>16)&0x1))
+    int newres = (HBLPaletteMasks[y]>>16)&ST_MEDIUM_RES_BIT;
+    /* Did resolution change? */
+    if (newres != (int)((pFrameBuffer->HBLPaletteMasks[y]>>16)&ST_MEDIUM_RES_BIT))
       *pUpdateLine |= PALETTEMASK_UPDATERES;
     else
       *pUpdateLine &= ~PALETTEMASK_UPDATERES;
+    /* Have used any low/medium res mix? */
+    return (newres != (oldres&ST_MEDIUM_RES_BIT));
   }
+  return FALSE;
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Check to see if palette changes cause screen update and keep 'HBLPalette[]' up-to-date
-*/
+/**
+ * Check to see if palette changes cause screen update and keep 'HBLPalette[]' up-to-date
+ */
 static void Screen_ComparePalette(int y, int *pUpdateLine)
 {
   BOOL bPaletteChanged = FALSE;
@@ -573,15 +644,16 @@ static void Screen_ComparePalette(int y, int *pUpdateLine)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Check for differences in Palette and Resolution from Mask table and update
-  and store off which lines need updating and create full-screen palette.
-  (It is very important for these routines to check for colour changes with
-  the previous screen so only the very minimum parts are updated)
-*/
-static int Screen_ComparePaletteMask(void)
+/**
+ * Check for differences in Palette and Resolution from Mask table and update
+ * and store off which lines need updating and create full-screen palette.
+ * (It is very important for these routines to check for colour changes with
+ * the previous screen so only the very minimum parts are updated).
+ * Return new STRes value.
+ */
+static int Screen_ComparePaletteMask(int res)
 {
-  BOOL bLowMedMix=FALSE;
+  BOOL bLowMedMix = FALSE;
   int LineUpdate = 0;
   int y;
 
@@ -617,7 +689,7 @@ static int Screen_ComparePaletteMask(void)
   if (bUseVDIRes)
   {
     /* Force to VDI resolution screen, without overscan */
-    STRes = VDIRes;
+    res = VDIRes;
 
     /* Colors changed? */
     if (HBLPalettes[0]!=PrevHBLPalette[0])
@@ -633,38 +705,38 @@ static int Screen_ComparePaletteMask(void)
   else if (bUseHighRes)
   {
     /* Force to standard hi-resolution screen, without overscan */
-    STRes = ST_HIGH_RES;
+    res = ST_HIGH_RES;
   }
   else    /* Full colour */
   {
     /* Get resolution */
-    STRes = (HBLPaletteMasks[0]>>16)&0x3;
+    res = (HBLPaletteMasks[0]>>16)&ST_RES_MASK;
     /* Do all lines - first is tagged as full-update */
     for(y=0; y<NUM_VISIBLE_LINES; y++)
     {
       /* Find any resolution/palette change and update palette/mask buffer */
       /* ( LineUpdate has top two bits set to say if line needs updating due to palette or resolution change ) */
-      Screen_CompareResolution(y,&LineUpdate,&bLowMedMix);
+      bLowMedMix |= Screen_CompareResolution(y, &LineUpdate, res);
       Screen_ComparePalette(y,&LineUpdate);
       HBLPaletteMasks[y] = (HBLPaletteMasks[y]&(~PALETTEMASK_UPDATEMASK)) | LineUpdate;
       /* Copy palette and mask for next frame */
       memcpy(&pFrameBuffer->HBLPalettes[y*16],HBLPalette,sizeof(short int)*16);
       pFrameBuffer->HBLPaletteMasks[y] = HBLPaletteMasks[y];
     }
-    /* Did mix resolution? */
-    if (bLowMedMix)
-      STRes = ST_LOWMEDIUM_MIX_RES;
+    /* Did mix/have medium resolution? */
+    if (bLowMedMix || (res & ST_MEDIUM_RES_BIT))
+      res = ST_MEDIUM_RES;
   }
 
-  return(STRes);
+  return res;
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Update Palette Mask to show 'full-update' required. This is usually done after a resolution change
-  or when going between a Window and full-screen display
-*/
+/**
+ * Update Palette Mask to show 'full-update' required. This is usually done after a resolution change
+ * or when going between a Window and full-screen display
+ */
 static void Screen_SetFullUpdateMask(void)
 {
   int y;
@@ -675,9 +747,9 @@ static void Screen_SetFullUpdateMask(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set details for ST screen conversion.
-*/
+/**
+ * Set details for ST screen conversion.
+ */
 static void Screen_SetConvertDetails(void)
 {
   pSTScreen = pFrameBuffer->pSTScreen;          /* Source in ST memory */
@@ -686,7 +758,8 @@ static void Screen_SetConvertDetails(void)
 
   PCScreenBytesPerLine = sdlscrn->pitch;        /* Bytes per line */
   pHBLPalettes = pFrameBuffer->HBLPalettes;     /* HBL palettes pointer */
-  bScrDoubleY = !ConfigureParams.Screen.bInterleavedScreen; /* non-interleaved? => double up on Y */
+  /* Not in TV-Mode? Then double up on Y: */
+  bScrDoubleY = !(ConfigureParams.Screen.MonitorType == MONITOR_TYPE_TV);
 
   if (bUseVDIRes)
   {
@@ -704,7 +777,7 @@ static void Screen_SetConvertDetails(void)
       STScreenLeftSkipBytes = 0;                /* Number of bytes to skip on ST screen for left (border) */
       STScreenStartHorizLine = 0;               /* Full height */
 
-      if (ConfigureParams.Screen.bUseHighRes)
+      if (bUseHighRes)
       {
         pFrameBuffer->OverscanModeCopy = OverscanMode = OVERSCANMODE_NONE;
         STScreenEndHorizLine = 400;
@@ -728,9 +801,9 @@ static void Screen_SetConvertDetails(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Lock full-screen for drawing
-*/
+/**
+ * Lock full-screen for drawing
+ */
 static BOOL Screen_Lock(void)
 {
   if(SDL_MUSTLOCK(sdlscrn))
@@ -746,9 +819,9 @@ static BOOL Screen_Lock(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  UnLock full-screen
-*/
+/**
+ * UnLock full-screen
+ */
 static void Screen_UnLock(void)
 {
   if( SDL_MUSTLOCK(sdlscrn) )
@@ -757,9 +830,9 @@ static void Screen_UnLock(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Swap ST Buffers, used for full-screen where have double-buffering
-*/
+/**
+ * Swap ST Buffers, used for full-screen where have double-buffering
+ */
 static void Screen_SwapSTBuffers(void)
 {
 #if NUM_FRAMEBUFFERS > 1
@@ -775,34 +848,26 @@ static void Screen_SwapSTBuffers(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Blit our converted ST screen to window/full-screen
-  Note that our source image includes all borders so if have them disabled simply blit a smaller source rectangle!
-*/
+/**
+ * Blit our converted ST screen to window/full-screen
+ * Note that our source image includes all borders so if have them disabled simply blit a smaller source rectangle!
+ */
 static void Screen_Blit(BOOL bSwapScreen)
 {
-  /* Rectangle areas to Blit according to if overscan is enabled or not (source always includes all borders) */
-/*   static SDL_Rect SrcWindowBitmapSizes[] = */
-/*   { */
-/*     { OVERSCAN_LEFT,OVERSCAN_TOP, 320,200 },                /\* ST_LOW_RES *\/ */
-/*     { (OVERSCAN_LEFT<<1),(OVERSCAN_TOP<<1), 640,400 },      /\* ST_MEDIUM_RES *\/ */
-/*     { 0,0, 640,400 },                                       /\* ST_HIGH_RES *\/ */
-/*     { (OVERSCAN_LEFT<<1),(OVERSCAN_BOTTOM<<1), 640,400 },   /\* ST_LOWMEDIUM_MIX_RES *\/ */
-/*   }; */
+  /* Rectangle areas to Blit according to if overscan is enabled or not
+   * (source always includes all borders)
+   */
   static const SDL_Rect SrcWindowBitmapSizes[] =
   {
-    { 0,0, 320,200 },                /* ST_LOW_RES */
+    { 0,0, 320,200 },      /* ST_LOW_RES */
     { 0,0, 640,400 },      /* ST_MEDIUM_RES */
-    { 0,0, 640,400 },                                       /* ST_HIGH_RES */
-    { 0,0, 640,400 },   /* ST_LOWMEDIUM_MIX_RES */
+    { 0,0, 640,400 }       /* ST_HIGH_RES */
   };
-
   static const SDL_Rect SrcWindowOverscanBitmapSizes[] =
   {
     { 0,0, OVERSCAN_LEFT+320+OVERSCAN_RIGHT,OVERSCAN_TOP+200+OVERSCAN_BOTTOM },
     { 0,0, (OVERSCAN_LEFT<<1)+640+(OVERSCAN_RIGHT<<1),(OVERSCAN_TOP<<1)+400+(OVERSCAN_BOTTOM<<1) },
-    { 0,0, 640,400 },
-    { 0,0, (OVERSCAN_LEFT<<1)+640+(OVERSCAN_RIGHT<<1),(OVERSCAN_TOP<<1)+400+(OVERSCAN_BOTTOM<<1) },
+    { 0,0, 640,400 }
   };
 
   unsigned char *pTmpScreen;
@@ -819,7 +884,7 @@ static void Screen_Blit(BOOL bSwapScreen)
   else
   {
     /* VDI resolution? */
-    if (bUseVDIRes || ConfigureParams.Screen.bUseHighRes)
+    if (bUseVDIRes || bUseHighRes)
     {
       /* Show VDI or mono resolution, no overscan */
       SDL_UpdateRect(sdlscrn, 0,0,0,0);
@@ -846,19 +911,20 @@ static void Screen_Blit(BOOL bSwapScreen)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Draw ST screen to window/full-screen framebuffer
-*/
+/**
+ * Draw ST screen to window/full-screen framebuffer
+ */
 static void Screen_DrawFrame(BOOL bForceFlip)
 {
+  int new_res;
   void (*pDrawFunction)(void);
 
   /* Scan palette/resolution masks for each line and build up palette/difference tables */
-  STRes = Screen_ComparePaletteMask();
+  new_res = Screen_ComparePaletteMask(STRes);
   /* Do require palette? Check if changed and update */
   Screen_Handle8BitPalettes();
   /* Did we change resolution this frame - allocate new screen if did so */
-  Screen_DidResolutionChange();
+  Screen_DidResolutionChange(new_res);
   /* Is need full-update, tag as such */
   if (pFrameBuffer->bFullUpdate)
     Screen_SetFullUpdateMask();
@@ -912,9 +978,9 @@ static void Screen_DrawFrame(BOOL bForceFlip)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Draw ST screen to window/full-screen
-*/
+/**
+ * Draw ST screen to window/full-screen
+ */
 void Screen_Draw(void)
 {
   if (!bQuitProgram)
@@ -927,9 +993,6 @@ void Screen_Draw(void)
       /* And status bar */
       /*StatusBar_UpdateIcons();*/ /* Sorry - no statusbar in Hatari yet */
     }
-
-    /* Check printer status */
-    Printer_CheckIdleStatus();
   }
 }
 
@@ -950,7 +1013,8 @@ void Screen_Draw(void)
 */
 
 
-/*-----------------------------------------------------------------------
+/*-----------------------------------------------------------------------*/
+/**
  * Update the STRGBPalette[] array with current colours for this raster line.
  *
  * Return 'ScrUpdateFlag', 0x80000000=Full update, 0x40000000=Update
@@ -979,7 +1043,8 @@ static int AdjustLinePaletteRemap(int y)
 }
 
 
-/*-----------------------------------------------------------------------
+/*-----------------------------------------------------------------------*/
+/**
  * Run updates to palette(STRGBPalette[]) until get to screen line
  * we are to convert from
  */
