@@ -15,7 +15,7 @@
   on boot-up which (correctly) cause a bus-error on Hatari as they would in a
   real STfm. If a user tries to select any of these images we bring up an error.
 */
-const char TOS_rcsid[] = "Hatari $Id: tos.c,v 1.39 2006/03/01 20:46:48 thothy Exp $";
+const char TOS_rcsid[] = "Hatari $Id: tos.c,v 1.50 2007/02/11 23:00:50 thothy Exp $";
 
 #include <SDL_endian.h>
 
@@ -31,6 +31,7 @@ const char TOS_rcsid[] = "Hatari $Id: tos.c,v 1.39 2006/03/01 20:46:48 thothy Ex
 #include "stMemory.h"
 #include "tos.h"
 #include "vdi.h"
+#include "uae-cpu/hatari-glue.h"
 
 
 Uint16 TosVersion;                      /* eg, 0x0100, 0x0102 */
@@ -55,7 +56,7 @@ static const char * const pszTosNameExts[] =
 enum
 {
 	TP_ALWAYS,            /* Patch should alway be applied */
-	TP_ACSI_OFF,          /* Apply patch only if ACSI HD emulation is off */
+	TP_HDIMAGE_OFF,       /* Apply patch only if HD emulation is off */
 	TP_ANTI_STE           /* Apply patch only if running on plain ST */
 };
 
@@ -73,25 +74,28 @@ typedef struct
 } TOS_PATCH;
 
 static const char pszDmaBoot[] = "boot from DMA bus";
-static const char pszMouse[] = "working mouse in big screen resolutions";
+static const char pszMouse[] = "big resolutions mouse driver";
 static const char pszRomCheck[] = "ROM checksum";
 static const char pszNoSteHw[] = "disable STE hardware access";
 static const char pszNoPmmu[] = "disable PMMU access";
+static const char pszHwDisable[] = "disable hardware access";
 
 //static Uint8 pRtsOpcode[] = { 0x4E, 0x75 };  /* 0x4E75 = RTS */
 static const Uint8 pNopOpcodes[] = { 0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71,
         0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71,
         0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71, 0x4E, 0x71 };  /* 0x4E71 = NOP */
 static const Uint8 pMouseOpcode[] = { 0xD3, 0xC1 };  /* "ADDA.L D1,A1" (instead of "ADDA.W D1,A1") */
-static const Uint8 pRomCheckOpcode[] = { 0x60, 0x00, 0x00, 0x98 };  /* BRA $e00894 */
+static const Uint8 pRomCheckOpcode206[] = { 0x60, 0x00, 0x00, 0x98 };  /* BRA $e00894 */
+static const Uint8 pRomCheckOpcode306[] = { 0x60, 0x00, 0x00, 0xB0 };  /* BRA $e00886 */
+static const Uint8 pRomCheckOpcode404[] = { 0x60, 0x00, 0x00, 0x94 };  /* BRA $e00746 */
 static const Uint8 pBraOpcode[] = { 0x60 };  /* 0x60XX = BRA */
 
 /* The patches for the TOS: */
 static const TOS_PATCH TosPatches[] =
 {
-  { 0x100, -1, pszDmaBoot, TP_ACSI_OFF, 0xFC03D6, 0x610000D0, 4, pNopOpcodes }, /* BSR $FC04A8 */
+  { 0x100, -1, pszDmaBoot, TP_HDIMAGE_OFF, 0xFC03D6, 0x610000D0, 4, pNopOpcodes }, /* BSR $FC04A8 */
 
-  { 0x102, -1, pszDmaBoot, TP_ACSI_OFF, 0xFC0472, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $FC0558 */
+  { 0x102, -1, pszDmaBoot, TP_HDIMAGE_OFF, 0xFC0472, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $FC0558 */
   { 0x102, 0, pszMouse, TP_ALWAYS, 0xFD0030, 0xD2C147F9, 2, pMouseOpcode },
   { 0x102, 1, pszMouse, TP_ALWAYS, 0xFD008A, 0xD2C147F9, 2, pMouseOpcode },
   { 0x102, 2, pszMouse, TP_ALWAYS, 0xFD00A8, 0xD2C147F9, 2, pMouseOpcode },
@@ -99,13 +103,13 @@ static const TOS_PATCH TosPatches[] =
   { 0x102, 6, pszMouse, TP_ALWAYS, 0xFCFEF0, 0xD2C147F9, 2, pMouseOpcode },
   { 0x102, 8, pszMouse, TP_ALWAYS, 0xFCFEFE, 0xD2C147F9, 2, pMouseOpcode },
 
-  { 0x104, -1, pszDmaBoot, TP_ACSI_OFF, 0xFC0466, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $FC054C */
+  { 0x104, -1, pszDmaBoot, TP_HDIMAGE_OFF, 0xFC0466, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $FC054C */
 
-  { 0x106, -1, pszDmaBoot, TP_ACSI_OFF, 0xE00576, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $E0065C */
+  { 0x106, -1, pszDmaBoot, TP_HDIMAGE_OFF, 0xE00576, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $E0065C */
 
-  { 0x162, -1, pszDmaBoot, TP_ACSI_OFF, 0xE00576, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $E0065C */
+  { 0x162, -1, pszDmaBoot, TP_HDIMAGE_OFF, 0xE00576, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $E0065C */
 
-  { 0x205, -1, pszDmaBoot, TP_ACSI_OFF, 0xE006AE, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $E00794 */
+  { 0x205, -1, pszDmaBoot, TP_HDIMAGE_OFF, 0xE006AE, 0x610000E4, 4, pNopOpcodes }, /* BSR.W $E00794 */
   /* An unpatched TOS 2.05 only works on STEs, so apply some anti-STE patches... */
   { 0x205, -1, pszNoSteHw, TP_ANTI_STE, 0xE00096, 0x42788900, 4, pNopOpcodes }, /* CLR.W $FFFF8900 */
   { 0x205, -1, pszNoSteHw, TP_ANTI_STE, 0xE0009E, 0x31D88924, 4, pNopOpcodes }, /* MOVE.W (A0)+,$FFFF8924 */
@@ -127,21 +131,46 @@ static const TOS_PATCH TosPatches[] =
   /* E007FA  MOVE.L  #$1FFFE,D7  Run checksums on 2xROMs (skip) */
   /* Checksum is total of TOS ROM image, but get incorrect results */
   /* as we've changed bytes in the ROM! So, just skip anyway! */
-  { 0x206, -1, pszRomCheck, TP_ALWAYS, 0xE007FA, 0x2E3C0001, 4, pRomCheckOpcode },
-  { 0x206, -1, pszDmaBoot, TP_ACSI_OFF, 0xE00898, 0x610000E0, 4, pNopOpcodes }, /* BSR.W $E0097A */
+  { 0x206, -1, pszRomCheck, TP_ALWAYS, 0xE007FA, 0x2E3C0001, 4, pRomCheckOpcode206 },
+  { 0x206, -1, pszDmaBoot, TP_HDIMAGE_OFF, 0xE00898, 0x610000E0, 4, pNopOpcodes }, /* BSR.W $E0097A */
 
+  { 0x306, -1, pszRomCheck, TP_ALWAYS, 0xE007D4, 0x2E3C0001, 4, pRomCheckOpcode306 },
   { 0x306, -1, pszNoPmmu, TP_ALWAYS, 0xE00068, 0xF0394000, 24, pNopOpcodes },
   { 0x306, -1, pszNoPmmu, TP_ALWAYS, 0xE01702, 0xF0394C00, 32, pNopOpcodes },
 
+  { 0x400, -1, pszNoPmmu, TP_ALWAYS, 0xE00064, 0xF0394000, 24, pNopOpcodes },
+  { 0x400, -1, pszNoPmmu, TP_ALWAYS, 0xE0148A, 0xF0394C00, 32, pNopOpcodes },
+  { 0x400, -1, pszNoPmmu, TP_ALWAYS, 0xE03948, 0xF0394000, 24, pNopOpcodes },
+  { 0x400, -1, pszRomCheck, TP_ALWAYS, 0xE00686, 0x2E3C0007, 4, pRomCheckOpcode404 },
+
+  { 0x401, -1, pszNoPmmu, TP_ALWAYS, 0xE0006A, 0xF0394000, 24, pNopOpcodes },
+  { 0x401, -1, pszNoPmmu, TP_ALWAYS, 0xE014A8, 0xF0394C00, 32, pNopOpcodes },
+  { 0x401, -1, pszNoPmmu, TP_ALWAYS, 0xE03946, 0xF0394000, 24, pNopOpcodes },
+  { 0x401, -1, pszRomCheck, TP_ALWAYS, 0xE006A6, 0x2E3C0007, 4, pRomCheckOpcode404 },
+
+  { 0x402, -1, pszNoPmmu, TP_ALWAYS, 0xE0006A, 0xF0394000, 24, pNopOpcodes },
+  { 0x402, -1, pszNoPmmu, TP_ALWAYS, 0xE014A8, 0xF0394C00, 32, pNopOpcodes },
+  { 0x402, -1, pszNoPmmu, TP_ALWAYS, 0xE03946, 0xF0394000, 24, pNopOpcodes },
+  { 0x402, -1, pszRomCheck, TP_ALWAYS, 0xE006A6, 0x2E3C0007, 4, pRomCheckOpcode404 },
+
+  { 0x404, -1, pszNoPmmu, TP_ALWAYS, 0xE0006A, 0xF0394000, 24, pNopOpcodes },
+  { 0x404, -1, pszNoPmmu, TP_ALWAYS, 0xE014E6, 0xF0394C00, 32, pNopOpcodes },
+  { 0x404, -1, pszNoPmmu, TP_ALWAYS, 0xE039A0, 0xF0394000, 24, pNopOpcodes },
+  { 0x404, -1, pszRomCheck, TP_ALWAYS, 0xE006B0, 0x2E3C0007, 4, pRomCheckOpcode404 },
+
+  { 0x492, -1, pszNoPmmu, TP_ALWAYS, 0x00F946, 0xF0394000, 24, pNopOpcodes },
+  { 0x492, -1, pszNoPmmu, TP_ALWAYS, 0x01097A, 0xF0394C00, 32, pNopOpcodes },
+  { 0x492, -1, pszNoPmmu, TP_ALWAYS, 0x012E04, 0xF0394000, 24, pNopOpcodes },
+
   { 0, 0, NULL, 0, 0, 0, 0, NULL }
 };
 
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Save/Restore snapshot of local variables ('MemorySnapShot_Store' handles type)
-*/
+/**
+ * Save/Restore snapshot of local variables ('MemorySnapShot_Store' handles type)
+ */
 void TOS_MemorySnapShot_Capture(BOOL bSave)
 {
 	/* Save/Restore details */
@@ -154,28 +183,21 @@ void TOS_MemorySnapShot_Capture(BOOL bSave)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Patch TOS to skip some TOS setup code which we don't support/need.
- 
-  So, how do we find these addresses when we have no commented source code?
-  - For the "Boot from DMA bus" patch:
-    Scan at start of rom for tst.w $482, boot call will be just above it.
-*/
+/**
+ * Patch TOS to skip some TOS setup code which we don't support/need.
+ *
+ * So, how do we find these addresses when we have no commented source code?
+ * - For the "Boot from DMA bus" patch:
+ *   Scan at start of rom for tst.w $482, boot call will be just above it.
+ */
 static void TOS_FixRom(void)
 {
 	int nGoodPatches, nBadPatches;
 	short TosCountry;
 	const TOS_PATCH *pPatch;
 
-	/* Check for EmuTOS first since we can not patch it */
-	if (STMemory_ReadLong(TosAddress+0x2c) == 0x45544F53)   /* 0x45544F53 = 'ETOS' */
-	{
-		Log_Printf(LOG_DEBUG, "Detected EmuTOS, skipping TOS patches.\n");
-		return;
-	}
-
-	/* We also can't patch RAM TOS images (yet) */
-	if (bRamTosImage)
+	/* We can't patch RAM TOS images (yet) */
+	if (bRamTosImage && TosVersion != 0x0492)
 	{
 		Log_Printf(LOG_DEBUG, "Detected RAM TOS image, skipping TOS patches.\n");
 		return;
@@ -196,17 +218,18 @@ static void TOS_FixRom(void)
 			if(STMemory_ReadLong(pPatch->Address) == pPatch->OldData)
 			{
 				/* Only apply the patch if it is really needed: */
-				if (pPatch->Flags == TP_ALWAYS || (pPatch->Flags == TP_ACSI_OFF && !ACSI_EMU_ON)
+				if (pPatch->Flags == TP_ALWAYS
+				    || (pPatch->Flags == TP_HDIMAGE_OFF && !ACSI_EMU_ON && !ConfigureParams.HardDisk.bUseIdeHardDiskImage)
 				    || (pPatch->Flags == TP_ANTI_STE && ConfigureParams.System.nMachineType == MACHINE_ST))
 				{
 					/* Now we can really apply the patch! */
-					/*fprintf(stderr, "Applying TOS patch '%s'.\n", pPatch->pszName);*/
+					Log_Printf(LOG_DEBUG, "Applying TOS patch '%s'.\n", pPatch->pszName);
 					memcpy(&STRam[pPatch->Address], pPatch->pNewData, pPatch->Size);
 					nGoodPatches += 1;
 				}
 				else
 				{
-					/*fprintf(stderr, "Skipped patch '%s'.\n", pPatch->pszName);*/
+					Log_Printf(LOG_DEBUG, "Skipped patch '%s'.\n", pPatch->pszName);
 				}
 			}
 			else
@@ -225,14 +248,72 @@ static void TOS_FixRom(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Load TOS Rom image file into ST memory space and fix image so can emulate correctly
-  Pre TOS 1.06 are loaded at 0xFC0000 with later ones at 0xE00000
-*/
+/**
+ * Assert that TOS version matches the machine type and change the system
+ * configuration if necessary.
+ * For example TOSes 1.06 and 1.62 are for the STE ONLY and so don't run
+ * on a real ST, TOS 3.0x is TT only and TOS 4.x is Falcon only.
+ * These TOS version access illegal memory addresses on machine they were
+ * not designed for and so cause the OS to lock up. So, if user selects one
+ * of these, switch to the appropriate machine type.
+ */
+static void TOS_CheckSysConfig(void)
+{
+	if ((TosVersion == 0x0106 || TosVersion == 0x0162) && ConfigureParams.System.nMachineType != MACHINE_STE)
+	{
+		Log_AlertDlg(LOG_INFO, "TOS versions 1.06 and 1.62 are for Atari STE only.\n"
+		             " ==> Switching to STE mode now.\n");
+		IoMem_UnInit();
+		ConfigureParams.System.nMachineType = MACHINE_STE;
+		IoMem_Init();
+	}
+	else if ((TosVersion & 0x0f00) == 0x0300 && ConfigureParams.System.nMachineType != MACHINE_TT)
+	{
+		Log_AlertDlg(LOG_INFO, "TOS versions 3.0x are for Atari TT only.\n"
+		             " ==> Switching to TT mode now.\n");
+		IoMem_UnInit();
+		ConfigureParams.System.nMachineType = MACHINE_TT;
+		IoMem_Init();
+		ConfigureParams.System.nCpuLevel = 3;
+		check_prefs_changed_cpu(ConfigureParams.System.nCpuLevel, ConfigureParams.System.bCompatibleCpu);
+	}
+	else if ((TosVersion & 0x0f00) == 0x0400 && ConfigureParams.System.nMachineType != MACHINE_FALCON)
+	{
+		Log_AlertDlg(LOG_INFO, "TOS versions 4.x are for Atari Falcon only.\n"
+		             " ==> Switching to Falcon mode now.\n");
+		IoMem_UnInit();
+		ConfigureParams.System.nMachineType = MACHINE_FALCON;
+		IoMem_Init();
+		ConfigureParams.System.nCpuLevel = 3;
+		check_prefs_changed_cpu(ConfigureParams.System.nCpuLevel, ConfigureParams.System.bCompatibleCpu);
+	}
+	else if ((TosVersion < 0x0300 && ConfigureParams.System.nMachineType == MACHINE_FALCON)
+	         || (TosVersion < 0x0200 && ConfigureParams.System.nMachineType == MACHINE_TT))
+	{
+		Log_AlertDlg(LOG_INFO, "This TOS versions does not work in TT/Falcon mode.\n"
+		             " ==> Switching to STE mode now.\n");
+		IoMem_UnInit();
+		ConfigureParams.System.nMachineType = MACHINE_STE;
+		IoMem_Init();
+		if (TosVersion <= 0x0104)
+		{
+			ConfigureParams.System.nCpuLevel = 0;
+			check_prefs_changed_cpu(ConfigureParams.System.nCpuLevel, ConfigureParams.System.bCompatibleCpu);
+		}
+	}
+}
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Load TOS Rom image file into ST memory space and fix image so can emulate correctly
+ * Pre TOS 1.06 are loaded at 0xFC0000 with later ones at 0xE00000
+ */
 int TOS_LoadImage(void)
 {
 	Uint8 *pTosFile = NULL;
 	long nFileSize;
+	BOOL bIsEmuTOS;
 
 	bTosImageLoaded = FALSE;
 
@@ -251,11 +332,17 @@ int TOS_LoadImage(void)
 	/* Check for RAM TOS images first: */
 	if (SDL_SwapBE32(*(Uint32 *)pTosFile) == 0x46FC2700)
 	{
+		int nRamTosLoaderSize;
 		Log_Printf(LOG_WARN, "Detected a RAM TOS - this will probably not work very well!\n");
 		/* RAM TOS images have a 256 bytes loader function before the real image
-		 * starts, so we simply skip the first 256 bytes here: */
-		TosSize -= 0x100;
-		memmove(pTosFile, pTosFile + 0x100, TosSize);
+		 * starts (34 bytes for TOS 4.92). Since we directly copy the image to the right
+		 * location later, we simply skip this additional header here: */
+		if (SDL_SwapBE32(*(Uint32 *)(pTosFile+34)) == 0x602E0492)
+			nRamTosLoaderSize = 0x22;
+		else
+			nRamTosLoaderSize = 0x100;
+		TosSize -= nRamTosLoaderSize;
+		memmove(pTosFile, pTosFile + nRamTosLoaderSize, TosSize);
 		bRamTosImage = TRUE;
 	}
 	else
@@ -263,12 +350,15 @@ int TOS_LoadImage(void)
 		bRamTosImage = FALSE;
 	}
 
+	/* Check for EmuTOS ... (0x45544F53 = 'ETOS') */
+	bIsEmuTOS = (SDL_SwapBE32(*(Uint32 *)&pTosFile[0x2c]) == 0x45544F53);
+
 	/* Now, look at start of image to find Version number and address */
 	TosVersion = SDL_SwapBE16(*(Uint16 *)&pTosFile[2]);
 	TosAddress = SDL_SwapBE32(*(Uint32 *)&pTosFile[8]);
 
 	/* Check for reasonable TOS version: */
-	if (TosVersion<0x100 || TosVersion>0x500 || TosSize>1024*1024L
+	if (TosVersion<0x100 || TosVersion>=0x500 || TosSize>1024*1024L
 	    || (!bRamTosImage && TosAddress!=0xe00000 && TosAddress!=0xfc0000))
 	{
 		Log_AlertDlg(LOG_FATAL, "Your TOS image seems not to be a valid TOS ROM file!\n"
@@ -276,17 +366,10 @@ int TOS_LoadImage(void)
 		return -2;
 	}
 
-	/* TOSes 1.06 and 1.62 are for the STE ONLY and so don't run on a real ST. */
-	/* They access illegal memory addresses which don't exist on a real machine and cause the OS */
-	/* to lock up. So, if user selects one of these, switch to STE mode. */
-	if ((TosVersion == 0x0106 || TosVersion == 0x0162) && ConfigureParams.System.nMachineType != MACHINE_STE)
-	{
-		Log_AlertDlg(LOG_INFO, "TOS versions 1.06 and 1.62\nare NOT valid ST ROM images.\n"
-		             " => Switching to STE mode now.\n");
-		IoMem_UnInit();
-		ConfigureParams.System.nMachineType = MACHINE_STE;
-		IoMem_Init();
-	}
+	/* Assert that machine type matches the TOS version. Note that EmuTOS can
+	 * handle all machine types, so we don't do the system check there: */
+	if (!bIsEmuTOS)
+		TOS_CheckSysConfig();
 
 	/* Copy loaded image into ST memory */
 	memcpy(STRam+TosAddress, pTosFile, TosSize);
@@ -306,7 +389,8 @@ int TOS_LoadImage(void)
 	}
 
 	/* Fix TOS image, modify code for emulation */
-	TOS_FixRom();
+	if (!bIsEmuTOS)
+		TOS_FixRom();
 
 	/* Set connected devices, memory configuration, etc. */
 	STMemory_SetDefaultConfig();
