@@ -9,7 +9,7 @@
   TV raster trace, border removal, palette changes per HBL, the 'video address
   pointer' etc...
 */
-const char Video_rcsid[] = "Hatari $Id: video.c,v 1.52 2006/08/09 08:14:24 eerot Exp $";
+const char Video_rcsid[] = "Hatari $Id: video.c,v 1.72 2007/01/28 23:05:57 thothy Exp $";
 
 #include <SDL_endian.h>
 
@@ -24,6 +24,7 @@ const char Video_rcsid[] = "Hatari $Id: video.c,v 1.52 2006/08/09 08:14:24 eerot
 #include "m68000.h"
 #include "memorySnapShot.h"
 #include "mfp.h"
+#include "printer.h"
 #include "screen.h"
 #include "shortcut.h"
 #include "sound.h"
@@ -32,6 +33,8 @@ const char Video_rcsid[] = "Hatari $Id: video.c,v 1.52 2006/08/09 08:14:24 eerot
 #include "vdi.h"
 #include "video.h"
 #include "ymFormat.h"
+#include "falcon/videl.h"
+#include "falcon/hostscreen.h"
 
 
 #define BORDERMASK_NONE    0x00                 /* Borders masks */
@@ -40,7 +43,8 @@ const char Video_rcsid[] = "Hatari $Id: video.c,v 1.52 2006/08/09 08:14:24 eerot
 #define BORDERMASK_MIDDLE  0x04
 
 
-BOOL bUseHighRes = FALSE;                       /* Use hi-res (ie Mono monitor) */
+BOOL bUseSTShifter;                             /* Falcon: whether to use ST palette */
+BOOL bUseHighRes;                               /* Use hi-res (ie Mono monitor) */
 int nVBLs, nHBL;                                /* VBL Counter, HBL line */
 int nStartHBL, nEndHBL;                         /* Start/End HBL for visible screen */
 int OverscanMode;                               /* OVERSCANMODE_xxxx for current display frame */
@@ -62,16 +66,20 @@ static Uint8 VideoShifterByte;                  /* VideoShifter (0xff8260) value
 static int LeftRightBorder;                     /* BORDERMASK_xxxx used to simulate left/right border removal */
 static int nLastAccessCycleLeft;                /* Line cycle where program tried to open left border */
 static BOOL bSteBorderFlag;                     /* TRUE when screen width has been switched to 336 (e.g. in Obsession) */
+static int nTTRes;                              /* TT shifter resolution mode */
+static BOOL bTTColorsSync, bTTColorsSTSync;     /* whether TT colors need convertion to SDL */
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Save/Restore snapshot of local variables('MemorySnapShot_Store' handles type)
-*/
+/**
+ * Save/Restore snapshot of local variables('MemorySnapShot_Store' handles type)
+ */
 void Video_MemorySnapShot_Capture(BOOL bSave)
 {
   /* Save/Restore details */
-  MemorySnapShot_Store(&VideoShifterByte,sizeof(VideoShifterByte));
+  MemorySnapShot_Store(&VideoShifterByte, sizeof(VideoShifterByte));
+  MemorySnapShot_Store(&nTTRes, sizeof(nTTRes));
+  MemorySnapShot_Store(&bUseSTShifter, sizeof(bUseSTShifter));
   MemorySnapShot_Store(&bUseHighRes,sizeof(bUseHighRes));
   MemorySnapShot_Store(&nVBLs,sizeof(nVBLs));
   MemorySnapShot_Store(&nHBL,sizeof(nHBL));
@@ -92,9 +100,9 @@ void Video_MemorySnapShot_Capture(BOOL bSave)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Calculate and return video address pointer.
-*/
+/**
+ * Calculate and return video address pointer.
+ */
 static Uint32 Video_CalculateAddress(void)
 {
   int X, FrameCycles;
@@ -111,13 +119,12 @@ static Uint32 Video_CalculateAddress(void)
   else
   {
     /* Now find which pixel we are on (ignore left/right borders) */
-    /* 96 + 320 + 96 = 512 pixels per scan line (each pixel is one cycle) */
     X = FrameCycles % nCyclesPerLine;
     if (X < SCREEN_START_CYCLE)       /* Limit if in NULL area outside screen */
       X = SCREEN_START_CYCLE;
     if (X > (nCyclesPerLine - SCREEN_START_CYCLE))
       X = (nCyclesPerLine - SCREEN_START_CYCLE);
-    /* X is now from 96 to 416 (320 pixels), subtract 96 to give X pixel across screen! */
+    /* X is now in the correct range, subtract SCREEN_START_CYCLE to give X pixel across screen! */
     X = ((X-SCREEN_START_CYCLE)>>1)&(~1);
 
     VideoAddress = pVideoRaster - STRam;
@@ -131,30 +138,12 @@ static Uint32 Video_CalculateAddress(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  HBL interrupt - this is very inaccurate on ST and appears to occur around 1/3rd way into
-  the display!
-*/
-void Video_InterruptHandler_HBL(void)
-{
-  /* Remove this interrupt from list and re-order */
-  Int_AcknowledgeInterrupt();
-
-  /* Generate new HBL, if need to - there are 313 HBLs per frame in 50 Hz */
-  if (nHBL < nScanlinesPerFrame-1)
-    Int_AddAbsoluteInterrupt(nCyclesPerLine, INTERRUPT_VIDEO_HBL);
-
-  M68000_Exception(EXCEPTION_HBLANK);   /* Horizontal blank interrupt, level 2! */
-}
-
-
-/*-----------------------------------------------------------------------*/
-/*
-  Write to VideoShifter (0xff8260), resolution bits
-*/
+/**
+ * Write to VideoShifter (0xff8260), resolution bits
+ */
 static void Video_WriteToShifter(Uint8 Byte)
 {
-  static int nLastHBL = -1, LastByte, nLastCycles;
+  static int nLastByte, nLastFrameCycles;
   int nFrameCycles, nLineCycles;
   
   nFrameCycles = Cycles_GetCounterOnWriteAccess(CYCLES_COUNTER_VIDEO);
@@ -169,23 +158,22 @@ static void Video_WriteToShifter(Uint8 Byte)
    * FIXME: This is a very inaccurate test that should be improved,
    * but we probably need better CPU cycles emulation first. There's
    * also no support for sync-scrolling yet :-( */
-  if (nHBL == nLastHBL && LastByte == 0x02 && Byte == 0x00
-      && nLineCycles <= 48 && nLineCycles-nLastCycles <= 16)
+  if (nLastByte == 0x02 && Byte == 0x00 && nLineCycles <= 12
+      && nFrameCycles-nLastFrameCycles <= 16)
   {
     LeftRightBorder |= BORDERMASK_LEFT;
     nLastAccessCycleLeft = nLineCycles;
   }
 
-  nLastHBL = nHBL;
-  LastByte = Byte;
-  nLastCycles = nLineCycles;
+  nLastByte = Byte;
+  nLastFrameCycles = nFrameCycles;
 }
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to VideoSync (0xff820a), Hz setting
-*/
+/**
+ * Write to VideoSync (0xff820a), Hz setting
+ */
 void Video_Sync_WriteByte(void)
 {
   static int nLastHBL = -1, LastByte, nLastCycles;
@@ -227,8 +215,9 @@ void Video_Sync_WriteByte(void)
 
   if (LastByte == 0x00 && Byte == 0x02)   /* switched from 60 Hz to 50 Hz? */
   {
-    if (nHBL == nLastHBL && nLineCycles >= 400 && nLineCycles <= 480
-        && nLineCycles-nLastCycles <= 16)
+    if (nHBL == nLastHBL && nLineCycles-nLastCycles <= 16
+        && nLineCycles >= (SCREEN_START_CYCLE+320-40)
+        && nLineCycles <= (SCREEN_START_CYCLE+320+40))
     {
       /* Right border */
       //fprintf(stderr,"Right sync: %i - %i = %i\n", nLineCycles, nLastAccessCycleLeft, nLineCycles - nLastAccessCycleLeft);
@@ -250,9 +239,9 @@ void Video_Sync_WriteByte(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Reset Sync/Shifter table at start of each HBL
-*/
+/**
+ * Reset Sync/Shifter table at start of each HBL
+ */
 static void Video_StartHBL(void)
 {
   LeftRightBorder = BORDERMASK_NONE;
@@ -260,9 +249,9 @@ static void Video_StartHBL(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Store whole palette on first line so have reference to work from
-*/
+/**
+ * Store whole palette on first line so have reference to work from
+ */
 static void Video_StoreFirstLinePalette(void)
 {
   Uint16 *pp2;
@@ -277,9 +266,9 @@ static void Video_StoreFirstLinePalette(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Store resolution on each line(used to test if mixed low/medium resolutions)
-*/
+/**
+ * Store resolution on each line(used to test if mixed low/medium resolutions)
+ */
 static void Video_StoreResolution(int y)
 {
   /* Clear resolution, and set with current value */
@@ -292,9 +281,9 @@ static void Video_StoreResolution(int y)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Copy one line of monochrome screen into buffer for conversion later.
-*/
+/**
+ * Copy one line of monochrome screen into buffer for conversion later.
+ */
 static void Video_CopyScreenLineMono(void)
 {
   int i;
@@ -344,10 +333,10 @@ static void Video_CopyScreenLineMono(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Copy one line of color screen into buffer for conversion later.
-  Possible lines may be top/bottom border, and/or left/right borders.
-*/
+/**
+ * Copy one line of color screen into buffer for conversion later.
+ * Possible lines may be top/bottom border, and/or left/right borders.
+ */
 static void Video_CopyScreenLineColor(void)
 {
   /* Is total blank line? I.e. top/bottom border? */
@@ -473,9 +462,9 @@ static void Video_CopyScreenLineColor(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Copy line of screen into buffer for conversion later.
-*/
+/**
+ * Copy line of screen into buffer for conversion later.
+ */
 static void Video_CopyScreenLine(void)
 {
   /* Only copy screen line if not doing high VDI resolution */
@@ -496,9 +485,9 @@ static void Video_CopyScreenLine(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Copy extended GEM resolution screen
-*/
+/**
+ * Copy extended GEM resolution screen
+ */
 static void Video_CopyVDIScreen(void)
 {
   /* Copy whole screen, don't care about being exact as for GEM only */
@@ -507,9 +496,9 @@ static void Video_CopyVDIScreen(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Check at end of each HBL to see if any Sync/Shifter hardware tricks have been attempted
-*/
+/**
+ * Check at end of each HBL to see if any Sync/Shifter hardware tricks have been attempted
+ */
 static void Video_EndHBL(void)
 {
   Uint8 nSyncByte = IoMem_ReadByte(0xff820a);
@@ -561,11 +550,29 @@ static void Video_EndHBL(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  End Of Line interrupt
-  As this occurs at the end of a line we cannot get timing for START of first
-  line (as in Spectrum 512)
-*/
+/**
+ * HBL interrupt - this is very inaccurate on ST and appears to occur around
+ * 1/3rd way into the display!
+ */
+void Video_InterruptHandler_HBL(void)
+{
+  /* Remove this interrupt from list and re-order */
+  Int_AcknowledgeInterrupt();
+
+  /* Generate new HBL, if need to - there are 313 HBLs per frame in 50 Hz */
+  if (nHBL < nScanlinesPerFrame-1)
+    Int_AddAbsoluteInterrupt(nCyclesPerLine, INTERRUPT_VIDEO_HBL);
+
+  M68000_Exception(EXCEPTION_HBLANK);   /* Horizontal blank interrupt, level 2! */
+}
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * End Of Line interrupt
+ *  As this occurs at the end of a line we cannot get timing for START of first
+ * line (as in Spectrum 512)
+ */
 void Video_InterruptHandler_EndLine(void)
 {
   /* Remove this interrupt from list and re-order */
@@ -581,16 +588,13 @@ void Video_InterruptHandler_EndLine(void)
     IKBD_SendAutoKeyboardCommands();
   }
 
-  /* Timer A/B occur at END of first visible screen line in Event Count mode */
+  /* Timer B occurs at END of first visible screen line in Event Count mode */
   if (nHBL >= nStartHBL && nHBL < nEndHBL)
-   {
-    /* Handle Timers A and B when using Event Count mode(timer taken from HBL) */
-// FIXME: Really raise Timer A here?
-//    if (MFP_TACR==0x08)        /* Is timer in Event Count mode? */
-//      MFP_TimerA_EventCount_Interrupt();
-    if (MFP_TBCR==0x08)        /* Is timer in Event Count mode? */
+  {
+    /* Handle Timer B when using Event Count mode */
+    if (MFP_TBCR == 0x08)      /* Is timer in Event Count mode? */
       MFP_TimerB_EventCount_Interrupt();
-   }
+  }
 
   FDC_UpdateHBL();             /* Update FDC motion */
   Video_EndHBL();              /* Increase HBL count, copy line to display buffer and do any video trickery */
@@ -604,10 +608,10 @@ void Video_InterruptHandler_EndLine(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Clear raster line table to store changes in palette/resolution on a line
-  basic. Called once on VBL interrupt.
-*/
+/**
+ * Clear raster line table to store changes in palette/resolution on a line
+ * basic. Called once on VBL interrupt.
+ */
 void Video_SetScreenRasters(void)
 {
   pHBLPaletteMasks = HBLPaletteMasks;
@@ -617,9 +621,9 @@ void Video_SetScreenRasters(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set pointers to HBLPalette tables to store correct colours/resolutions
-*/
+/**
+ * Set pointers to HBLPalette tables to store correct colours/resolutions
+ */
 static void Video_SetHBLPaletteMaskPointers(void)
 {
   int FrameCycles;
@@ -647,9 +651,9 @@ static void Video_SetHBLPaletteMaskPointers(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Set video shifter timing variables according to screen refresh rate
-*/
+/**
+ * Set video shifter timing variables according to screen refresh rate
+ */
 static void Video_ResetShifterTimings(void)
 {
   Uint8 nSyncByte;
@@ -689,9 +693,9 @@ static void Video_ResetShifterTimings(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Called on VBL, set registers ready for frame
-*/
+/**
+ * Called on VBL, set registers ready for frame
+ */
 static void Video_ClearOnVBL(void)
 {
   /* New screen, so first HBL */
@@ -717,9 +721,140 @@ static void Video_ClearOnVBL(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  VBL interrupt, draw screen and reset counters
-*/
+/**
+ * Get width, height and bpp according to TT-Resolution
+ */
+void Video_GetTTRes(int *width, int *height, int *bpp)
+{
+  switch (nTTRes)
+  {
+    case 0: *width = 320; *height = 200; *bpp = 4; break;
+    case 1: *width = 640; *height = 200; *bpp = 2; break;
+    case 2: *width = 640; *height = 400; *bpp = 1; break;
+    case 4: *width = 640; *height = 480; *bpp = 4; break;
+    case 6: *width = 1280; *height = 960; *bpp = 1; break;
+    case 7: *width = 320; *height = 480; *bpp = 8; break;
+    default:
+      fprintf(stderr, "TT res error!\n");
+      *width = 320; *height = 200; *bpp = 4;
+      break;
+  }
+}
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Convert TT palette to SDL and blit TT screen using VIDEL code
+ */
+static void Video_RenderTTScreen(void)
+{
+  static int nPrevTTRes = -1;
+  int width, height, bpp, i, colors, offset;
+  uint8 r,g,b, lowbyte, highbyte;
+  uint32 ttpalette, src, dst;
+  Uint16 stcolor, ttcolor;
+
+  Video_GetTTRes(&width, &height, &bpp);
+  if (nTTRes != nPrevTTRes)
+  {
+    HostScreen_setWindowSize(width, height, 8);
+    nPrevTTRes = nTTRes;
+  }
+
+  /* colors need synching? */
+  if (!(bTTColorsSync && bTTColorsSTSync))
+  {
+    ttpalette = 0xff8400;
+
+    if (!bTTColorsSTSync)
+    {
+      /* sync TT ST-palette to TT-palette */
+      src = 0xff8240;	/* ST-palette */
+      offset = (IoMem_ReadWord(0xff8262) & 0x0f);
+      /*fprintf(stdout, "offset: %d\n", offset);*/
+      dst = ttpalette + offset * 16*SIZE_WORD;
+
+      for (i = 0; i < 16; i++)
+      {
+        stcolor = IoMem_ReadWord(src);
+        ttcolor = ((stcolor&0x700) << 1) | ((stcolor&0x70) << 1) | ((stcolor&0x7) << 1);
+        IoMem_WriteWord(dst, ttcolor);
+        src += SIZE_WORD; dst += SIZE_WORD;
+      }
+      bTTColorsSTSync = TRUE;
+    }
+    colors = 1 << bpp;
+    for (i = 0; i < colors; i++)
+    {
+      lowbyte = IoMem_ReadByte(ttpalette++);
+      highbyte = IoMem_ReadByte(ttpalette++);
+      r = (lowbyte  & 0x0f) << 4;
+      g = (highbyte & 0xf0);
+      b = (highbyte & 0x0f) << 4;
+      //printf("%d: (%d,%d,%d)\n", i,r,g,b);
+      HostScreen_setPaletteColor(i, r,g,b);
+    }
+    HostScreen_updatePalette(colors);
+    bTTColorsSync = TRUE;
+  }
+
+  /* Yes, we are abusing the Videl routines for rendering the TT modes! */
+  if (!HostScreen_renderBegin())
+    return;
+  if (ConfigureParams.Screen.bZoomLowRes)
+    VIDEL_ConvertScreenZoom(width, height, bpp, width * bpp / 16);
+  else
+    VIDEL_ConvertScreenNoZoom(width, height, bpp, width * bpp / 16);
+  HostScreen_renderEnd();
+  HostScreen_update1(FALSE);
+}
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Draw screen (either with ST/STE shifter drawing functions or with
+ * Videl drawing functions)
+ */
+static void Video_DrawScreen(void)
+{
+  /* Skip frame if need to */
+  if (nVBLs % (ConfigureParams.Screen.FrameSkips+1))
+    return;
+
+  /* Use extended VDI resolution?
+   * If so, just copy whole screen on VBL rather than per HBL */
+  if (bUseVDIRes)
+    Video_CopyVDIScreen();
+
+  /* Now draw the screen! */
+  if (ConfigureParams.System.nMachineType == MACHINE_FALCON && !bUseVDIRes)
+  {
+    VIDEL_renderScreen();
+  }
+  else if (ConfigureParams.System.nMachineType == MACHINE_TT && !bUseVDIRes)
+  {
+    Video_RenderTTScreen();
+  }
+  else
+    Screen_Draw();
+}
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Start HBL and VBL interrupts.
+ */
+void Video_StartInterrupts(void)
+{
+  Int_AddAbsoluteInterrupt(nCyclesPerLine-96, INTERRUPT_VIDEO_ENDLINE);
+  Int_AddAbsoluteInterrupt(nCyclesPerLine, INTERRUPT_VIDEO_HBL);
+  Int_AddAbsoluteInterrupt(CYCLES_PER_FRAME, INTERRUPT_VIDEO_VBL);
+}
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * VBL interrupt, draw screen and reset counters
+ */
 void Video_InterruptHandler_VBL(void)
 {
   int PendingCyclesOver;
@@ -729,10 +864,9 @@ void Video_InterruptHandler_VBL(void)
 
   /* Remove this interrupt from list and re-order */
   Int_AcknowledgeInterrupt();
-  /* Start HBL interrupts */
-  Int_AddAbsoluteInterrupt(nCyclesPerLine, INTERRUPT_VIDEO_ENDLINE);
-  Int_AddAbsoluteInterrupt(CYCLES_HBL,INTERRUPT_VIDEO_HBL);
-  Int_AddAbsoluteInterrupt(CYCLES_PER_FRAME,INTERRUPT_VIDEO_VBL);
+
+  /* Start VBL & HBL interrupts */
+  Video_StartInterrupts();
 
   /* Set frame cycles, used for Video Address */
   Cycles_SetCounter(CYCLES_COUNTER_VIDEO, PendingCyclesOver);
@@ -742,19 +876,12 @@ void Video_InterruptHandler_VBL(void)
   /* Act on shortcut keys */
   ShortCut_ActKey();
 
-  /* Draw screen, skip frame if need to */
-  if (!ConfigureParams.Screen.bFrameSkip || (nVBLs&1))
-  {
-    /* Use extended VDI resolution?
-     * If so, just copy whole screen on VBL rather than per HBL */
-    if (bUseVDIRes)
-      Video_CopyVDIScreen();
+  Video_DrawScreen();
 
-    /* Now draw the screen! */
-    Screen_Draw();
-  }
+  /* Check printer status */
+  Printer_CheckIdleStatus();
 
-  /* Update counter for number of screen refreshes per second(for debugging) */
+  /* Update counter for number of screen refreshes per second */
   nVBLs++;
   /* Set video registers for frame */
   Video_ClearOnVBL();
@@ -769,7 +896,8 @@ void Video_InterruptHandler_VBL(void)
   Main_EventHandler();         /* Process messages, set 'bQuitProgram' if user tries to quit */
   if (bQuitProgram)
   {
-    Int_AddAbsoluteInterrupt(4, 0L);  /* Pass NULL interrupt function to quit cleanly */
+    /* Pass NULL interrupt function to quit cleanly */
+    Int_AddAbsoluteInterrupt(4, INTERRUPT_NULL);
     set_special(SPCFLAG_BRK);         /* Assure that CPU core shuts down */
   }
 
@@ -778,9 +906,9 @@ void Video_InterruptHandler_VBL(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Reset video chip
-*/
+/**
+ * Reset video chip
+ */
 void Video_Reset(void)
 {
   /* NOTE! Must reset all of these register type things here!!!! */
@@ -808,48 +936,48 @@ void Video_Reset(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to video address base high and med register (0xff8201 and 0xff8203).
-  When a program writes to these registers, some other video registers
-  are reset to zero.
-*/
+/**
+ * Write to video address base high and med register (0xff8201 and 0xff8203).
+ * When a program writes to these registers, some other video registers
+ * are reset to zero.
+ */
 void Video_ScreenBaseSTE_WriteByte(void)
 {
   IoMem[0xff820d] = 0;          /* Reset screen base low register */
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read video address counter high byte (0xff8205)
-*/
+/**
+ * Read video address counter high byte (0xff8205)
+ */
 void Video_ScreenCounterHigh_ReadByte(void)
 {
   IoMem[0xff8205] = Video_CalculateAddress() >> 16;   /* Get video address counter high byte */
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read video address counter med byte (0xff8207)
-*/
+/**
+ * Read video address counter med byte (0xff8207)
+ */
 void Video_ScreenCounterMed_ReadByte(void)
 {
   IoMem[0xff8207] = Video_CalculateAddress() >> 8;    /* Get video address counter med byte */
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read video address counter low byte (0xff8209)
-*/
+/**
+ * Read video address counter low byte (0xff8209)
+ */
 void Video_ScreenCounterLow_ReadByte(void)
 {
   IoMem[0xff8209] = Video_CalculateAddress();         /* Get video address counter low byte */
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to video address counter (0xff8205, 0xff8207 and 0xff8209).
-  Called on STE only and like with base address, you cannot set lowest bit.
-*/
+/**
+ * Write to video address counter (0xff8205, 0xff8207 and 0xff8209).
+ * Called on STE only and like with base address, you cannot set lowest bit.
+ */
 void Video_ScreenCounter_WriteByte(void)
 {
   Uint32 addr;
@@ -858,19 +986,19 @@ void Video_ScreenCounter_WriteByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read video sync register (0xff820a)
-*/
+/**
+ * Read video sync register (0xff820a)
+ */
 void Video_Sync_ReadByte(void)
 {
   /* Nothing... */
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read video base address low byte (0xff820d). A plain ST can only store
-  screen addresses rounded to 256 bytes (i.e. no lower byte).
-*/
+/**
+ * Read video base address low byte (0xff820d). A plain ST can only store
+ * screen addresses rounded to 256 bytes (i.e. no lower byte).
+ */
 void Video_BaseLow_ReadByte(void)
 {
   if (ConfigureParams.System.nMachineType == MACHINE_ST)
@@ -883,9 +1011,9 @@ void Video_BaseLow_ReadByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read video line width register (0xff820f)
-*/
+/**
+ * Read video line width register (0xff820f)
+ */
 void Video_LineWidth_ReadByte(void)
 {
   if (ConfigureParams.System.nMachineType == MACHINE_ST)
@@ -895,9 +1023,9 @@ void Video_LineWidth_ReadByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read video shifter mode register (0xff8260)
-*/
+/**
+ * Read video shifter mode register (0xff8260)
+ */
 void Video_ShifterMode_ReadByte(void)
 {
   if (bUseHighRes)
@@ -907,9 +1035,9 @@ void Video_ShifterMode_ReadByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Read horizontal scroll register (0xff8265)
-*/
+/**
+ * Read horizontal scroll register (0xff8265)
+ */
 void Video_HorScroll_Read(void)
 {
   IoMem[0xff8265] = HWScrollCount;
@@ -917,18 +1045,18 @@ void Video_HorScroll_Read(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write video line width register (0xff820f) - STE only.
-*/
+/**
+ * Write video line width register (0xff820f) - STE only.
+ */
 void Video_LineWidth_WriteByte(void)
 {
     ScanLineSkip = IoMem_ReadByte(0xff820f);
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to video shifter palette registers (0xff8240-0xff825e)
-*/
+/**
+ * Write to video shifter palette registers (0xff8240-0xff825e)
+ */
 static void Video_ColorReg_WriteWord(Uint32 addr)
 {
   if (!bUseHighRes)                        /* Don't store if hi-res */
@@ -1031,11 +1159,24 @@ void Video_Color15_WriteWord(void)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write video shifter mode register (0xff860)
-*/
+/**
+ * Write video shifter mode register (0xff860)
+ */
 void Video_ShifterMode_WriteByte(void)
 {
+  if (ConfigureParams.System.nMachineType == MACHINE_TT)
+  {
+    nTTRes = IoMem_ReadByte(0xff8260) & 7;
+    IoMem_WriteByte(0xff8262, nTTRes);                /* Copy to TT shifter mode register */
+  }
+  if (ConfigureParams.System.nMachineType == MACHINE_FALCON)
+  {
+    /* - activate STE palette
+     * - TODO: set line width ($8210)
+     * - TODO: sets paramaters in $82c2 (double lines/interlace & cycles/pixel)
+     */
+    bUseSTShifter = TRUE;
+  }
   if (!bUseHighRes && !bUseVDIRes)                    /* Don't store if hi-res and don't store if VDI resolution */
   {
     VideoShifterByte = IoMem[0xff8260] & 3;           /* We only care for lower 2-bits */
@@ -1048,16 +1189,16 @@ void Video_ShifterMode_WriteByte(void)
 }
 
 /*-----------------------------------------------------------------------*/
-/*
-  Write to horizontal scroll register (0xff8265).
-  Note: The STE shifter has a funny "bug"  that allows to increase the
-  resolution to 336x200 instead of 320x200. It occurs when a program writes
-  certain values to 0xff8264:
-	move.w  #1,$ffff8264      ; Word access!
-	clr.b   $ffff8264         ; Byte access!
-  Some games (Obsession, Skulls) and demos (Pacemaker by Paradox) use this
-  feature to increase the resolution, so we have to emulate this bug, too!
-*/
+/**
+ * Write to horizontal scroll register (0xff8265).
+ * Note: The STE shifter has a funny "bug"  that allows to increase the
+ * resolution to 336x200 instead of 320x200. It occurs when a program writes
+ * certain values to 0xff8264:
+ *	move.w  #1,$ffff8264      ; Word access!
+ *	clr.b   $ffff8264         ; Byte access!
+ * Some games (Obsession, Skulls) and demos (Pacemaker by Paradox) use this
+ * feature to increase the resolution, so we have to emulate this bug, too!
+ */
 void Video_HorScroll_Write(void)
 {
   static BOOL bFirstSteAccess = FALSE;
@@ -1086,3 +1227,40 @@ void Video_HorScroll_Write(void)
 
   HWScrollCount &= 0x0f;
 }
+
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Write to TT shifter mode register (0xff8262)
+ */
+void Video_TTShiftMode_WriteWord(void)
+{
+	nTTRes = IoMem_ReadByte(0xff8262) & 7;
+
+	/*fprintf(stderr, "Write to FF8262: %x, res=%i\n", IoMem_ReadWord(0xff8262),nTTRes);*/
+
+	/* Is it an ST compatible resolution? */
+	if (nTTRes <= 2)
+	{
+		IoMem_WriteByte(0xff8260, nTTRes);
+		Video_ShifterMode_WriteByte();
+	}
+}
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Write to TT color register (0xff8400)
+ */
+void Video_TTColorRegs_WriteWord(void)
+{
+  bTTColorsSync = FALSE;
+}
+
+/*-----------------------------------------------------------------------*/
+/**
+ * Write to ST color register on TT (0xff8400)
+ */
+void Video_TTColorSTRegs_WriteWord(void)
+{
+  bTTColorsSTSync = FALSE;
+}
