@@ -9,7 +9,7 @@
   We intercept and direct some XBios calls to handle the RS-232 etc. and help
   with floppy debugging.
 */
-const char XBios_rcsid[] = "Hatari $Id: xbios.c,v 1.11 2006/02/12 21:28:22 eerot Exp $";
+const char XBios_rcsid[] = "Hatari $Id: xbios.c,v 1.12 2007/01/16 18:42:59 thothy Exp $";
 
 #include "main.h"
 #include "configuration.h"
@@ -48,10 +48,10 @@ static const int BaudRates[] = {
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  XBIOS Floppy Read
-  Call 8
-*/
+/**
+ * XBIOS Floppy Read
+ * Call 8
+ */
 static BOOL XBios_Floprd(Uint32 Params)
 {
 #if XBIOS_DEBUG
@@ -75,10 +75,10 @@ static BOOL XBios_Floprd(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  XBIOS Floppy Write
-  Call 9
-*/
+/**
+ * XBIOS Floppy Write
+ * Call 9
+ */
 static BOOL XBios_Flopwr(Uint32 Params)
 {
 #if XBIOS_DEBUG
@@ -102,10 +102,10 @@ static BOOL XBios_Flopwr(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  XBIOS RsConf
-  Call 15
-*/
+/**
+ * XBIOS RsConf
+ * Call 15
+ */
 static BOOL XBios_Rsconf(Uint32 Params)
 {
   short int Baud,Ctrl,Ucr,Rsr,Tsr,Scr;
@@ -146,10 +146,10 @@ static BOOL XBios_Rsconf(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  XBIOS Scrdmp
-  Call 20
-*/
+/**
+ * XBIOS Scrdmp
+ * Call 20
+ */
 static BOOL XBios_Scrdmp(Uint32 Params)
 {
   fprintf(stderr, "XBIOS screendump!\n");
@@ -164,10 +164,10 @@ static BOOL XBios_Scrdmp(Uint32 Params)
 
 
 /*----------------------------------------------------------------------- */
-/*
-  XBIOS Prtblk
-  Call 36
-*/
+/**
+ * XBIOS Prtblk
+ * Call 36
+ */
 static BOOL XBios_Prtblk(Uint32 Params)
 {
   fprintf(stderr, "Intercepted XBIOS Prtblk()\n");
@@ -180,9 +180,9 @@ static BOOL XBios_Prtblk(Uint32 Params)
 
 
 /*-----------------------------------------------------------------------*/
-/*
-  Check if we need to re-direct XBios call to our own routines
-*/
+/**
+ * Check if we need to re-direct XBios call to our own routines
+ */
 BOOL XBios(void)
 {
   Uint32 Params;
